@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*               ARGUMENT ACCESS MODULE                */
    /*******************************************************/
@@ -19,6 +19,10 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Added IllegalLogicalNameMessage function.      */
+/*                                                           */
 /*************************************************************/
 
 #define _ARGACCES_SOURCE_
@@ -482,12 +486,12 @@ globle int EnvArgTypeCheck(
 /*  TRUE is returned if a numeric argument was successfully       */
 /*  retrieved, otherwise FALSE is returned.                       */
 /******************************************************************/
-globle BOOLEAN GetNumericArgument(
+globle intBool GetNumericArgument(
   void *theEnv,
   struct expr *theArgument,
   char *functionName,
   DATA_OBJECT *result,
-  BOOLEAN convertToFloat,
+  intBool convertToFloat,
   int whichArgument)
   {
    unsigned short theType;
@@ -776,7 +780,7 @@ globle void ExpectedCountError(
 /*                 function calls which have the sequence    */
 /*                 expansion operator in their argument list */
 /*************************************************************/
-globle BOOLEAN CheckFunctionArgCount(
+globle intBool CheckFunctionArgCount(
   void *theEnv,
   char *functionName,
   char *restrictions,
@@ -948,7 +952,9 @@ void *GetFactOrInstanceArgument(
   DATA_OBJECT *item,
   char *functionName)
   {
+#if DEFTEMPLATE_CONSTRUCT || OBJECT_SYSTEM
    void *ptr;
+#endif
 
    /*==============================*/
    /* Retrieve the first argument. */
@@ -1006,3 +1012,16 @@ void *GetFactOrInstanceArgument(
    return(NULL);
   }
 
+/****************************************************/
+/* IllegalLogicalNameMessage: Generic error message */
+/*   for illegal logical names.                     */
+/****************************************************/
+void IllegalLogicalNameMessage(
+  void *theEnv,
+  char *theFunction)
+  {
+   PrintErrorID(theEnv,"IOFUN",1,FALSE);
+   EnvPrintRouter(theEnv,WERROR,"Illegal logical name used for ");
+   EnvPrintRouter(theEnv,WERROR,theFunction);
+   EnvPrintRouter(theEnv,WERROR," function.\n");
+  }
