@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*               CLIPS Version 6.20  01/31/02          */
+   /*               CLIPS Version 6.24  06/05/06          */
    /*                                                     */
    /*                    BLOAD MODULE                     */
    /*******************************************************/
@@ -18,6 +18,8 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
 /*************************************************************/
 
 #define _BLOAD_SOURCE_
@@ -206,7 +208,7 @@ globle int EnvBload(
         strncmp(constructBuffer,BloadData(theEnv)->BinaryPrefixID,CONSTRUCT_HEADER_SIZE) != 0;
         GenReadBinary(theEnv,constructBuffer,(unsigned long) CONSTRUCT_HEADER_SIZE))
      {
-      BOOLEAN found;
+      intBool found;
 
       /*================================================*/
       /* Search for the construct type in the list of   */
@@ -269,7 +271,7 @@ globle int EnvBload(
         strncmp(constructBuffer,BloadData(theEnv)->BinaryPrefixID,CONSTRUCT_HEADER_SIZE) != 0;
         GenReadBinary(theEnv,constructBuffer,(unsigned long) CONSTRUCT_HEADER_SIZE))
      {
-      BOOLEAN found;
+      intBool found;
 
       /*==================================================*/
       /* Search for the function to load the construct    */
@@ -563,7 +565,7 @@ static struct FunctionDefinition *FastFindFunction(
 /*   environment is the result of a bload */
 /*   command, otherwise returns FALSE.    */
 /******************************************/
-globle BOOLEAN Bloaded(
+globle intBool Bloaded(
   void *theEnv)
   {
    return(BloadData(theEnv)->BloadActive);
@@ -757,7 +759,7 @@ static int BloadOutOfMemoryFunction(
   void *theEnv,
   unsigned long size)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(size,theEnv)
 #endif
    return(TRUE);
@@ -794,7 +796,7 @@ globle int BloadCommand(
    fileName = GetFileName(theEnv,"bload",1);
    if (fileName != NULL) return(EnvBload(theEnv,fileName));
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 #endif
