@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*             BASIC MATH FUNCTIONS MODULE             */
    /*******************************************************/
@@ -18,6 +18,9 @@
 /* Contributing Programmer(s):                               */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Correction for FalseSymbol/TrueSymbol. DR0859  */
+/*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
 /*                                                           */
 /*************************************************************/
 
@@ -39,7 +42,7 @@
 
 struct basicMathFunctionData
   { 
-   BOOLEAN AutoFloatDividend;
+   intBool AutoFloatDividend;
   };
 
 #define BasicMathFunctionData(theEnv) ((struct basicMathFunctionData *) GetEnvironmentData(theEnv,BMATHFUN_DATA))
@@ -84,7 +87,7 @@ globle void AdditionFunction(
   {
    double ftotal = 0.0;
    long ltotal = 0L;
-   BOOLEAN useFloatTotal = FALSE;
+   intBool useFloatTotal = FALSE;
    EXPRESSION *theExpression;
    DATA_OBJECT theArgument;
    int pos = 1;
@@ -146,7 +149,7 @@ globle void MultiplicationFunction(
   {
    double ftotal = 1.0;
    long ltotal = 1L;
-   BOOLEAN useFloatTotal = FALSE;
+   intBool useFloatTotal = FALSE;
    EXPRESSION *theExpression;
    DATA_OBJECT theArgument;
    int pos = 1;
@@ -207,7 +210,7 @@ globle void SubtractionFunction(
   {
    double ftotal = 0.0;
    long ltotal = 0L;
-   BOOLEAN useFloatTotal = FALSE;
+   intBool useFloatTotal = FALSE;
    EXPRESSION *theExpression;
    DATA_OBJECT theArgument;
    int pos = 1;
@@ -288,7 +291,7 @@ globle void DivisionFunction(
   {
    double ftotal = 1.0;
    long ltotal = 1L;
-   BOOLEAN useFloatTotal;
+   intBool useFloatTotal;
    EXPRESSION *theExpression;
    DATA_OBJECT theArgument;
    int pos = 1;
@@ -475,7 +478,7 @@ globle int SetAutoFloatDividendCommand(
    /* The symbol FALSE disables the auto float dividend feature. */
    /*============================================================*/
 
-   if ((theArgument.value == SymbolData(theEnv)->FalseSymbol) && (theArgument.type == SYMBOL))
+   if ((theArgument.value == EnvFalseSymbol(theEnv)) && (theArgument.type == SYMBOL))
      { BasicMathFunctionData(theEnv)->AutoFloatDividend = FALSE; }
    else
      { BasicMathFunctionData(theEnv)->AutoFloatDividend = TRUE; }
@@ -511,7 +514,7 @@ globle int GetAutoFloatDividendCommand(
 /* EnvGetAutoFloatDividend: C access routine for */
 /*   the get-auto-float-dividend command.        */
 /*************************************************/
-globle BOOLEAN EnvGetAutoFloatDividend(
+globle intBool EnvGetAutoFloatDividend(
   void *theEnv)
   {
    return(BasicMathFunctionData(theEnv)->AutoFloatDividend);
@@ -521,7 +524,7 @@ globle BOOLEAN EnvGetAutoFloatDividend(
 /* EnvSetAutoFloatDividend: C access routine for */
 /*   the set-auto-float-dividend command.        */
 /*************************************************/
-globle BOOLEAN EnvSetAutoFloatDividend(
+globle intBool EnvSetAutoFloatDividend(
   void *theEnv,
   int value)
   {
