@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.21  06/15/03            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*                COMMAND LINE MODULE                  */
    /*******************************************************/
@@ -18,6 +18,12 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Refactored several functions and added         */
+/*            additional functions for use by an interface   */
+/*            layered on top of CLIPS.                       */
+/*                                                           */
 /*************************************************************/
 
 #define _COMMLINE_SOURCE_
@@ -85,7 +91,7 @@ static void DeallocateCommandLineData(
    if (CommandLineData(theEnv)->CommandString != NULL) 
      { rm(theEnv,CommandLineData(theEnv)->CommandString,CommandLineData(theEnv)->MaximumCharacters); }
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 #endif
@@ -507,20 +513,7 @@ globle void CommandLoop(
       /* buffer, then execute it.                */
       /*=========================================*/
 
-      if ((CompleteCommand(CommandLineData(theEnv)->CommandString) != 0) && (RouterData(theEnv)->CommandBufferInputCount > 0))
-        {
-         FlushPPBuffer(theEnv);
-         SetPPBufferStatus(theEnv,OFF);
-         RouterData(theEnv)->CommandBufferInputCount = -1;
-         RouteCommand(theEnv,CommandLineData(theEnv)->CommandString,TRUE);
-         FlushPPBuffer(theEnv);
-         SetHaltExecution(theEnv,FALSE);
-         SetEvaluationError(theEnv,FALSE);
-         FlushCommandString(theEnv);
-         FlushBindList(theEnv);
-         PeriodicCleanup(theEnv,TRUE,FALSE);
-         PrintPrompt(theEnv);
-        }
+      ExecuteIfCommandComplete(theEnv);
      }
   }
   
@@ -532,16 +525,46 @@ globle void CommandLoop(
 globle void CommandLoopBatch(
   void *theEnv)
   {
-   int inchar;
-
    SetHaltExecution(theEnv,FALSE);
    SetEvaluationError(theEnv,FALSE);
    PeriodicCleanup(theEnv,TRUE,FALSE);
    PrintPrompt(theEnv);
    RouterData(theEnv)->CommandBufferInputCount = 0;
 
+   CommandLoopBatchDriver(theEnv);
+  }
+
+/************************************************************/
+/* CommandLoopOnceThenBatch: Loop which waits for commands  */
+/*   from a batch file and then executes them. Returns when */
+/*   there are no longer any active batch files.            */
+/************************************************************/
+globle void CommandLoopOnceThenBatch(
+  void *theEnv)
+  {
+   if (! ExecuteIfCommandComplete(theEnv)) return;
+
+   CommandLoopBatchDriver(theEnv);
+  }
+  
+/*********************************************************/
+/* CommandLoopBatchDriver: Loop which waits for commands */
+/*   from a batch file and then executes them. Returns   */
+/*   when there are no longer any active batch files.    */
+/*********************************************************/
+globle void CommandLoopBatchDriver(
+  void *theEnv)
+  {
+   int inchar;
+
    while (TRUE)
      {
+      if (GetHaltCommandLoopBatch(theEnv) == TRUE)
+        { 
+         CloseAllBatchSources(theEnv);
+         SetHaltCommandLoopBatch(theEnv,FALSE);
+        }
+        
       /*===================================================*/
       /* If a batch file is active, grab the command input */
       /* directly from the batch file, otherwise call the  */
@@ -581,23 +604,49 @@ globle void CommandLoopBatch(
       /* buffer, then execute it.                */
       /*=========================================*/
 
-      if ((CompleteCommand(CommandLineData(theEnv)->CommandString) != 0) && (RouterData(theEnv)->CommandBufferInputCount > 0))
-        {
-         FlushPPBuffer(theEnv);
-         SetPPBufferStatus(theEnv,OFF);
-         RouterData(theEnv)->CommandBufferInputCount = -1;
-         RouteCommand(theEnv,CommandLineData(theEnv)->CommandString,TRUE);
-         FlushPPBuffer(theEnv);
-         SetHaltExecution(theEnv,FALSE);
-         SetEvaluationError(theEnv,FALSE);
-         FlushCommandString(theEnv);
-         FlushBindList(theEnv);
-         PeriodicCleanup(theEnv,TRUE,FALSE);
-         PrintPrompt(theEnv);
-        }
+      ExecuteIfCommandComplete(theEnv);
      }
   }
-  
+
+/**********************************************************/
+/* ExecuteIfCommandComplete: Checks to determine if there */
+/*   is a completed command and if so executes it.        */
+/**********************************************************/
+globle intBool ExecuteIfCommandComplete(
+  void *theEnv)
+  {
+   if ((CompleteCommand(CommandLineData(theEnv)->CommandString) == 0) || 
+       (RouterData(theEnv)->CommandBufferInputCount <= 0))
+     { return FALSE; }
+      
+   FlushPPBuffer(theEnv);
+   SetPPBufferStatus(theEnv,OFF);
+   RouterData(theEnv)->CommandBufferInputCount = -1;
+   RouteCommand(theEnv,CommandLineData(theEnv)->CommandString,TRUE);
+   FlushPPBuffer(theEnv);
+   SetHaltExecution(theEnv,FALSE);
+   SetEvaluationError(theEnv,FALSE);
+   FlushCommandString(theEnv);
+   FlushBindList(theEnv);
+   PeriodicCleanup(theEnv,TRUE,FALSE);
+   PrintPrompt(theEnv);
+         
+   return TRUE;
+  }
+
+/*******************************************/
+/* CommandCompleteAndNotEmpty: */
+/*******************************************/
+globle intBool CommandCompleteAndNotEmpty(
+  void *theEnv)
+  {
+   if ((CompleteCommand(CommandLineData(theEnv)->CommandString) == 0) || 
+       (RouterData(theEnv)->CommandBufferInputCount <= 0))
+     { return FALSE; }
+     
+   return TRUE;
+  }
+       
 /*******************************************/
 /* PrintPrompt: Prints the command prompt. */
 /*******************************************/
@@ -610,6 +659,15 @@ globle void PrintPrompt(
       { (*CommandLineData(theEnv)->AfterPromptFunction)(theEnv); }
    }
 
+/*****************************************/
+/* PrintBanner: Prints the CLIPS banner. */
+/*****************************************/
+globle void PrintBanner(
+   void *theEnv)
+   {
+    EnvPrintRouter(theEnv,WPROMPT,CommandLineData(theEnv)->BannerString);
+   }
+
 /************************************************/
 /* SetAfterPromptFunction: Replaces the current */
 /*   value of AfterPromptFunction.              */
@@ -624,7 +682,7 @@ globle void SetAfterPromptFunction(
 /************************************************/
 /* RouteCommand: Processes a completed command. */
 /************************************************/
-globle BOOLEAN RouteCommand(
+globle intBool RouteCommand(
   void *theEnv,
   char *command,
   int printResult)
@@ -807,7 +865,7 @@ globle int (*SetEventFunction(void *theEnv,int (*theFunction)(void *)))(void *)
 /* TopLevelCommand: Indicates whether a */
 /*   top-level command is being parsed. */
 /****************************************/
-globle BOOLEAN TopLevelCommand(
+globle intBool TopLevelCommand(
   void *theEnv)
   {
    return(CommandLineData(theEnv)->ParsingTopLevelCommand);
@@ -889,5 +947,24 @@ globle char *GetCommandCompletionString(
    return("");
   }
 
+/****************************************************************/
+/* SetHaltCommandLoopBatch: Sets the HaltCommandLoopBatch flag. */
+/****************************************************************/
+globle void SetHaltCommandLoopBatch(
+  void *theEnv,
+  int value)
+  { 
+   CommandLineData(theEnv)->HaltCommandLoopBatch = value; 
+  }
+
+/*******************************************************************/
+/* GetHaltCommandLoopBatch: Returns the HaltCommandLoopBatch flag. */
+/*******************************************************************/
+globle int GetHaltCommandLoopBatch(
+  void *theEnv)
+  {
+   return(CommandLineData(theEnv)->HaltCommandLoopBatch);
+  }
+
 #endif
 
