@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*                  CONSTRUCT MODULE                   */
    /*******************************************************/
@@ -19,6 +19,11 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Added environment parameter to GenClose.       */
+/*            Added environment parameter to GenOpen.        */
+/*                                                           */
+/*            Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
 /*************************************************************/
 
 #define _CONSTRCT_SOURCE_
@@ -162,7 +167,7 @@ globle int EnvSave(
    /* Open the save file. */
    /*=====================*/
 
-   if ((filePtr = GenOpen(fileName,"w")) == NULL)
+   if ((filePtr = GenOpen(theEnv,fileName,"w")) == NULL)
      { return(FALSE); }
 
    /*===========================*/
@@ -191,7 +196,7 @@ globle int EnvSave(
    /* Close the save file. */
    /*======================*/
 
-   GenClose(filePtr);
+   GenClose(theEnv,filePtr);
 
    /*===========================*/
    /* Remove the router bypass. */
@@ -212,7 +217,7 @@ globle int EnvSave(
 /*   ListOfSaveFunctions. Returns TRUE if the function */
 /*   was successfully removed, otherwise FALSE.        */
 /*******************************************************/
-globle BOOLEAN RemoveSaveFunction(
+globle intBool RemoveSaveFunction(
   void *theEnv,
   char *name)
   {
@@ -253,7 +258,7 @@ globle unsigned GetCompilationsWatch(
 /**********************************/
 globle void SetPrintWhileLoading(
   void *theEnv,
-  BOOLEAN value)
+  intBool value)
   {
    ConstructData(theEnv)->PrintWhileLoading = value;
   }
@@ -262,7 +267,7 @@ globle void SetPrintWhileLoading(
 /* GetPrintWhileLoading: Returns the */
 /*   value of PrintWhileLoading.     */
 /*************************************/
-globle BOOLEAN GetPrintWhileLoading(
+globle intBool GetPrintWhileLoading(
   void *theEnv)
   {
    return(ConstructData(theEnv)->PrintWhileLoading);
@@ -284,7 +289,7 @@ globle void InitializeConstructs(
    AddWatchItem(theEnv,"compilations",0,&ConstructData(theEnv)->WatchCompilations,30,NULL,NULL);
 #endif
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 #endif
@@ -412,7 +417,7 @@ globle int (*SetBeforeResetFunction(void *theEnv,
 /* AddResetFunction: Adds a function */
 /*   to ListOfResetFunctions.        */
 /*************************************/
-globle BOOLEAN AddResetFunction(
+globle intBool AddResetFunction(
   char *name,
   void (*functionPtr)(void),
   int priority)
@@ -432,7 +437,7 @@ globle BOOLEAN AddResetFunction(
 /* EnvAddResetFunction: Adds a function */
 /*   to ListOfResetFunctions.           */
 /****************************************/
-globle BOOLEAN EnvAddResetFunction(
+globle intBool EnvAddResetFunction(
   void *theEnv,
   char *name,
   void (*functionPtr)(void *),
@@ -448,7 +453,7 @@ globle BOOLEAN EnvAddResetFunction(
 /* EnvRemoveResetFunction: Removes a function */
 /*   from the ListOfResetFunctions.           */
 /**********************************************/
-globle BOOLEAN EnvRemoveResetFunction(
+globle intBool EnvRemoveResetFunction(
   void *theEnv,
   char *name)
   {
@@ -544,7 +549,7 @@ globle void EnvClear(
 /*   determined (e.g. facts will be deleted as part of   */
 /*   the determination).                                 */
 /*********************************************************/
-globle BOOLEAN ClearReady(
+globle intBool ClearReady(
   void *theEnv)
   {
    struct callFunctionItem *theFunction;
@@ -566,7 +571,7 @@ globle BOOLEAN ClearReady(
 /* AddClearReadyFunction: Adds a function */
 /*   to ListOfClearReadyFunctions.        */
 /******************************************/
-globle BOOLEAN AddClearReadyFunction(
+globle intBool AddClearReadyFunction(
   void *theEnv,
   char *name,
   int (*functionPtr)(void *),
@@ -583,7 +588,7 @@ globle BOOLEAN AddClearReadyFunction(
 /* RemoveClearReadyFunction: Removes a function */
 /*   from the ListOfClearReadyFunctions.        */
 /************************************************/
-globle BOOLEAN RemoveClearReadyFunction(
+globle intBool RemoveClearReadyFunction(
   void *theEnv,
   char *name)
   {
@@ -602,7 +607,7 @@ globle BOOLEAN RemoveClearReadyFunction(
 /* AddClearFunction: Adds a function */
 /*   to ListOfClearFunctions.        */
 /*************************************/
-globle BOOLEAN AddClearFunction(
+globle intBool AddClearFunction(
   char *name,
   void (*functionPtr)(void),
   int priority)
@@ -623,7 +628,7 @@ globle BOOLEAN AddClearFunction(
 /* EnvAddClearFunction: Adds a function */
 /*   to ListOfClearFunctions.           */
 /****************************************/
-globle BOOLEAN EnvAddClearFunction(
+globle intBool EnvAddClearFunction(
   void *theEnv,
   char *name,
   void (*functionPtr)(void *),
@@ -640,7 +645,7 @@ globle BOOLEAN EnvAddClearFunction(
 /* EnvRemoveClearFunction: Removes a function */
 /*    from the ListOfClearFunctions.          */
 /**********************************************/
-globle BOOLEAN EnvRemoveClearFunction(
+globle intBool EnvRemoveClearFunction(
   void *theEnv,
   char *name)
   {
@@ -797,7 +802,7 @@ globle struct construct *AddConstruct(
   struct defmoduleItemHeader *(*getModuleItemFunction)(struct constructHeader *),
   void *(*getNextItemFunction)(void *,void *),
   void (*setNextItemFunction)(struct constructHeader *,struct constructHeader *),
-  BOOLEAN (*isConstructDeletableFunction)(void *,void *),
+  intBool (*isConstructDeletableFunction)(void *,void *),
   int (*deleteFunction)(void *,void *),
   void (*freeFunction)(void *,void *))
   {
@@ -837,13 +842,13 @@ globle struct construct *AddConstruct(
 /* AddSaveFunction: Adds a function */
 /*   to the ListOfSaveFunctions.    */
 /************************************/
-globle BOOLEAN AddSaveFunction(
+globle intBool AddSaveFunction(
   void *theEnv,
   char *name,
   void (*functionPtr)(void *,void *,char *),
   int priority)
   {
-#if (MAC_MPW || MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY)
+#if (MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY)
 #pragma unused(name)
 #pragma unused(functionPtr)
 #pragma unused(priority)
@@ -855,7 +860,7 @@ globle BOOLEAN AddSaveFunction(
                            (void (*)(void *)) functionPtr,
                            ConstructData(theEnv)->ListOfSaveFunctions,TRUE);
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 #endif
