@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  07/01/05            */
    /*                                                     */
    /*             CONSTRAINT UTILITY MODULE               */
    /*******************************************************/
@@ -17,6 +17,7 @@
 /*      Brian Donnell                                        */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.24: Added allowed-classes slot facet.              */
 /*                                                           */
 /*************************************************************/
 
@@ -64,7 +65,9 @@ globle struct constraintRecord *GetConstraintRecord(
    constraints->stringRestriction = FALSE;
    constraints->floatRestriction = FALSE;
    constraints->integerRestriction = FALSE;
+   constraints->classRestriction = FALSE;
    constraints->instanceNameRestriction = FALSE;
+   constraints->classList = NULL;
    constraints->restrictionList = NULL;
    constraints->minValue = GenConstant(theEnv,SYMBOL,SymbolData(theEnv)->NegativeInfinity);
    constraints->maxValue = GenConstant(theEnv,SYMBOL,SymbolData(theEnv)->PositiveInfinity);
@@ -144,7 +147,9 @@ globle struct constraintRecord *CopyConstraintRecord(
    theConstraint->stringRestriction = sourceConstraint->stringRestriction;
    theConstraint->floatRestriction = sourceConstraint->floatRestriction;
    theConstraint->integerRestriction = sourceConstraint->integerRestriction;
+   theConstraint->classRestriction = sourceConstraint->classRestriction;
    theConstraint->instanceNameRestriction = sourceConstraint->instanceNameRestriction;
+   theConstraint->classList = CopyExpression(theEnv,sourceConstraint->classList);
    theConstraint->restrictionList = CopyExpression(theEnv,sourceConstraint->restrictionList);
    theConstraint->minValue = CopyExpression(theEnv,sourceConstraint->minValue);
    theConstraint->maxValue = CopyExpression(theEnv,sourceConstraint->maxValue);
