@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.21  06/15/03            */
+   /*             CLIPS Version 6.24  05/17/06            */
    /*                                                     */
    /*                    DRIVE MODULE                     */
    /*******************************************************/
@@ -17,6 +17,15 @@
 /* Contributing Programmer(s):                               */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Correction for FalseSymbol/TrueSymbol. DR0859  */
+/*                                                           */
+/*      6.24: Removed INCREMENTAL_RESET and                  */
+/*            LOGICAL_DEPENDENCIES compilation flags.        */
+/*                                                           */
+/*            Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Rule with exists CE has incorrect activation.  */
+/*            DR0867                                         */
 /*                                                           */
 /*************************************************************/
 
@@ -39,14 +48,8 @@
 #include "reteutil.h"
 #include "retract.h"
 #include "router.h"
-
-#if LOGICAL_DEPENDENCIES
 #include "lgcldpnd.h"
-#endif
-
-#if INCREMENTAL_RESET
 #include "incrrset.h"
-#endif
 
 #include "drive.h"
 
@@ -79,7 +82,7 @@ globle void NetworkAssert(
    /* is not part of the network to be reset, then return.    */
    /*=========================================================*/
 
-#if INCREMENTAL_RESET && (! BLOAD_ONLY) && (! RUN_TIME)
+#if (! BLOAD_ONLY) && (! RUN_TIME)
    if (EngineData(theEnv)->IncrementalResetInProgress && (join->initialize == FALSE)) return;
 #endif
 
@@ -338,7 +341,7 @@ globle void NetworkAssert(
 /*   Performs a faster evaluation for join expressions */
 /*   than if EvaluateExpression was used directly.     */
 /*******************************************************/
-globle BOOLEAN EvaluateJoinExpression(
+globle intBool EvaluateJoinExpression(
   void *theEnv,
   struct expr *joinExpr,
   struct partialMatch *lbinds,
@@ -501,7 +504,7 @@ globle BOOLEAN EvaluateJoinExpression(
             return(FALSE);
            }
 
-         if ((theResult.value == SymbolData(theEnv)->FalseSymbol) && (theResult.type == SYMBOL))
+         if ((theResult.value == EnvFalseSymbol(theEnv)) && (theResult.type == SYMBOL))
            { result = FALSE; }
          else
            { result = TRUE; }
@@ -676,13 +679,13 @@ static void PNRDrive(
    if (listOfJoins != NULL)
      {
       if (((struct joinNode *) (listOfJoins->rightSideEntryStructure)) == join)
-        { NegEntryRetract(theEnv,listOfJoins,lhsBinds,FALSE); }
+        { NegEntryRetract(theEnv,listOfJoins,lhsBinds,NULL); }
       else while (listOfJoins != NULL)
         {
 
          PosEntryRetract(theEnv,listOfJoins,
                          lhsBinds->binds[lhsBinds->bcount - 1].gm.theMatch,
-                         lhsBinds,(int) join->depth-1,FALSE);
+                         lhsBinds,(int) join->depth-1,NULL);
          listOfJoins = listOfJoins->rightDriveNode;
         }
      }
@@ -691,9 +694,7 @@ static void PNRDrive(
    /* Remove any logical dependency links associated with this partial match. */
    /*=========================================================================*/
 
-#if LOGICAL_DEPENDENCIES
    if (lhsBinds->dependentsf) RemoveLogicalSupport(theEnv,lhsBinds);
-#endif
 
    /*========================================*/
    /* Put the pseudo-fact on a garbage list. */
