@@ -1,10 +1,27 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*              CLIPS Version 6.20  01/31/02           */
+   /*              CLIPS Version 6.24  06/05/06           */
    /*                                                     */
    /*                                                     */
    /*******************************************************/
+   
+/*************************************************************/
+/* Purpose:                                                  */
+/*                                                           */
+/* Principal Programmer(s):                                  */
+/*                                                           */
+/* Contributing Programmer(s):                               */
+/*                                                           */
+/* Revision History:                                         */
+/*      6.23: Changed name of variable log to logName        */
+/*            because of Unix compiler warnings of shadowed  */
+/*            definitions.                                   */
+/*                                                           */
+/*      6.24: Corrected code generating compilation          */
+/*            warnings.                                      */
+/*                                                           */
+/*************************************************************/
 
 /*
  * This file contains the command processing functions for a number of
@@ -44,8 +61,10 @@ extern  short   iochan;                          /* In "termio.c"        */
 #endif
 
 #if     UNIX_7 || UNIX_V
+/*
 extern void sleep(int);
-
+*/
+#include        <unistd.h>
 #include        <signal.h>
 #endif
 
@@ -362,12 +381,12 @@ globle int buffer_ungetc(
 
 globle int query_cmp(
   void *theEnv,
-  char *log)
+  char *logName)
 {
-   if((strcmp(log,"wdialog") == 0) ||
-      (strcmp(log,"wtrace")  == 0) ||
-      (strcmp(log,"wwarning")  == 0) ||
-      (strcmp(log,"werror")  == 0))
+   if((strcmp(logName,"wdialog") == 0) ||
+      (strcmp(logName,"wtrace")  == 0) ||
+      (strcmp(logName,"wwarning")  == 0) ||
+      (strcmp(logName,"werror")  == 0))
        return(TRUE);
    else
        return(FALSE);
@@ -375,7 +394,7 @@ globle int query_cmp(
 
 globle int print_cmp(
   void *theEnv,
-  char *log, 
+  char *logName, 
   char *str)
   {
    register int i;
@@ -1546,7 +1565,8 @@ globle int lreplace(
   void *theEnv,
   char *pat2)
 {
-      int doto,i;
+      int doto;
+      unsigned i;
       char *cp1,*cp2;
       LINE *lp1,*lp2;
       WINDOW *wp;
