@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*             EXPRESSION OPERATIONS MODULE            */
    /*******************************************************/
@@ -18,6 +18,8 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
 /*************************************************************/
 
 #define _EXPRNOPS_SOURCE_
@@ -129,7 +131,7 @@ globle int CheckArgumentAgainstRestriction(
 /* ConstantExpression: Returns TRUE if the expression */
 /*   is a constant, otherwise FALSE.                  */
 /************************************************************/
-globle BOOLEAN ConstantExpression(
+globle intBool ConstantExpression(
   struct expr *testPtr)
   {
    while (testPtr != NULL)
@@ -150,7 +152,7 @@ globle BOOLEAN ConstantExpression(
 /* ConstantType: Returns TRUE if the type */
 /*   is a constant, otherwise FALSE.      */
 /************************************************/
-globle BOOLEAN ConstantType(
+globle intBool ConstantType(
   int theType)
   {
    switch (theType)
@@ -173,7 +175,7 @@ globle BOOLEAN ConstantType(
 /* IdenticalExpression: Determines if two expressions are identical. Returns */
 /*   TRUE if the expressions are identical, otherwise FALSE is returned.     */
 /*****************************************************************************/
-globle BOOLEAN IdenticalExpression(
+globle intBool IdenticalExpression(
   struct expr *firstList,
   struct expr *secondList)
   {
@@ -273,9 +275,9 @@ globle struct expr *CopyExpression(
 /*   contains any variables. Returns TRUE if the expression */
 /*   contains any variables, otherwise FALSE is returned.   */
 /************************************************************/
-globle BOOLEAN ExpressionContainsVariables(
+globle intBool ExpressionContainsVariables(
   struct expr *theExpression,
-  BOOLEAN globalsAreVariables)
+  intBool globalsAreVariables)
   {
    while (theExpression != NULL)
      {
