@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*              EXPRESSION PARSER MODULE               */
    /*******************************************************/
@@ -16,6 +16,11 @@
 /*      Brian L. Donnell                                     */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Changed name of variable exp to theExp         */
+/*            because of Unix compiler warnings of shadowed  */
+/*            definitions.                                   */
+/*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
 /*                                                           */
 /*************************************************************/
 
@@ -294,14 +299,14 @@ globle struct expr *Function2Parse(
                    refernce (i.e. ? instead of $? - the $ is
                    being treated as a special expansion operator)
  **********************************************************************/
-globle BOOLEAN ReplaceSequenceExpansionOps(
+globle intBool ReplaceSequenceExpansionOps(
   void *theEnv,
   EXPRESSION *actions,
   EXPRESSION *fcallexp,
   void *expcall,
   void *expmult)
   {
-   EXPRESSION *exp;
+   EXPRESSION *theExp;
 
    while (actions != NULL)
      {
@@ -322,19 +327,19 @@ globle BOOLEAN ReplaceSequenceExpansionOps(
            }
          if (fcallexp->value != expcall)
            {
-            exp = GenConstant(theEnv,fcallexp->type,fcallexp->value);
-            exp->argList = fcallexp->argList;
-            exp->nextArg = NULL;
+            theExp = GenConstant(theEnv,fcallexp->type,fcallexp->value);
+            theExp->argList = fcallexp->argList;
+            theExp->nextArg = NULL;
             fcallexp->type = FCALL;
             fcallexp->value = expcall;
-            fcallexp->argList = exp;
+            fcallexp->argList = theExp;
            }
          if (actions->value != expmult)
            {
-            exp = GenConstant(theEnv,SF_VARIABLE,actions->value);
+            theExp = GenConstant(theEnv,SF_VARIABLE,actions->value);
             if (actions->type == MF_GBL_VARIABLE)
-              exp->type = GBL_VARIABLE;
-            actions->argList = exp;
+              theExp->type = GBL_VARIABLE;
+            actions->argList = theExp;
             actions->type = FCALL;
             actions->value = expmult;
            }
@@ -344,10 +349,10 @@ globle BOOLEAN ReplaceSequenceExpansionOps(
          if ((actions->type == GCALL) ||
              (actions->type == PCALL) ||
              (actions->type == FCALL))
-           exp = actions;
+           theExp = actions;
          else
-           exp = fcallexp;
-         if (ReplaceSequenceExpansionOps(theEnv,actions->argList,exp,expcall,expmult))
+           theExp = fcallexp;
+         if (ReplaceSequenceExpansionOps(theEnv,actions->argList,theExp,expcall,expmult))
            return(TRUE);
         }
       actions = actions->nextArg;
@@ -801,7 +806,7 @@ globle struct expr *GroupActions(
 /* EnvSetSequenceOperatorRecognition: C access routine  */
 /*   for the set-sequence-operator-recognition function */
 /********************************************************/
-globle BOOLEAN EnvSetSequenceOperatorRecognition(
+globle intBool EnvSetSequenceOperatorRecognition(
   void *theEnv,
   int value)
   {
@@ -816,7 +821,7 @@ globle BOOLEAN EnvSetSequenceOperatorRecognition(
 /* EnvSetSequenceOperatorRecognition: C access routine  */
 /*   for the Get-sequence-operator-recognition function */
 /********************************************************/
-globle BOOLEAN EnvGetSequenceOperatorRecognition(
+globle intBool EnvGetSequenceOperatorRecognition(
   void *theEnv)
   {
    return(ExpressionData(theEnv)->SequenceOpMode);
