@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.21  06/15/03            */
+   /*             CLIPS Version 6.24  06/02/06            */
    /*                                                     */
    /*               EXTERNAL FUNCTION MODULE              */
    /*******************************************************/
@@ -18,6 +18,9 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Corrected code to remove run-time program      */
+/*            compiler warning.                              */
+/*                                                           */
 /*************************************************************/
 
 #define _EXTNFUNC_SOURCE_
@@ -41,8 +44,10 @@
 
    static void                    AddHashFunction(void *,struct FunctionDefinition *);
    static void                    InitializeFunctionHashTable(void *);
-   static int                     RemoveHashFunction(void *,struct FunctionDefinition *);
    static void                    DeallocateExternalFunctionData(void *);
+#if (! RUN_TIME)
+   static int                     RemoveHashFunction(void *,struct FunctionDefinition *);
+#endif
 
 /*********************************************************/
 /* InitializeExternalFunctionData: Allocates environment */
@@ -199,7 +204,7 @@ globle int DefineFunction3(
   int (*pointer)(void *),
   char *actualName,
   char *restrictions,
-  BOOLEAN environmentAware)
+  intBool environmentAware)
   {
    struct FunctionDefinition *newFunction;
 
@@ -295,6 +300,40 @@ globle int UndefineFunction(
    return(FALSE);
   }
 
+/******************************************/
+/* RemoveHashFunction: Removes a function */
+/*   from the function hash table.        */
+/******************************************/
+static int RemoveHashFunction(
+  void *theEnv,
+  struct FunctionDefinition *fdPtr)
+  {
+   struct FunctionHash *fhPtr, *lastPtr = NULL;
+   unsigned hashValue;
+
+   hashValue = HashSymbol(ValueToString(fdPtr->callFunctionName),SIZE_FUNCTION_HASH);
+
+   for (fhPtr = ExternalFunctionData(theEnv)->FunctionHashtable[hashValue];
+        fhPtr != NULL;
+        fhPtr = fhPtr->next)
+     {
+      if (fhPtr->fdPtr == fdPtr)
+        {
+         if (lastPtr == NULL)
+           { ExternalFunctionData(theEnv)->FunctionHashtable[hashValue] = fhPtr->next; }
+         else
+           { lastPtr->next = fhPtr->next; }
+
+         rtn_struct(theEnv,FunctionHash,fhPtr);
+         return(TRUE);
+        }
+
+      lastPtr = fhPtr;
+     }
+
+   return(FALSE);
+  }
+
 /***************************************************************************/
 /* AddFunctionParser: Associates a specialized expression parsing function */
 /*   with the function entry for a function which was defined using        */
@@ -609,40 +648,6 @@ static void AddHashFunction(
    newhash->next = temp;
   }
 
-/******************************************/
-/* RemoveHashFunction: Removes a function */
-/*   from the function hash table.        */
-/******************************************/
-static int RemoveHashFunction(
-  void *theEnv,
-  struct FunctionDefinition *fdPtr)
-  {
-   struct FunctionHash *fhPtr, *lastPtr = NULL;
-   unsigned hashValue;
-
-   hashValue = HashSymbol(ValueToString(fdPtr->callFunctionName),SIZE_FUNCTION_HASH);
-
-   for (fhPtr = ExternalFunctionData(theEnv)->FunctionHashtable[hashValue];
-        fhPtr != NULL;
-        fhPtr = fhPtr->next)
-     {
-      if (fhPtr->fdPtr == fdPtr)
-        {
-         if (lastPtr == NULL)
-           { ExternalFunctionData(theEnv)->FunctionHashtable[hashValue] = fhPtr->next; }
-         else
-           { lastPtr->next = fhPtr->next; }
-
-         rtn_struct(theEnv,FunctionHash,fhPtr);
-         return(TRUE);
-        }
-
-      lastPtr = fhPtr;
-     }
-
-   return(FALSE);
-  }
-
 /*************************************************/
 /* GetMinimumArgs: Returns the minimum number of */
 /*   arguments expected by an external function. */
