@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  05/17/06            */
    /*                                                     */
    /*                 FACT MATCH MODULE                   */
    /*******************************************************/
@@ -16,6 +16,11 @@
 /* Contributing Programmer(s):                               */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Correction for FalseSymbol/TrueSymbol. DR0859  */
+/*                                                           */
+/*      6.24: Removed INCREMENTAL_RESET compilation flag.    */
+/*                                                           */
+/*            Renamed BOOLEAN macro type to intBool.         */
 /*                                                           */
 /*************************************************************/
 
@@ -34,9 +39,7 @@
 #include "extnfunc.h"
 #include "factgen.h"
 #include "factrete.h"
-#if INCREMENTAL_RESET
 #include "incrrset.h"
-#endif
 #include "memalloc.h"
 #include "reteutil.h"
 #include "router.h"
@@ -48,7 +51,7 @@
 /* LOCAL INTERNAL FUNCTION DEFINITIONS */
 /***************************************/
 
-   static BOOLEAN                  EvaluatePatternExpression(void *,struct factPatternNode *,struct expr *,int);
+   static intBool                  EvaluatePatternExpression(void *,struct factPatternNode *,struct expr *,int);
    static void                     TraceErrorToJoin(void *,struct factPatternNode *,int);
    static void                     ProcessFactAlphaMatch(void *,struct fact *,struct multifieldMarker *,struct factPatternNode *);
    static struct factPatternNode  *GetNextFactPatternNode(void *,int,struct factPatternNode *);
@@ -587,7 +590,7 @@ static int EvaluatePatternExpression(
       return(FALSE);
      }
 
-   if ((theResult.value == SymbolData(theEnv)->FalseSymbol) && (theResult.type == SYMBOL))
+   if ((theResult.value == EnvFalseSymbol(theEnv)) && (theResult.type == SYMBOL))
      { return(FALSE); }
 
    return(TRUE);
@@ -618,7 +621,7 @@ static void PatternNetErrorMessage(
    PrintErrorID(theEnv,"FACTMCH",1,TRUE);
    EnvPrintRouter(theEnv,WERROR,"This error occurred in the fact pattern network\n");
    EnvPrintRouter(theEnv,WERROR,"   Currently active fact: ");
-   PrintFact(theEnv,WERROR,FactData(theEnv)->CurrentPatternFact);
+   PrintFact(theEnv,WERROR,FactData(theEnv)->CurrentPatternFact,FALSE,FALSE);
    EnvPrintRouter(theEnv,WERROR,"\n");
 
    /*==============================================*/
@@ -695,11 +698,11 @@ static int SkipFactPatternNode(
   void *theEnv,
   struct factPatternNode *thePattern)
   {
-#if (MAC_MPW || MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY || (! INCREMENTAL_RESET))
+#if (MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY)
 #pragma unused(theEnv,thePattern)
 #endif
 
-#if INCREMENTAL_RESET && (! RUN_TIME) && (! BLOAD_ONLY)
+#if (! RUN_TIME) && (! BLOAD_ONLY)
    if (EngineData(theEnv)->IncrementalResetInProgress &&
        (thePattern->header.initialize == FALSE))
      { return(TRUE); }
@@ -708,8 +711,6 @@ static int SkipFactPatternNode(
    return(FALSE);
   }
 
-#if INCREMENTAL_RESET
-
 /***************************************************************/
 /* MarkFactPatternForIncrementalReset: Sets the initialization */
 /*  field of a fact pattern for use with incremental reset.    */
@@ -728,7 +729,7 @@ globle void MarkFactPatternForIncrementalReset(
   int value)
   {
    struct factPatternNode *patternPtr = (struct factPatternNode *) thePattern;
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 
@@ -780,7 +781,5 @@ globle void FactsIncrementalReset(
      }
   }
 
-#endif /* INCREMENTAL_RESET */
-
 #endif /* DEFTEMPLATE_CONSTRUCT && DEFRULE_CONSTRUCT */
 
