@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  05/17/06            */
    /*                                                     */
    /*          FACT RETE ACCESS FUNCTIONS MODULE          */
    /*******************************************************/
@@ -15,6 +15,11 @@
 /* Contributing Programmer(s):                               */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Correction for FalseSymbol/TrueSymbol. DR0859  */
+/*                                                           */
+/*      6.24: Removed INCREMENTAL_RESET compilation flag.    */
+/*                                                           */
+/*            Renamed BOOLEAN macro type to intBool.         */
 /*                                                           */
 /*************************************************************/
 
@@ -30,9 +35,7 @@
 #include "memalloc.h"
 #include "extnfunc.h"
 #include "router.h"
-#if INCREMENTAL_RESET
 #include "incrrset.h"
-#endif
 #include "reteutil.h"
 #include "drive.h"
 #include "engine.h"
@@ -46,7 +49,7 @@
 /* FactPNGetVar1: Fact pattern network function for extracting */
 /*   a variable's value. This is the most generalized routine. */
 /***************************************************************/
-globle BOOLEAN FactPNGetVar1(
+globle intBool FactPNGetVar1(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR returnValue)
@@ -157,7 +160,7 @@ globle BOOLEAN FactPNGetVar1(
 /*   for extracting a variable's value. The value */
 /*   extracted is from a single field slot.       */
 /**************************************************/
-globle BOOLEAN FactPNGetVar2(
+globle intBool FactPNGetVar2(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR returnValue)
@@ -195,7 +198,7 @@ globle BOOLEAN FactPNGetVar2(
 /*   variable's value. The value extracted is from a multifield  */
 /*   slot that contains at most one multifield variable.         */
 /*****************************************************************/
-globle BOOLEAN FactPNGetVar3(
+globle intBool FactPNGetVar3(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR returnValue)
@@ -260,12 +263,12 @@ globle BOOLEAN FactPNGetVar3(
 #if IBM_TBC
 #pragma argsused
 #endif
-globle BOOLEAN FactPNConstant1(
+globle intBool FactPNConstant1(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR returnValue)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(returnValue)
 #endif
    struct factConstantPN1Call *hack;
@@ -304,12 +307,12 @@ globle BOOLEAN FactPNConstant1(
 #if IBM_TBC
 #pragma argsused
 #endif
-globle BOOLEAN FactPNConstant2(
+globle intBool FactPNConstant2(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR returnValue)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(returnValue)
 #endif
    struct factConstantPN2Call *hack;
@@ -359,7 +362,7 @@ globle BOOLEAN FactPNConstant2(
 /* FactJNGetVar1: Fact join network function for extracting a */
 /*   variable's value. This is the most generalized routine.  */
 /**************************************************************/
-globle BOOLEAN FactJNGetVar1(
+globle intBool FactJNGetVar1(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR returnValue)
@@ -490,7 +493,7 @@ globle BOOLEAN FactJNGetVar1(
 /*   extracting a variable's value. The value    */
 /*   extracted is from a single field slot.      */
 /*************************************************/
-globle BOOLEAN FactJNGetVar2(
+globle intBool FactJNGetVar2(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR returnValue)
@@ -533,7 +536,7 @@ globle BOOLEAN FactJNGetVar2(
 /*   variable's value. The value extracted is from a multifield */
 /*   slot that contains at most one multifield variable.        */
 /****************************************************************/
-globle BOOLEAN FactJNGetVar3(
+globle intBool FactJNGetVar3(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR returnValue)
@@ -599,7 +602,7 @@ globle BOOLEAN FactJNGetVar3(
 /* FactSlotLength: Determines if the length of a    */
 /*  multifield slot falls within a specified range. */
 /****************************************************/
-globle BOOLEAN FactSlotLength(
+globle intBool FactSlotLength(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR returnValue)
@@ -610,7 +613,7 @@ globle BOOLEAN FactSlotLength(
    struct multifieldMarker *tempMark;
 
    returnValue->type = SYMBOL;
-   returnValue->value = SymbolData(theEnv)->FalseSymbol;
+   returnValue->value = EnvFalseSymbol(theEnv);
 
    hack = (struct factCheckLengthPNCall *) ValueToBitMap(theValue);
 
@@ -630,7 +633,7 @@ globle BOOLEAN FactSlotLength(
    if (hack->exactly && (segmentPtr->multifieldLength > (unsigned) (hack->minLength + extraOffset)))
      { return(FALSE); }
 
-   returnValue->value = SymbolData(theEnv)->TrueSymbol;
+   returnValue->value = EnvTrueSymbol(theEnv);
    return(TRUE);
   }
 
@@ -646,7 +649,7 @@ globle int FactJNCompVars1(
   void *theValue,
   DATA_OBJECT *theResult)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theResult)
 #endif
    int p1, e1, p2, e2;
@@ -705,7 +708,7 @@ globle int FactJNCompVars2(
   void *theValue,
   DATA_OBJECT *theResult)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theResult)
 #endif
    int p1, s1, p2, s2;
@@ -806,8 +809,8 @@ globle int FactPNCompVars1(
    else rv = (int) hack->pass;
 
    theResult->type = SYMBOL;
-   if (rv) theResult->value = SymbolData(theEnv)->TrueSymbol;
-   else theResult->value = SymbolData(theEnv)->FalseSymbol;
+   if (rv) theResult->value = EnvTrueSymbol(theEnv);
+   else theResult->value = EnvFalseSymbol(theEnv);
 
    return(rv);
   }
@@ -839,7 +842,7 @@ globle unsigned short AdjustFieldPosition(
   int *extent)
   {
    unsigned short actualIndex;
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 
@@ -904,7 +907,7 @@ globle int FactStoreMultifield(
   void *theValue,
   DATA_OBJECT *theResult)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theValue)
 #endif
 
