@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*               CLIPS Version 6.20  01/31/02          */
+   /*             CLIPS Version 6.24  05/17/06            */
    /*                                                     */
    /*                                                     */
    /*******************************************************/
@@ -15,6 +15,9 @@
 /* Contributing Programmer(s):                               */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Correction for FalseSymbol/TrueSymbol. DR0859  */
+/*                                                           */
+/*      6.24: Removed IMPERATIVE_METHODS compilation flag.   */
 /*                                                           */
 /*************************************************************/
 
@@ -123,7 +126,7 @@ globle void GenericDispatch(
 #endif
 
    result->type = SYMBOL;
-   result->value = SymbolData(theEnv)->FalseSymbol;
+   result->value = EnvFalseSymbol(theEnv);
    EvaluationData(theEnv)->EvaluationError = FALSE;
    if (EvaluationData(theEnv)->HaltExecution)
      return;
@@ -260,7 +263,7 @@ globle void UnboundMethodErr(
   SIDE EFFECTS : Any query functions are evaluated
   NOTES        : Uses globals ProcParamArraySize and ProcParamArray
  ***********************************************************************/
-globle BOOLEAN IsMethodApplicable(
+globle intBool IsMethodApplicable(
   void *theEnv,
   DEFMETHOD *meth)
   {
@@ -327,7 +330,7 @@ globle BOOLEAN IsMethodApplicable(
          DefgenericData(theEnv)->GenericCurrentArgument = &ProceduralPrimitiveData(theEnv)->ProcParamArray[i];
          EvaluateExpression(theEnv,rp->query,&temp);
          if ((temp.type != SYMBOL) ? FALSE :
-             (temp.value == SymbolData(theEnv)->FalseSymbol))
+             (temp.value == EnvFalseSymbol(theEnv)))
            return(FALSE);
         }
       if (((int) k) != meth->restrictionCount-1)
@@ -336,8 +339,6 @@ globle BOOLEAN IsMethodApplicable(
    return(TRUE);
   }
 
-#if IMPERATIVE_METHODS
-
 /***************************************************
   NAME         : NextMethodP
   DESCRIPTION  : Determines if a shadowed generic
@@ -386,7 +387,7 @@ globle void CallNextMethod(
 #endif
 
    result->type = SYMBOL;
-   result->value = SymbolData(theEnv)->FalseSymbol;
+   result->value = EnvFalseSymbol(theEnv);
    if (EvaluationData(theEnv)->HaltExecution)
      return;
    oldMethod = DefgenericData(theEnv)->CurrentMethod;
@@ -462,7 +463,7 @@ globle void CallSpecificMethod(
    int mi;
 
    result->type = SYMBOL;
-   result->value = SymbolData(theEnv)->FalseSymbol;
+   result->value = EnvFalseSymbol(theEnv);
    if (EnvArgTypeCheck(theEnv,"call-specific-method",1,SYMBOL,&temp) == FALSE)
      return;
    gfunc = CheckGenericExists(theEnv,"call-specific-method",DOToString(temp));
@@ -493,7 +494,7 @@ globle void OverrideNextMethod(
   DATA_OBJECT *result)
   {
    result->type = SYMBOL;
-   result->value = SymbolData(theEnv)->FalseSymbol;
+   result->value = EnvFalseSymbol(theEnv);
    if (EvaluationData(theEnv)->HaltExecution)
      return;
    if (DefgenericData(theEnv)->CurrentMethod == NULL)
@@ -507,8 +508,6 @@ globle void OverrideNextMethod(
                    GetFirstArgument(),result);
   }
 
-#endif /* IMPERATIVE_METHODS */
-
 /***********************************************************
   NAME         : GetGenericCurrentArgument
   DESCRIPTION  : Returns the value of the generic function
