@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*                  DEFGLOBAL MODULE                   */
    /*******************************************************/
@@ -17,6 +17,12 @@
 /*      Brian L. Donnell                                     */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Correction for FalseSymbol/TrueSymbol. DR0859  */
+/*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Corrected code to remove run-time program      */
+/*            compiler warning.                              */
 /*                                                           */
 /*************************************************************/
 
@@ -61,7 +67,7 @@
    static void                    ReturnModule(void *,void *);
    static void                    ReturnDefglobal(void *,void *);
    static void                    InitializeDefglobalModules(void *);
-   static BOOLEAN                 GetDefglobalValue2(void *,void *,DATA_OBJECT_PTR);
+   static intBool                 GetDefglobalValue2(void *,void *,DATA_OBJECT_PTR);
    static void                    IncrementDefglobalBusyCount(void *,void *);
    static void                    DecrementDefglobalBusyCount(void *,void *);
    static void                    DeallocateDefglobalData(void *);
@@ -156,7 +162,7 @@ static void DestroyDefglobalAction(
   struct constructHeader *theConstruct,
   void *buffer)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(buffer)
 #endif
 #if (! BLOAD_ONLY)
@@ -166,7 +172,7 @@ static void DestroyDefglobalAction(
 
    DestroyDefglobal(theEnv,theDefglobal);
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv,theConstruct)
 #endif
 #endif
@@ -258,31 +264,16 @@ globle void *EnvGetNextDefglobal(
 /* EnvIsDefglobalDeletable: Returns TRUE if a particular */
 /*   defglobal can be deleted, otherwise returns FALSE.  */
 /*********************************************************/
-#if IBM_TBC
-#pragma argsused
-#endif
-globle BOOLEAN EnvIsDefglobalDeletable(
+globle intBool EnvIsDefglobalDeletable(
   void *theEnv,
   void *ptr)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
-#pragma unused(ptr)
-#endif
-#if BLOAD_ONLY || RUN_TIME
-#if MAC_MPW || MAC_MCW || IBM_MCW
-#pragma unused(theEnv)
-#endif
-   return(FALSE);
-#else
-#if BLOAD || BLOAD_AND_BSAVE
-
-   if (Bloaded(theEnv)) return(FALSE);
-#endif
+   if (! ConstructsDeletable(theEnv))
+     { return FALSE; }
 
    if (((struct defglobal *) ptr)->busyCount) return(FALSE);
 
    return(TRUE);
-#endif
   }
 
 /************************************************************/
@@ -293,7 +284,7 @@ static void ReturnDefglobal(
   void *theEnv,
   void *vTheDefglobal)
   {
-#if (MAC_MPW || MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY)
+#if (MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY)
 #pragma unused(theEnv,vTheDefglobal)
 #endif
    
@@ -347,7 +338,7 @@ static void DestroyDefglobal(
   void *theEnv,
   void *vTheDefglobal)
   {
-#if (MAC_MPW || MAC_MCW || IBM_MCW) && BLOAD_ONLY
+#if (MAC_MCW || IBM_MCW) && BLOAD_ONLY
 #pragma unused(theEnv,vTheDefglobal)
 #endif
    
@@ -403,7 +394,7 @@ globle void QSetDefglobalValue(
       if (EvaluationData(theEnv)->EvaluationError)
         {
          vPtr->type = SYMBOL;
-         vPtr->value = SymbolData(theEnv)->FalseSymbol;
+         vPtr->value = EnvFalseSymbol(theEnv);
         }
      }
 
@@ -518,7 +509,7 @@ globle void EnvSetGlobalsChanged(
 /* GetDefglobalValue2: Returns the value of the specified */
 /*   global variable in the supplied DATA_OBJECT.         */
 /**********************************************************/
-static BOOLEAN GetDefglobalValue2(
+static intBool GetDefglobalValue2(
   void *theEnv,
   void *theValue,
   DATA_OBJECT_PTR vPtr)
@@ -546,7 +537,7 @@ static BOOLEAN GetDefglobalValue2(
       EnvPrintRouter(theEnv,WERROR,ValueToString(theValue));
       EnvPrintRouter(theEnv,WERROR,"* is unbound.\n");
       vPtr->type = SYMBOL;
-      vPtr->value = SymbolData(theEnv)->FalseSymbol;
+      vPtr->value = EnvFalseSymbol(theEnv);
       SetEvaluationError(theEnv,TRUE);
       return(FALSE);
      }
@@ -561,7 +552,7 @@ static BOOLEAN GetDefglobalValue2(
      {
       AmbiguousReferenceErrorMessage(theEnv,"defglobal",ValueToString(theValue));
       vPtr->type = SYMBOL;
-      vPtr->value = SymbolData(theEnv)->FalseSymbol;
+      vPtr->value = EnvFalseSymbol(theEnv);
       SetEvaluationError(theEnv,TRUE);
       return(FALSE);
      }
@@ -615,7 +606,7 @@ globle int QGetDefglobalValue(
 /* EnvGetDefglobalValue: Returns the value of the specified */
 /*   global variable in the supplied DATA_OBJECT.           */
 /************************************************************/
-globle BOOLEAN EnvGetDefglobalValue(
+globle intBool EnvGetDefglobalValue(
   void *theEnv,
   char *variableName,
   DATA_OBJECT_PTR vPtr)
@@ -634,7 +625,7 @@ globle BOOLEAN EnvGetDefglobalValue(
 /* EnvSetDefglobalValue: Sets the value of the specified global */
 /*   variable to the value stored in the supplied DATA_OBJECT.  */
 /****************************************************************/
-globle BOOLEAN EnvSetDefglobalValue(
+globle intBool EnvSetDefglobalValue(
   void *theEnv,
   char *variableName,
   DATA_OBJECT_PTR vPtr)
@@ -674,7 +665,7 @@ static void IncrementDefglobalBusyCount(
   void *vTheGlobal)
   {
    struct defglobal *theGlobal = (struct defglobal *) vTheGlobal;
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 
