@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*               CLIPS Version 6.20  01/31/02          */
+   /*               CLIPS Version 6.24  05/17/06          */
    /*                                                     */
    /*                  OBJECT MESSAGE FUNCTIONS           */
    /*******************************************************/
@@ -15,6 +15,14 @@
 /* Contributing Programmer(s):                               */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Changed name of variable log to logName        */
+/*            because of Unix compiler warnings of shadowed  */
+/*            definitions.                                   */
+/*                                                           */
+/*      6.24: Removed IMPERATIVE_MESSAGE_HANDLERS and        */
+/*            AUXILIARY_MESSAGE_HANDLERS compilation flags.  */
+/*                                                           */
+/*            Renamed BOOLEAN macro type to intBool.         */
 /*                                                           */
 /*************************************************************/
 
@@ -145,7 +153,7 @@ globle int CheckHandlerArgCount(
 globle void SlotAccessViolationError(
   void *theEnv,
   char *slotName,
-  BOOLEAN instanceFlag,
+  intBool instanceFlag,
   void *theInstanceOrClass)
   {
    PrintErrorID(theEnv,"MSGFUN",3,FALSE);
@@ -549,14 +557,6 @@ globle unsigned HandlerType(
    for (i = MAROUND ; i <= MAFTER ; i++)
      if (strcmp(str,MessageHandlerData(theEnv)->hndquals[i]) == 0)
        {
-#if ! IMPERATIVE_MESSAGE_HANDLERS
-        if (i == MAROUND)
-          break;
-#endif
-#if ! AUXILIARY_MESSAGE_HANDLERS
-        if ((i == MBEFORE) || (i == MAFTER))
-          break;
-#endif
         return(i);
        }
 
@@ -626,15 +626,15 @@ globle int CheckCurrentMessage(
  ***************************************************/
 globle void PrintHandler(
   void *theEnv,
-  char *log,
+  char *logName,
   HANDLER *theHandler,
   int crtn)
   {
-   EnvPrintRouter(theEnv,log,ValueToString(theHandler->name));
-   EnvPrintRouter(theEnv,log," ");
-   EnvPrintRouter(theEnv,log,MessageHandlerData(theEnv)->hndquals[theHandler->type]);
-   EnvPrintRouter(theEnv,log," in class ");
-   PrintClassName(theEnv,log,theHandler->cls,crtn);
+   EnvPrintRouter(theEnv,logName,ValueToString(theHandler->name));
+   EnvPrintRouter(theEnv,logName," ");
+   EnvPrintRouter(theEnv,logName,MessageHandlerData(theEnv)->hndquals[theHandler->type]);
+   EnvPrintRouter(theEnv,logName," in class ");
+   PrintClassName(theEnv,logName,theHandler->cls,crtn);
   }
 
 /***********************************************************
@@ -819,7 +819,6 @@ globle void DisplayCore(
   HANDLER_LINK *core,
   int sdepth)
   {
-#if IMPERATIVE_MESSAGE_HANDLERS
    if (core->hnd->type == MAROUND)
      {
       PrintPreviewHandler(theEnv,logicalName,core,sdepth,BEGIN_TRACE);
@@ -828,9 +827,7 @@ globle void DisplayCore(
       PrintPreviewHandler(theEnv,logicalName,core,sdepth,END_TRACE);
      }
    else
-#endif
      {
-#if AUXILIARY_MESSAGE_HANDLERS
       while ((core != NULL) ? (core->hnd->type == MBEFORE) : FALSE)
         {
          PrintPreviewHandler(theEnv,logicalName,core,sdepth,BEGIN_TRACE);
@@ -838,16 +835,16 @@ globle void DisplayCore(
          core = core->nxt;
         }
       if ((core != NULL) ? (core->hnd->type == MPRIMARY) : FALSE)
-#endif
+
         core = DisplayPrimaryCore(theEnv,logicalName,core,sdepth);
-#if AUXILIARY_MESSAGE_HANDLERS
+
       while ((core != NULL) ? (core->hnd->type == MAFTER) : FALSE)
         {
          PrintPreviewHandler(theEnv,logicalName,core,sdepth,BEGIN_TRACE);
          PrintPreviewHandler(theEnv,logicalName,core,sdepth,END_TRACE);
          core = core->nxt;
         }
-#endif
+
      }
   }
 
@@ -891,16 +888,16 @@ globle HANDLER_LINK *FindPreviewApplicableHandlers(
  ***********************************************************/
 globle void WatchMessage(
   void *theEnv,
-  char *log,
+  char *logName,
   char *tstring)
   {
-   EnvPrintRouter(theEnv,log,"MSG ");
-   EnvPrintRouter(theEnv,log,tstring);
-   EnvPrintRouter(theEnv,log," ");
-   EnvPrintRouter(theEnv,log,ValueToString(MessageHandlerData(theEnv)->CurrentMessageName));
-   EnvPrintRouter(theEnv,log," ED:");
-   PrintLongInteger(theEnv,log,(long) EvaluationData(theEnv)->CurrentEvaluationDepth);
-   PrintProcParamArray(theEnv,log);
+   EnvPrintRouter(theEnv,logName,"MSG ");
+   EnvPrintRouter(theEnv,logName,tstring);
+   EnvPrintRouter(theEnv,logName," ");
+   EnvPrintRouter(theEnv,logName,ValueToString(MessageHandlerData(theEnv)->CurrentMessageName));
+   EnvPrintRouter(theEnv,logName," ED:");
+   PrintLongInteger(theEnv,logName,(long) EvaluationData(theEnv)->CurrentEvaluationDepth);
+   PrintProcParamArray(theEnv,logName);
   }
 
 /***********************************************************
@@ -917,20 +914,20 @@ globle void WatchMessage(
  ***********************************************************/
 globle void WatchHandler(
   void *theEnv,
-  char *log,
+  char *logName,
   HANDLER_LINK *hndl,
   char *tstring)
   {
    HANDLER *hnd;
    
-   EnvPrintRouter(theEnv,log,"HND ");
-   EnvPrintRouter(theEnv,log,tstring);
-   EnvPrintRouter(theEnv,log," ");
+   EnvPrintRouter(theEnv,logName,"HND ");
+   EnvPrintRouter(theEnv,logName,tstring);
+   EnvPrintRouter(theEnv,logName," ");
    hnd = hndl->hnd;
    PrintHandler(theEnv,WTRACE,hnd,TRUE);
-   EnvPrintRouter(theEnv,log,"       ED:");
-   PrintLongInteger(theEnv,log,(long) EvaluationData(theEnv)->CurrentEvaluationDepth);
-   PrintProcParamArray(theEnv,log);
+   EnvPrintRouter(theEnv,logName,"       ED:");
+   PrintLongInteger(theEnv,logName,(long) EvaluationData(theEnv)->CurrentEvaluationDepth);
+   PrintProcParamArray(theEnv,logName);
   }
 
 #endif /* DEBUGGING_FUNCTIONS */
@@ -971,11 +968,9 @@ static HANDLER_LINK *DisplayPrimaryCore(
    register HANDLER_LINK *rtn;
 
    PrintPreviewHandler(theEnv,logicalName,core,pdepth,BEGIN_TRACE);
-#if IMPERATIVE_MESSAGE_HANDLERS
    if ((core->nxt != NULL) ? (core->nxt->hnd->type == MPRIMARY) : FALSE)
      rtn = DisplayPrimaryCore(theEnv,logicalName,core->nxt,pdepth+1);
    else
-#endif
      rtn = core->nxt;
    PrintPreviewHandler(theEnv,logicalName,core,pdepth,END_TRACE);
    return(rtn);
