@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*               CLIPS Version 6.21  06/15/03          */
+   /*               CLIPS Version 6.24  05/17/06          */
    /*                                                     */
    /*              OBJECT MESSAGE DISPATCH CODE           */
    /*******************************************************/
@@ -15,6 +15,12 @@
 /* Contributing Programmer(s):                               */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Correction for FalseSymbol/TrueSymbol. DR0859  */
+/*                                                           */
+/*      6.24: Removed IMPERATIVE_MESSAGE_HANDLERS and        */
+/*            AUXILIARY_MESSAGE_HANDLERS compilation flags.  */
+/*                                                           */
+/*            Renamed BOOLEAN macro type to intBool.         */
 /*                                                           */
 /*************************************************************/
 
@@ -137,7 +143,7 @@ globle void EnvSend(
 
    SetEvaluationError(theEnv,FALSE);
    result->type = SYMBOL;
-   result->value = SymbolData(theEnv)->FalseSymbol;
+   result->value = EnvFalseSymbol(theEnv);
    msym = FindSymbolHN(theEnv,msg);
    if (msym == NULL)
      {
@@ -200,7 +206,7 @@ globle void SendCommand(
    DATA_OBJECT temp;
 
    result->type = SYMBOL;
-   result->value = SymbolData(theEnv)->FalseSymbol;
+   result->value = EnvFalseSymbol(theEnv);
    if (EnvArgTypeCheck(theEnv,"send",2,SYMBOL,&temp) == FALSE)
      return;
    msg = (SYMBOL_HN *) temp.value;
@@ -236,8 +242,6 @@ globle DATA_OBJECT *GetNthMessageArgument(
    return(&ProceduralPrimitiveData(theEnv)->ProcParamArray[n]);
   }
 
-#if IMPERATIVE_MESSAGE_HANDLERS
-
 /*****************************************************
   NAME         : NextHandlerAvailable
   DESCRIPTION  : Determines if there the currently
@@ -296,7 +300,7 @@ globle void CallNextHandler(
 #endif
 
    SetpType(result,SYMBOL);
-   SetpValue(result,SymbolData(theEnv)->FalseSymbol);
+   SetpValue(result,EnvFalseSymbol(theEnv));
    EvaluationData(theEnv)->EvaluationError = FALSE;
    if (EvaluationData(theEnv)->HaltExecution)
      return;
@@ -401,8 +405,6 @@ globle void CallNextHandler(
    ProcedureFunctionData(theEnv)->ReturnFlag = FALSE;
   }
 
-#endif /* IMPERATIVE_MESSAGE_HANDLERS */
-
 /*************************************************************************
   NAME         : FindApplicableOfName
   DESCRIPTION  : Groups all handlers of all types of the specified
@@ -439,10 +441,7 @@ globle void FindApplicableOfName(
      {
       if (hnd[arr[i]].name != mname)
         break;
-#if ! IMPERATIVE_MESSAGE_HANDLERS
-      if ((hnd[arr[i]].type == MPRIMARY) && (tops[MPRIMARY] != NULL))
-        continue;
-#endif
+
       tmp = get_struct(theEnv,messageHandlerLink);
       hnd[arr[i]].busy++;
       IncrementDefclassBusyCount(theEnv,(void *) hnd[arr[i]].cls);
@@ -452,13 +451,13 @@ globle void FindApplicableOfName(
          tmp->nxt = NULL;
          tops[tmp->hnd->type] = bots[tmp->hnd->type] = tmp;
         }
-#if AUXILIARY_MESSAGE_HANDLERS
+
       else if (tmp->hnd->type == MAFTER)
         {
          tmp->nxt = tops[tmp->hnd->type];
          tops[tmp->hnd->type] = tmp;
         }
-#endif
+
       else
         {
          bots[tmp->hnd->type]->nxt = tmp;
@@ -499,25 +498,19 @@ globle HANDLER_LINK *JoinHandlerLinks(
 
    mlink = tops[MPRIMARY];
 
-#if AUXILIARY_MESSAGE_HANDLERS
    if (tops[MBEFORE] != NULL)
      {
       bots[MBEFORE]->nxt = mlink;
       mlink = tops[MBEFORE];
      }
-#endif
 
-#if IMPERATIVE_MESSAGE_HANDLERS
    if (tops[MAROUND] != NULL)
      {
       bots[MAROUND]->nxt = mlink;
       mlink = tops[MAROUND];
      }
-#endif
 
-#if AUXILIARY_MESSAGE_HANDLERS
    bots[MPRIMARY]->nxt = tops[MAFTER];
-#endif
 
    return(mlink);
   }
@@ -554,7 +547,7 @@ globle void PrintHandlerSlotGetFunction(
    sd = theDefclass->instanceTemplate[theDefclass->slotNameMap[theReference->slotID] - 1];
    EnvPrintRouter(theEnv,logicalName,ValueToString(sd->slotName->name));
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -587,7 +580,7 @@ globle void PrintHandlerSlotGetFunction(
                   no-inherit or the subclass
                   overrode the original slot)
  ***************************************************/
-globle BOOLEAN HandlerSlotGetFunction(
+globle intBool HandlerSlotGetFunction(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -606,7 +599,7 @@ globle BOOLEAN HandlerSlotGetFunction(
      {
       StaleInstanceAddress(theEnv,"for slot get",0);
       theResult->type = SYMBOL;
-      theResult->value = SymbolData(theEnv)->FalseSymbol;
+      theResult->value = EnvFalseSymbol(theEnv);
       SetEvaluationError(theEnv,TRUE);
       return(FALSE);
      }
@@ -640,7 +633,7 @@ globle BOOLEAN HandlerSlotGetFunction(
 HandlerGetError:
    EarlySlotBindError(theEnv,theInstance,theDefclass,theReference->slotID);
    theResult->type = SYMBOL;
-   theResult->value = SymbolData(theEnv)->FalseSymbol;
+   theResult->value = EnvFalseSymbol(theEnv);
    SetEvaluationError(theEnv,TRUE);
    return(FALSE);
   }
@@ -683,7 +676,7 @@ globle void PrintHandlerSlotPutFunction(
      }
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -716,7 +709,7 @@ globle void PrintHandlerSlotPutFunction(
                   no-inherit or the subclass
                   overrode the original slot)
  ***************************************************/
-globle BOOLEAN HandlerSlotPutFunction(
+globle intBool HandlerSlotPutFunction(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -736,7 +729,7 @@ globle BOOLEAN HandlerSlotPutFunction(
      {
       StaleInstanceAddress(theEnv,"for slot put",0);
       theResult->type = SYMBOL;
-      theResult->value = SymbolData(theEnv)->FalseSymbol;
+      theResult->value = EnvFalseSymbol(theEnv);
       SetEvaluationError(theEnv,TRUE);
       return(FALSE);
      }
@@ -780,7 +773,7 @@ globle BOOLEAN HandlerSlotPutFunction(
    if (GetFirstArgument())
      {
       if (EvaluateAndStoreInDataObject(theEnv,(int) sp->desc->multiple,
-                                       GetFirstArgument(),&theSetVal) == FALSE)
+                                       GetFirstArgument(),&theSetVal,TRUE) == FALSE)
          goto HandlerPutError2;
      }
    else
@@ -799,7 +792,7 @@ HandlerPutError:
 
 HandlerPutError2:
    theResult->type = SYMBOL;
-   theResult->value = SymbolData(theEnv)->FalseSymbol;
+   theResult->value = EnvFalseSymbol(theEnv);
    SetEvaluationError(theEnv,TRUE);
 
    return(FALSE);
@@ -823,7 +816,7 @@ globle void DynamicHandlerGetSlot(
    DATA_OBJECT temp;
 
    result->type = SYMBOL;
-   result->value = SymbolData(theEnv)->FalseSymbol;
+   result->value = EnvFalseSymbol(theEnv);
    if (CheckCurrentMessage(theEnv,"dynamic-get",TRUE) == FALSE)
      return;
    EvaluateExpression(theEnv,GetFirstArgument(),&temp);
@@ -875,7 +868,7 @@ globle void DynamicHandlerPutSlot(
    DATA_OBJECT temp;
 
    theResult->type = SYMBOL;
-   theResult->value = SymbolData(theEnv)->FalseSymbol;
+   theResult->value = EnvFalseSymbol(theEnv);
    if (CheckCurrentMessage(theEnv,"dynamic-put",TRUE) == FALSE)
      return;
    EvaluateExpression(theEnv,GetFirstArgument(),&temp);
@@ -910,7 +903,7 @@ globle void DynamicHandlerPutSlot(
    if (GetFirstArgument()->nextArg)
      {
       if (EvaluateAndStoreInDataObject(theEnv,(int) sp->desc->multiple,
-                        GetFirstArgument()->nextArg,&temp) == FALSE)
+                        GetFirstArgument()->nextArg,&temp,TRUE) == FALSE)
         return;
      }
    else
@@ -957,7 +950,7 @@ static void PerformMessage(
 #endif
 
    result->type = SYMBOL;
-   result->value = SymbolData(theEnv)->FalseSymbol;
+   result->value = EnvFalseSymbol(theEnv);
    EvaluationData(theEnv)->EvaluationError = FALSE;
    if (EvaluationData(theEnv)->HaltExecution)
      return;
@@ -1041,8 +1034,6 @@ static void PerformMessage(
       oldCurrent = MessageHandlerData(theEnv)->CurrentCore;
       oldNext = MessageHandlerData(theEnv)->NextInCore;
 
-#if IMPERATIVE_MESSAGE_HANDLERS
-
       if (MessageHandlerData(theEnv)->TopOfCore->hnd->type == MAROUND)
         {
          MessageHandlerData(theEnv)->CurrentCore = MessageHandlerData(theEnv)->TopOfCore;
@@ -1081,9 +1072,6 @@ static void PerformMessage(
 #endif
         }
       else
-
-#endif  /* IMPERATIVE_MESSAGE_HANDLERS */
-
         {
          MessageHandlerData(theEnv)->CurrentCore = NULL;
          MessageHandlerData(theEnv)->NextInCore = MessageHandlerData(theEnv)->TopOfCore;
@@ -1122,7 +1110,7 @@ static void PerformMessage(
    if (EvaluationData(theEnv)->EvaluationError)
      {
       result->type = SYMBOL;
-      result->value = SymbolData(theEnv)->FalseSymbol;
+      result->value = EnvFalseSymbol(theEnv);
      }
   }
 
@@ -1187,10 +1175,12 @@ static void CallHandlers(
   void *theEnv,
   DATA_OBJECT *result)
   {
-   HANDLER_LINK *oldCurrent,*oldNext;
-#if AUXILIARY_MESSAGE_HANDLERS
-   DATA_OBJECT temp;
+#if IBM_TBC
+   HANDLER_LINK *oldCurrent,*oldNext;                /* prevents warning */
+#else
+   HANDLER_LINK *oldCurrent = NULL,*oldNext = NULL;  /* prevents warning */
 #endif
+   DATA_OBJECT temp;
 #if PROFILING_FUNCTIONS
    struct profileFrameInfo profileFrame;
 #endif
@@ -1198,7 +1188,6 @@ static void CallHandlers(
    if (EvaluationData(theEnv)->HaltExecution)
      return;
 
-#if AUXILIARY_MESSAGE_HANDLERS
    oldCurrent = MessageHandlerData(theEnv)->CurrentCore;
    oldNext = MessageHandlerData(theEnv)->NextInCore;
 
@@ -1243,8 +1232,6 @@ static void CallHandlers(
      }
    if (MessageHandlerData(theEnv)->NextInCore->hnd->type == MPRIMARY)
      {
-#endif /* AUXILIARY_MESSAGE_HANDLERS */
-
       MessageHandlerData(theEnv)->CurrentCore = MessageHandlerData(theEnv)->NextInCore;
       MessageHandlerData(theEnv)->NextInCore = MessageHandlerData(theEnv)->NextInCore->nxt;
 #if DEBUGGING_FUNCTIONS
@@ -1277,7 +1264,6 @@ static void CallHandlers(
 #endif
       ProcedureFunctionData(theEnv)->ReturnFlag = FALSE;
 
-#if AUXILIARY_MESSAGE_HANDLERS
       if ((MessageHandlerData(theEnv)->NextInCore == NULL) || EvaluationData(theEnv)->HaltExecution)
         {
          MessageHandlerData(theEnv)->NextInCore = oldNext;
@@ -1335,7 +1321,6 @@ static void CallHandlers(
          return;
         }
      }
-#endif /*  AUXILIARY_MESSAGE_HANDLERS */
 
    MessageHandlerData(theEnv)->NextInCore = oldNext;
    MessageHandlerData(theEnv)->CurrentCore = oldCurrent;
