@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*                  MULTIFIELD MODULE                  */
    /*******************************************************/
@@ -17,6 +17,12 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Corrected code to remove compiler warnings.    */
+/*                                                           */
+/*            Moved ImplodeMultifield from multifun.c.       */
+/*                                                           */
 /*************************************************************/
 
 #define _MULTIFLD_SOURCE_
@@ -34,6 +40,10 @@
 #include "router.h"
 #include "strngrtr.h"
 #include "utility.h"
+#if OBJECT_SYSTEM
+#include "object.h"
+#endif
+
 #include "multifld.h"
 
 /***************************************/
@@ -507,7 +517,7 @@ globle void StoreInMultifield(
 /*************************************************************/
 /* MultifieldDOsEqual: determines if two segments are equal. */
 /*************************************************************/
-globle BOOLEAN MultifieldDOsEqual(
+globle intBool MultifieldDOsEqual(
   DATA_OBJECT_PTR dobj1,
   DATA_OBJECT_PTR dobj2)
   {
@@ -552,7 +562,7 @@ globle int MultifieldsEqual(
    unsigned long length, i = 0;
 
    length = segment1->multifieldLength;
-   if (length != (int) segment2->multifieldLength)
+   if (length != segment2->multifieldLength)
      { return(FALSE); }
 
    elem1 = segment1->theFields;
@@ -668,7 +678,170 @@ globle struct multifield *GetMultifieldList(
    return(MultifieldData(theEnv)->ListOfMultifields);
   }
 
+/***************************************/
+/* ImplodeMultifield: C access routine */
+/*   for the implode$ function.        */
+/***************************************/
+globle void *ImplodeMultifield(
+  void *theEnv,
+  DATA_OBJECT *value)
+  {
+   unsigned strsize = 0;
+   long i, j;
+   char *tmp_str;
+   char *ret_str;
+   void *rv;
+   struct multifield *theMultifield;
 
+   /*===================================================*/
+   /* Determine the size of the string to be allocated. */
+   /*===================================================*/
+
+   theMultifield = (struct multifield *) GetpValue(value);
+   for (i = GetpDOBegin(value) ; i <= GetpDOEnd(value) ; i++)
+     {
+      if (GetMFType(theMultifield,i) == FLOAT)
+        {
+         tmp_str = FloatToString(theEnv,ValueToDouble(GetMFValue(theMultifield,i)));
+         strsize += strlen(tmp_str) + 1;
+        }
+      else if (GetMFType(theMultifield,i) == INTEGER)
+        {
+         tmp_str = LongIntegerToString(theEnv,ValueToLong(GetMFValue(theMultifield,i)));
+         strsize += strlen(tmp_str) + 1;
+        }
+      else if (GetMFType(theMultifield,i) == STRING)
+        {
+         strsize += strlen(ValueToString(GetMFValue(theMultifield,i))) + 3;
+         tmp_str = ValueToString(GetMFValue(theMultifield,i));
+         while(*tmp_str)
+           {
+            if (*tmp_str == '"')
+              { strsize++; }
+            else if (*tmp_str == '\\') /* GDR 111599 #835 */
+              { strsize++; }           /* GDR 111599 #835 */
+            tmp_str++;
+           }
+        }
+#if OBJECT_SYSTEM
+      else if (GetMFType(theMultifield,i) == INSTANCE_NAME)
+        { strsize += strlen(ValueToString(GetMFValue(theMultifield,i))) + 3; }
+      else if (GetMFType(theMultifield,i) == INSTANCE_ADDRESS)
+        { strsize += strlen(ValueToString(((INSTANCE_TYPE *)
+                            GetMFValue(theMultifield,i))->name)) + 3; }
+#endif
+
+      else
+        { strsize += strlen(ValueToString(GetMFValue(theMultifield,i))) + 1; }
+     }
+
+   /*=============================================*/
+   /* Allocate the string and copy all components */
+   /* of the MULTIFIELD variable to it.           */
+   /*=============================================*/
+
+   if (strsize == 0) return(EnvAddSymbol(theEnv,""));
+   ret_str = (char *) gm2(theEnv,strsize);
+   for(j=0, i=GetpDOBegin(value); i <= GetpDOEnd(value) ; i++)
+     {
+      /*============================*/
+      /* Convert numbers to strings */
+      /*============================*/
+
+      if (GetMFType(theMultifield,i) == FLOAT)
+        {
+         tmp_str = FloatToString(theEnv,ValueToDouble(GetMFValue(theMultifield,i)));
+         while(*tmp_str)
+           {
+            *(ret_str+j) = *tmp_str;
+            j++, tmp_str++;
+           }
+        }
+      else if (GetMFType(theMultifield,i) == INTEGER)
+        {
+         tmp_str = LongIntegerToString(theEnv,ValueToLong(GetMFValue(theMultifield,i)));
+         while(*tmp_str)
+           {
+            *(ret_str+j) = *tmp_str;
+            j++, tmp_str++;
+           }
+        }
+
+      /*=======================================*/
+      /* Enclose strings in quotes and preceed */
+      /* imbedded quotes with a backslash      */
+      /*=======================================*/
+
+      else if (GetMFType(theMultifield,i) == STRING)
+        {
+         tmp_str = ValueToString(GetMFValue(theMultifield,i));
+         *(ret_str+j) = '"';
+         j++;
+         while(*tmp_str)
+           {
+            if (*tmp_str == '"')
+              {
+               *(ret_str+j) = '\\';
+               j++;
+              }
+            else if (*tmp_str == '\\') /* GDR 111599 #835 */
+              {                        /* GDR 111599 #835 */
+               *(ret_str+j) = '\\';    /* GDR 111599 #835 */
+               j++;                    /* GDR 111599 #835 */
+              }                        /* GDR 111599 #835 */
+              
+            *(ret_str+j) = *tmp_str;
+            j++, tmp_str++;
+           }
+         *(ret_str+j) = '"';
+         j++;
+        }
+#if OBJECT_SYSTEM
+      else if (GetMFType(theMultifield,i) == INSTANCE_NAME)
+        {
+         tmp_str = ValueToString(GetMFValue(theMultifield,i));
+         *(ret_str + j++) = '[';
+         while(*tmp_str)
+           {
+            *(ret_str+j) = *tmp_str;
+            j++, tmp_str++;
+           }
+         *(ret_str + j++) = ']';
+        }
+      else if (GetMFType(theMultifield,i) == INSTANCE_ADDRESS)
+        {
+         tmp_str = ValueToString(((INSTANCE_TYPE *) GetMFValue(theMultifield,i))->name);
+         *(ret_str + j++) = '[';
+         while(*tmp_str)
+           {
+            *(ret_str+j) = *tmp_str;
+            j++, tmp_str++;
+           }
+         *(ret_str + j++) = ']';
+        }
+#endif
+      else
+        {
+         tmp_str = ValueToString(GetMFValue(theMultifield,i));
+         while(*tmp_str)
+           {
+            *(ret_str+j) = *tmp_str;
+            j++, tmp_str++;
+           }
+         }
+      *(ret_str+j) = ' ';
+      j++;
+     }
+   *(ret_str+j-1) = '\0';
+
+   /*====================*/
+   /* Return the string. */
+   /*====================*/
+
+   rv = EnvAddSymbol(theEnv,ret_str);
+   rm(theEnv,ret_str,strsize);
+   return(rv);
+  }
 
 
 
