@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*               CLIPS Version 6.20  01/31/02          */
+   /*               CLIPS Version 6.24  05/17/06          */
    /*                                                     */
    /*                                                     */
    /*******************************************************/
@@ -17,6 +17,12 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Converted INSTANCE_PATTERN_MATCHING to         */
+/*            DEFRULE_CONSTRUCT.                             */
+/*                                                           */
+/*            ResetObjectMatchTimeTags did not pass in the   */
+/*            environment argument when BLOAD_ONLY was set.  */
+/*                                                           */
 /*************************************************************/
 
 /* =========================================
@@ -26,7 +32,7 @@
    ***************************************** */
 #include "setup.h"
 
-#if INSTANCE_PATTERN_MATCHING && (BLOAD || BLOAD_ONLY || BLOAD_AND_BSAVE)
+#if DEFRULE_CONSTRUCT && OBJECT_SYSTEM && (BLOAD || BLOAD_ONLY || BLOAD_AND_BSAVE)
 
 #include "bload.h"
 #include "bsave.h"
@@ -516,7 +522,7 @@ static void ClearBloadObjectPatterns(
    SetObjectNetworkTerminalPointer(theEnv,NULL);
    SetObjectNetworkPointer(theEnv,NULL);
 #if BLOAD_ONLY
-   ResetObjectMatchTimeTags();
+   ResetObjectMatchTimeTags(theEnv);
 #endif
   }
 
