@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*               CLIPS Version 6.20  01/31/02          */
+   /*               CLIPS Version 6.24  05/17/06          */
    /*                                                     */
    /*          OBJECT PATTERN MATCHER MODULE              */
    /*******************************************************/
@@ -16,6 +16,13 @@
 /*                                                            */
 /* Revision History:                                          */
 /*                                                            */
+/*      6.24: Removed INCREMENTAL_RESET compilation flag.     */
+/*                                                            */
+/*            Converted INSTANCE_PATTERN_MATCHING to          */
+/*            DEFRULE_CONSTRUCT.                              */
+/*                                                            */
+/*            Renamed BOOLEAN macro type to intBool.          */
+/*                                                            */
 /**************************************************************/
 /* =========================================
    *****************************************
@@ -24,7 +31,7 @@
    ***************************************** */
 #include "setup.h"
 
-#if INSTANCE_PATTERN_MATCHING
+#if DEFRULE_CONSTRUCT && OBJECT_SYSTEM
 
 #if (! BLOAD_ONLY) && (! RUN_TIME)
 
@@ -95,9 +102,9 @@
    =========================================
    ***************************************** */
 
-static BOOLEAN PatternParserFind(SYMBOL_HN *);
+static intBool PatternParserFind(SYMBOL_HN *);
 static struct lhsParseNode *ObjectLHSParse(void *,char *,struct token *);
-static BOOLEAN ReorderAndAnalyzeObjectPattern(void *,struct lhsParseNode *);
+static intBool ReorderAndAnalyzeObjectPattern(void *,struct lhsParseNode *);
 static struct patternNodeHeader *PlaceObjectPattern(void *,struct lhsParseNode *);
 static OBJECT_PATTERN_NODE *FindObjectPatternNode(OBJECT_PATTERN_NODE *,struct lhsParseNode *,
                                                   OBJECT_PATTERN_NODE **,unsigned);
@@ -106,7 +113,7 @@ static OBJECT_PATTERN_NODE *CreateNewObjectPatternNode(void *,struct lhsParseNod
 static void DetachObjectPattern(void *,struct patternNodeHeader *);
 static void ClearObjectPatternMatches(void *,OBJECT_ALPHA_NODE *);
 static void RemoveObjectPartialMatches(void *,INSTANCE_TYPE *,struct patternNodeHeader *);
-static BOOLEAN CheckDuplicateSlots(void *,struct lhsParseNode *,SYMBOL_HN *);
+static intBool CheckDuplicateSlots(void *,struct lhsParseNode *,SYMBOL_HN *);
 static struct lhsParseNode *ParseClassRestriction(void *,char *,struct token *);
 static struct lhsParseNode *ParseNameRestriction(void *,char *,struct token *);
 static struct lhsParseNode *ParseSlotRestriction(void *,char *,struct token *,CONSTRAINT_RECORD *,int);
@@ -116,9 +123,9 @@ static void DeleteIntermediateClassBitMap(void *,CLASS_BITMAP *);
 static void *CopyClassBitMap(void *,void *);
 static void DeleteClassBitMap(void *,void *);
 static void MarkBitMapClassesBusy(void *,BITMAP_HN *,int);
-static BOOLEAN EmptyClassBitMap(CLASS_BITMAP *);
-static BOOLEAN IdenticalClassBitMap(CLASS_BITMAP *,CLASS_BITMAP *);
-static BOOLEAN ProcessClassRestriction(void *,CLASS_BITMAP *,struct lhsParseNode **,int);
+static intBool EmptyClassBitMap(CLASS_BITMAP *);
+static intBool IdenticalClassBitMap(CLASS_BITMAP *,CLASS_BITMAP *);
+static intBool ProcessClassRestriction(void *,CLASS_BITMAP *,struct lhsParseNode **,int);
 static CONSTRAINT_RECORD *ProcessSlotRestriction(void *,CLASS_BITMAP *,SYMBOL_HN *,int *);
 static void IntersectClassBitMaps(CLASS_BITMAP *,CLASS_BITMAP *);
 static void UnionClassBitMaps(CLASS_BITMAP *,CLASS_BITMAP *);
@@ -130,10 +137,8 @@ static BITMAP_HN *FormSlotBitMap(void *,struct lhsParseNode *);
 static struct lhsParseNode *RemoveSlotExistenceTests(void *,struct lhsParseNode *,BITMAP_HN **);
 static struct lhsParseNode *CreateInitialObjectPattern(void *);
 static EXPRESSION *ObjectMatchDelayParse(void *,EXPRESSION *,char *);
-#if INCREMENTAL_RESET
 static void MarkObjectPtnIncrementalReset(void *,struct patternNodeHeader *,int);
 static void ObjectIncrementalReset(void *);
-#endif
 
 #endif
 
@@ -198,13 +203,8 @@ globle void SetupObjectPatternStuff(
    newPtr->returnUserDataFunction = DeleteClassBitMap;
    newPtr->copyUserDataFunction = CopyClassBitMap;
 
-#if INCREMENTAL_RESET
    newPtr->markIRPatternFunction = MarkObjectPtnIncrementalReset;
    newPtr->incrementalResetFunction = ObjectIncrementalReset;
-#else
-   newPtr->markIRPatternFunction = NULL;
-   newPtr->incrementalResetFunction = NULL;
-#endif
 
    newPtr->initialPatternFunction = CreateInitialObjectPattern;
 
@@ -278,7 +278,7 @@ static void ResetInitialObject(
   SIDE EFFECTS : None
   NOTES        : Used by AddPatternParser()
  *****************************************************/
-static BOOLEAN PatternParserFind(
+static intBool PatternParserFind(
   SYMBOL_HN *value)
   {
    if (strcmp(ValueToString(value),OBJECT_PATTERN_INDICATOR) == 0)
@@ -310,7 +310,7 @@ static struct lhsParseNode *ObjectLHSParse(
   char *readSource,
   struct token *lastToken)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(lastToken)
 #endif
    struct token theToken;
@@ -480,7 +480,7 @@ ObjectLHSParseERROR:
   NOTES        : Adds a default is-a slot if one does not
                  already exist
  **************************************************************/
-static BOOLEAN ReorderAndAnalyzeObjectPattern(
+static intBool ReorderAndAnalyzeObjectPattern(
   void *theEnv,
   struct lhsParseNode *topNode)
   {
@@ -1211,7 +1211,7 @@ static void RemoveObjectPartialMatches(
                  duplicate is found
   NOTES        : None
  ******************************************************/
-static BOOLEAN CheckDuplicateSlots(
+static intBool CheckDuplicateSlots(
   void *theEnv,
   struct lhsParseNode *nodeList,
   SYMBOL_HN *slotName)
@@ -1502,7 +1502,7 @@ static void *CopyClassBitMap(
   void *theEnv,
   void *gset)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 
@@ -1575,7 +1575,7 @@ static void MarkBitMapClassesBusy(
   SIDE EFFECTS : None
   NOTES        : None
  ****************************************************/
-static BOOLEAN EmptyClassBitMap(
+static intBool EmptyClassBitMap(
   CLASS_BITMAP *bmp)
   {
    register unsigned short bytes;
@@ -1601,7 +1601,7 @@ static BOOLEAN EmptyClassBitMap(
   SIDE EFFECTS : None
   NOTES        : None
  ***************************************************/
-static BOOLEAN IdenticalClassBitMap(
+static intBool IdenticalClassBitMap(
   CLASS_BITMAP *cs1,
   CLASS_BITMAP *cs2)
   {
@@ -1629,7 +1629,7 @@ static BOOLEAN IdenticalClassBitMap(
                  to constant restrictions are removed
   NOTES        : None
  *****************************************************************/
-static BOOLEAN ProcessClassRestriction(
+static intBool ProcessClassRestriction(
   void *theEnv,
   CLASS_BITMAP *clsset,
   struct lhsParseNode **classRestrictions,
@@ -2217,8 +2217,6 @@ static EXPRESSION *ObjectMatchDelayParse(
    return(top);
   }
 
-#if INCREMENTAL_RESET
-
 /***************************************************
   NAME         : MarkObjectPtnIncrementalReset
   DESCRIPTION  : Marks/unmarks an object pattern for
@@ -2241,7 +2239,7 @@ static void MarkObjectPtnIncrementalReset(
   struct patternNodeHeader *thePattern,
   int value)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 
@@ -2275,6 +2273,4 @@ static void ObjectIncrementalReset(
 
 #endif
 
-#endif
-
 
