@@ -1,9 +1,9 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*               CLIPS Version 6.20  01/31/02          */
-   /*                                                     */
+   /*               CLIPS Version 6.24  05/17/06          */
    /*                                                     */
+   /*          OBJECT PATTERN MATCHER MODULE              */
    /*******************************************************/
 
 /*************************************************************/
@@ -16,12 +16,15 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Converted INSTANCE_PATTERN_MATCHING to         */
+/*            DEFRULE_CONSTRUCT.                             */
+/*                                                           */
 /*************************************************************/
 
 #ifndef _H_objrtbld
 #define _H_objrtbld
 
-#if INSTANCE_PATTERN_MATCHING
+#if DEFRULE_CONSTRUCT && OBJECT_SYSTEM
 
 #ifdef LOCALE
 #undef LOCALE
