@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*               CLIPS Version 6.20  01/31/02          */
+   /*               CLIPS Version 6.24  05/17/06          */
    /*                                                     */
    /*    INFERENCE ENGINE OBJECT ACCESS ROUTINES MODULE   */
    /*******************************************************/
@@ -15,6 +15,12 @@
 /* Contributing Programmer(s):                                */
 /*                                                            */
 /* Revision History:                                          */
+/*      6.23: Correction for FalseSymbol/TrueSymbol. DR0859   */
+/*                                                            */
+/*      6.24: Converted INSTANCE_PATTERN_MATCHING to          */
+/*            DEFRULE_CONSTRUCT.                              */
+/*                                                            */
+/*            Renamed BOOLEAN macro type to intBool.          */
 /*                                                            */
 /**************************************************************/
 /* =========================================
@@ -24,7 +30,7 @@
    ***************************************** */
 #include "setup.h"
 
-#if INSTANCE_PATTERN_MATCHING
+#if DEFRULE_CONSTRUCT && OBJECT_SYSTEM
 
 #include <stdio.h>
 #define _STDIO_INCLUDED_
@@ -67,28 +73,28 @@
    ***************************************** */
 
 static void PrintObjectGetVarJN1(void *,char *,void *);
-static BOOLEAN ObjectGetVarJNFunction1(void *,void *,DATA_OBJECT *);
+static intBool ObjectGetVarJNFunction1(void *,void *,DATA_OBJECT *);
 static void PrintObjectGetVarJN2(void *,char *,void *);
-static BOOLEAN ObjectGetVarJNFunction2(void *,void *,DATA_OBJECT *);
+static intBool ObjectGetVarJNFunction2(void *,void *,DATA_OBJECT *);
 static void PrintObjectGetVarPN1(void *,char *,void *);
-static BOOLEAN ObjectGetVarPNFunction1(void *,void *,DATA_OBJECT *);
+static intBool ObjectGetVarPNFunction1(void *,void *,DATA_OBJECT *);
 static void PrintObjectGetVarPN2(void *,char *,void *);
-static BOOLEAN ObjectGetVarPNFunction2(void *,void *,DATA_OBJECT *);
+static intBool ObjectGetVarPNFunction2(void *,void *,DATA_OBJECT *);
 static void PrintObjectCmpConstant(void *,char *,void *);
 static void PrintSlotLengthTest(void *,char *,void *);
-static BOOLEAN SlotLengthTestFunction(void *,void *,DATA_OBJECT *);
+static intBool SlotLengthTestFunction(void *,void *,DATA_OBJECT *);
 static void PrintPNSimpleCompareFunction1(void *,char *,void *);
-static BOOLEAN PNSimpleCompareFunction1(void *,void *,DATA_OBJECT *);
+static intBool PNSimpleCompareFunction1(void *,void *,DATA_OBJECT *);
 static void PrintPNSimpleCompareFunction2(void *,char *,void *);
-static BOOLEAN PNSimpleCompareFunction2(void *,void *,DATA_OBJECT *);
+static intBool PNSimpleCompareFunction2(void *,void *,DATA_OBJECT *);
 static void PrintPNSimpleCompareFunction3(void *,char *,void *);
-static BOOLEAN PNSimpleCompareFunction3(void *,void *,DATA_OBJECT *);
+static intBool PNSimpleCompareFunction3(void *,void *,DATA_OBJECT *);
 static void PrintJNSimpleCompareFunction1(void *,char *,void *);
-static BOOLEAN JNSimpleCompareFunction1(void *,void *,DATA_OBJECT *);
+static intBool JNSimpleCompareFunction1(void *,void *,DATA_OBJECT *);
 static void PrintJNSimpleCompareFunction2(void *,char *,void *);
-static BOOLEAN JNSimpleCompareFunction2(void *,void *,DATA_OBJECT *);
+static intBool JNSimpleCompareFunction2(void *,void *,DATA_OBJECT *);
 static void PrintJNSimpleCompareFunction3(void *,char *,void *);
-static BOOLEAN JNSimpleCompareFunction3(void *,void *,DATA_OBJECT *);
+static intBool JNSimpleCompareFunction3(void *,void *,DATA_OBJECT *);
 static void GetPatternObjectAndMarks(void *,int,INSTANCE_TYPE **,struct multifieldMarker **);
 static void GetObjectValueGeneral(void *,DATA_OBJECT *,INSTANCE_TYPE *,
                                  struct multifieldMarker *,struct ObjectMatchVar1 *);
@@ -300,7 +306,7 @@ static void DestroyObjectAlphaNodes(
   NOTES        : Called directly by
                    EvaluatePatternExpression()
  *****************************************************/
-globle BOOLEAN ObjectCmpConstantFunction(
+globle intBool ObjectCmpConstantFunction(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -349,7 +355,7 @@ globle BOOLEAN ObjectCmpConstantFunction(
    else
      rv = hack->pass;
    theResult->type = SYMBOL;
-   theResult->value = rv ? SymbolData(theEnv)->TrueSymbol : SymbolData(theEnv)->FalseSymbol;
+   theResult->value = rv ? EnvTrueSymbol(theEnv) : EnvFalseSymbol(theEnv);
    return(rv);
   }
 
@@ -395,7 +401,7 @@ static void PrintObjectGetVarJN1(
      }
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -403,7 +409,7 @@ static void PrintObjectGetVarJN1(
 #endif
   }
 
-static BOOLEAN ObjectGetVarJNFunction1(
+static intBool ObjectGetVarJNFunction1(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -446,7 +452,7 @@ static void PrintObjectGetVarJN2(
      }
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -454,7 +460,7 @@ static void PrintObjectGetVarJN2(
 #endif
   }
 
-static BOOLEAN ObjectGetVarJNFunction2(
+static intBool ObjectGetVarJNFunction2(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -498,7 +504,7 @@ static void PrintObjectGetVarPN1(
      }
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -506,7 +512,7 @@ static void PrintObjectGetVarPN1(
 #endif
   }
 
-static BOOLEAN ObjectGetVarPNFunction1(
+static intBool ObjectGetVarPNFunction1(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -544,7 +550,7 @@ static void PrintObjectGetVarPN2(
      }
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -552,7 +558,7 @@ static void PrintObjectGetVarPN2(
 #endif
   }
 
-static BOOLEAN ObjectGetVarPNFunction2(
+static intBool ObjectGetVarPNFunction2(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -590,7 +596,7 @@ static void PrintObjectCmpConstant(
      }
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -619,7 +625,7 @@ static void PrintSlotLengthTest(
    PrintLongInteger(theEnv,logicalName,(long) hack->minLength);
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -627,7 +633,7 @@ static void PrintSlotLengthTest(
 #endif
   }
 
-static BOOLEAN SlotLengthTestFunction(
+static intBool SlotLengthTestFunction(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -635,13 +641,13 @@ static BOOLEAN SlotLengthTestFunction(
    struct ObjectMatchLength *hack;
 
    theResult->type = SYMBOL;
-   theResult->value = SymbolData(theEnv)->FalseSymbol;
+   theResult->value = EnvFalseSymbol(theEnv);
    hack = (struct ObjectMatchLength *) ValueToBitMap(theValue);
    if (ObjectReteData(theEnv)->CurrentObjectSlotLength < hack->minLength)
      return(FALSE);
    if (hack->exactly && (ObjectReteData(theEnv)->CurrentObjectSlotLength > hack->minLength))
      return(FALSE);
-   theResult->value = SymbolData(theEnv)->TrueSymbol;
+   theResult->value = EnvTrueSymbol(theEnv);
    return(TRUE);
   }
 
@@ -665,7 +671,7 @@ static void PrintPNSimpleCompareFunction1(
    EnvPrintRouter(theEnv,logicalName,ValueToString(FindIDSlotName(theEnv,(unsigned) hack->secondSlot)));
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -673,7 +679,7 @@ static void PrintPNSimpleCompareFunction1(
 #endif
   }
 
-static BOOLEAN PNSimpleCompareFunction1(
+static intBool PNSimpleCompareFunction1(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -692,7 +698,7 @@ static BOOLEAN PNSimpleCompareFunction1(
    else
      rv = hack->pass;
    theResult->type = SYMBOL;
-   theResult->value = rv ? SymbolData(theEnv)->TrueSymbol : SymbolData(theEnv)->FalseSymbol;
+   theResult->value = rv ? EnvTrueSymbol(theEnv) : EnvFalseSymbol(theEnv);
    return(rv);
   }
 
@@ -718,7 +724,7 @@ static void PrintPNSimpleCompareFunction2(
    EnvPrintRouter(theEnv,logicalName,ValueToString(FindIDSlotName(theEnv,(unsigned) hack->secondSlot)));
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -726,7 +732,7 @@ static void PrintPNSimpleCompareFunction2(
 #endif
   }
 
-static BOOLEAN PNSimpleCompareFunction2(
+static intBool PNSimpleCompareFunction2(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -747,7 +753,7 @@ static BOOLEAN PNSimpleCompareFunction2(
    else
      rv = hack->pass;
    theResult->type = SYMBOL;
-   theResult->value = rv ? SymbolData(theEnv)->TrueSymbol : SymbolData(theEnv)->FalseSymbol;
+   theResult->value = rv ? EnvTrueSymbol(theEnv) : EnvFalseSymbol(theEnv);
    return(rv);
   }
 
@@ -775,7 +781,7 @@ static void PrintPNSimpleCompareFunction3(
    PrintLongInteger(theEnv,logicalName,(long) hack->secondOffset);
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -783,7 +789,7 @@ static void PrintPNSimpleCompareFunction3(
 #endif
   }
 
-static BOOLEAN PNSimpleCompareFunction3(
+static intBool PNSimpleCompareFunction3(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -804,7 +810,7 @@ static BOOLEAN PNSimpleCompareFunction3(
    else
      rv = hack->pass;
    theResult->type = SYMBOL;
-   theResult->value = rv ? SymbolData(theEnv)->TrueSymbol : SymbolData(theEnv)->FalseSymbol;
+   theResult->value = rv ? EnvTrueSymbol(theEnv) : EnvFalseSymbol(theEnv);
    return(rv);
   }
 
@@ -832,7 +838,7 @@ static void PrintJNSimpleCompareFunction1(
    EnvPrintRouter(theEnv,logicalName,ValueToString(FindIDSlotName(theEnv,(unsigned) hack->secondSlot)));
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -840,7 +846,7 @@ static void PrintJNSimpleCompareFunction1(
 #endif
   }
 
-static BOOLEAN JNSimpleCompareFunction1(
+static intBool JNSimpleCompareFunction1(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -863,7 +869,7 @@ static BOOLEAN JNSimpleCompareFunction1(
    else
      rv = hack->pass;
    theResult->type = SYMBOL;
-   theResult->value = rv ? SymbolData(theEnv)->TrueSymbol : SymbolData(theEnv)->FalseSymbol;
+   theResult->value = rv ? EnvTrueSymbol(theEnv) : EnvFalseSymbol(theEnv);
    return(rv);
   }
 
@@ -893,7 +899,7 @@ static void PrintJNSimpleCompareFunction2(
    EnvPrintRouter(theEnv,logicalName,ValueToString(FindIDSlotName(theEnv,(unsigned) hack->secondSlot)));
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -901,7 +907,7 @@ static void PrintJNSimpleCompareFunction2(
 #endif
   }
 
-static BOOLEAN JNSimpleCompareFunction2(
+static intBool JNSimpleCompareFunction2(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -926,7 +932,7 @@ static BOOLEAN JNSimpleCompareFunction2(
    else
      rv = hack->pass;
    theResult->type = SYMBOL;
-   theResult->value = rv ? SymbolData(theEnv)->TrueSymbol : SymbolData(theEnv)->FalseSymbol;
+   theResult->value = rv ? EnvTrueSymbol(theEnv) : EnvFalseSymbol(theEnv);
    return(rv);
   }
 
@@ -958,7 +964,7 @@ static void PrintJNSimpleCompareFunction3(
    PrintLongInteger(theEnv,logicalName,(long) hack->secondOffset);
    EnvPrintRouter(theEnv,logicalName,")");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #pragma unused(logicalName)
 #pragma unused(theValue)
@@ -966,7 +972,7 @@ static void PrintJNSimpleCompareFunction3(
 #endif
   }
 
-static BOOLEAN JNSimpleCompareFunction3(
+static intBool JNSimpleCompareFunction3(
   void *theEnv,
   void *theValue,
   DATA_OBJECT *theResult)
@@ -993,7 +999,7 @@ static BOOLEAN JNSimpleCompareFunction3(
    else
      rv = hack->pass;
    theResult->type = SYMBOL;
-   theResult->value = rv ? SymbolData(theEnv)->TrueSymbol : SymbolData(theEnv)->FalseSymbol;
+   theResult->value = rv ? EnvTrueSymbol(theEnv) : EnvFalseSymbol(theEnv);
    return(rv);
   }
 
