@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*               CLIPS Version 6.20  01/31/02          */
+   /*               CLIPS Version 6.24  05/17/06          */
    /*                                                     */
    /*    INFERENCE ENGINE OBJECT PARSING ROUTINES MODULE  */
    /*******************************************************/
@@ -15,6 +15,14 @@
 /* Contributing Programmer(s):                                */
 /*                                                            */
 /* Revision History:                                          */
+/*      6.23: Changed name of variable exp to theExp          */
+/*            because of Unix compiler warnings of shadowed   */
+/*            definitions.                                    */
+/*                                                            */
+/*      6.24: Converted INSTANCE_PATTERN_MATCHING to          */
+/*            DEFRULE_CONSTRUCT.                              */
+/*                                                            */
+/*            Renamed BOOLEAN macro type to intBool.          */
 /*                                                            */
 /**************************************************************/
 /* =========================================
@@ -24,7 +32,7 @@
    ***************************************** */
 #include "setup.h"
 
-#if INSTANCE_PATTERN_MATCHING && (! RUN_TIME) && (! BLOAD_ONLY)
+#if DEFRULE_CONSTRUCT && OBJECT_SYSTEM && (! RUN_TIME) && (! BLOAD_ONLY)
 
 #ifndef _STDIO_INCLUDED_
 #include <stdio.h>
@@ -45,7 +53,7 @@
    ***************************************** */
 
 static void GenObjectGetVar(void *,int,EXPRESSION *,struct lhsParseNode *);
-static BOOLEAN IsSimpleSlotVariable(struct lhsParseNode *);
+static intBool IsSimpleSlotVariable(struct lhsParseNode *);
 static EXPRESSION *GenerateSlotComparisonTest(void *,int,struct lhsParseNode *,struct lhsParseNode *);
 
 /* =========================================
@@ -94,7 +102,7 @@ globle EXPRESSION *GenObjectPNConstantCompare(
   struct lhsParseNode *theNode)
   {
    struct ObjectCmpPNConstant hack;
-   EXPRESSION *exp;
+   EXPRESSION *theExp;
    unsigned short tmpType;
 
    /* ===============================================================
@@ -129,23 +137,23 @@ globle EXPRESSION *GenObjectPNConstantCompare(
         }
       else
         hack.offset = theNode->singleFieldsAfter;
-      exp = GenConstant(theEnv,OBJ_PN_CONSTANT,AddBitMap(theEnv,(void *) &hack,
+      theExp = GenConstant(theEnv,OBJ_PN_CONSTANT,AddBitMap(theEnv,(void *) &hack,
                                         (int) sizeof(struct ObjectCmpPNConstant)));
-      exp->argList = GenConstant(theEnv,theNode->type,theNode->value);
+      theExp->argList = GenConstant(theEnv,theNode->type,theNode->value);
      }
    else
      {
       hack.general = 1;
-      exp = GenConstant(theEnv,OBJ_PN_CONSTANT,AddBitMap(theEnv,(void *) &hack,
+      theExp = GenConstant(theEnv,OBJ_PN_CONSTANT,AddBitMap(theEnv,(void *) &hack,
                                         (int) sizeof(struct ObjectCmpPNConstant)));
-      exp->argList = GenConstant(theEnv,0,NULL);
+      theExp->argList = GenConstant(theEnv,0,NULL);
       tmpType = theNode->type;
       theNode->type = SF_VARIABLE;
-      GenObjectGetVar(theEnv,FALSE,exp->argList,theNode);
+      GenObjectGetVar(theEnv,FALSE,theExp->argList,theNode);
       theNode->type = tmpType;
-      exp->argList->nextArg = GenConstant(theEnv,theNode->type,theNode->value);
+      theExp->argList->nextArg = GenConstant(theEnv,theNode->type,theNode->value);
      }
-   return(exp);
+   return(theExp);
   }
 
 globle void ReplaceGetPNObjectValue(
@@ -373,7 +381,7 @@ static void GenObjectGetVar(
   SIDE EFFECTS : None
   NOTES        : None
  ****************************************************************/
-static BOOLEAN IsSimpleSlotVariable(
+static intBool IsSimpleSlotVariable(
   struct lhsParseNode *node)
   {
    if ((node->type == MF_WILDCARD) || (node->type == MF_VARIABLE))
@@ -426,7 +434,7 @@ static EXPRESSION *GenerateSlotComparisonTest(
   struct lhsParseNode *selfNode,
   struct lhsParseNode *referringNode)
   {
-   EXPRESSION *exp;
+   EXPRESSION *theExp;
    struct ObjectCmpPNSingleSlotVars1 phack1;
    struct ObjectCmpPNSingleSlotVars2 phack2;
    struct ObjectCmpPNSingleSlotVars3 phack3;
@@ -460,11 +468,11 @@ static EXPRESSION *GenerateSlotComparisonTest(
            {
             jhack1.firstPattern = (unsigned short) selfNode->pattern;
             jhack1.secondPattern = (unsigned short) referringNode->pattern;
-            exp = GenConstant(theEnv,OBJ_JN_CMP1,AddBitMap(theEnv,(void *) &jhack1,
+            theExp = GenConstant(theEnv,OBJ_JN_CMP1,AddBitMap(theEnv,(void *) &jhack1,
                                            (int) sizeof(struct ObjectCmpJoinSingleSlotVars1)));
            }
          else
-           exp = GenConstant(theEnv,OBJ_PN_CMP1,AddBitMap(theEnv,(void *) &phack1,
+           theExp = GenConstant(theEnv,OBJ_PN_CMP1,AddBitMap(theEnv,(void *) &phack1,
                                            (int) sizeof(struct ObjectCmpPNSingleSlotVars1)));
         }
       /* ============================================
@@ -516,10 +524,10 @@ static EXPRESSION *GenerateSlotComparisonTest(
               phack2.offset = jhack2.offset = referringNode->singleFieldsAfter;
            }
          if (joinTest)
-           exp = GenConstant(theEnv,OBJ_JN_CMP2,AddBitMap(theEnv,(void *) &jhack2,
+           theExp = GenConstant(theEnv,OBJ_JN_CMP2,AddBitMap(theEnv,(void *) &jhack2,
                                            (int) sizeof(struct ObjectCmpJoinSingleSlotVars2)));
          else
-           exp = GenConstant(theEnv,OBJ_PN_CMP2,AddBitMap(theEnv,(void *) &phack2,
+           theExp = GenConstant(theEnv,OBJ_PN_CMP2,AddBitMap(theEnv,(void *) &phack2,
                                            (int) sizeof(struct ObjectCmpPNSingleSlotVars2)));
         }
 
@@ -555,11 +563,11 @@ static EXPRESSION *GenerateSlotComparisonTest(
            {
             jhack3.firstPattern = (unsigned short) selfNode->pattern;
             jhack3.secondPattern = (unsigned short) referringNode->pattern;
-            exp = GenConstant(theEnv,OBJ_JN_CMP3,AddBitMap(theEnv,(void *) &jhack3,
+            theExp = GenConstant(theEnv,OBJ_JN_CMP3,AddBitMap(theEnv,(void *) &jhack3,
                                          (int) sizeof(struct ObjectCmpJoinSingleSlotVars3)));
            }
          else
-           exp = GenConstant(theEnv,OBJ_PN_CMP3,AddBitMap(theEnv,(void *) &phack3,
+           theExp = GenConstant(theEnv,OBJ_PN_CMP3,AddBitMap(theEnv,(void *) &phack3,
                                            (int) sizeof(struct ObjectCmpPNSingleSlotVars3)));
         }
      }
@@ -571,13 +579,13 @@ static EXPRESSION *GenerateSlotComparisonTest(
       ================================================== */
    else
      {
-      exp = GenConstant(theEnv,FCALL,selfNode->negated ? ExpressionData(theEnv)->PTR_NEQ : ExpressionData(theEnv)->PTR_EQ);
-      exp->argList = GenConstant(theEnv,0,NULL);
-      GenObjectGetVar(theEnv,joinTest,exp->argList,selfNode);
-      exp->argList->nextArg = GenConstant(theEnv,0,NULL);
-      GenObjectGetVar(theEnv,joinTest,exp->argList->nextArg,referringNode);
+      theExp = GenConstant(theEnv,FCALL,selfNode->negated ? ExpressionData(theEnv)->PTR_NEQ : ExpressionData(theEnv)->PTR_EQ);
+      theExp->argList = GenConstant(theEnv,0,NULL);
+      GenObjectGetVar(theEnv,joinTest,theExp->argList,selfNode);
+      theExp->argList->nextArg = GenConstant(theEnv,0,NULL);
+      GenObjectGetVar(theEnv,joinTest,theExp->argList->nextArg,referringNode);
      }
-   return(exp);
+   return(theExp);
   }
 
 #endif
