@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  07/01/05            */
    /*                                                     */
    /*                PRINT UTILITY MODULE                 */
    /*******************************************************/
@@ -18,6 +18,14 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Link error occurs for the SlotExistError       */
+/*            function when OBJECT_SYSTEM is set to 0 in     */
+/*            setup.h. DR0865                                */
+/*                                                           */
+/*            Added DataObjectToString function.             */
+/*                                                           */
+/*            Added SlotExistError function.                 */
+/*                                                           */
 /*************************************************************/
 
 #define _PRNTUTIL_SOURCE_
@@ -35,6 +43,11 @@
 #include "evaluatn.h"
 #include "argacces.h"
 #include "router.h"
+#include "multifun.h"
+#include "factmngr.h"
+#include "inscom.h"
+#include "insmngr.h"
+#include "memalloc.h"
 
 #include "prntutil.h"
 
@@ -245,6 +258,26 @@ globle void CantFindItemErrorMessage(
    EnvPrintRouter(theEnv,WERROR,".\n");
   }
 
+/*****************************************************/
+/* CantFindItemInFunctionErrorMessage: Generic error */
+/*  message when an "item" can not be found.         */
+/*****************************************************/
+globle void CantFindItemInFunctionErrorMessage(
+  void *theEnv,
+  char *itemType,
+  char *itemName,
+  char *func)
+  {
+   PrintErrorID(theEnv,"PRNTUTIL",1,FALSE);
+   EnvPrintRouter(theEnv,WERROR,"Unable to find ");
+   EnvPrintRouter(theEnv,WERROR,itemType);
+   EnvPrintRouter(theEnv,WERROR," ");
+   EnvPrintRouter(theEnv,WERROR,itemName);
+   EnvPrintRouter(theEnv,WERROR," in function ");
+   EnvPrintRouter(theEnv,WERROR,func);
+   EnvPrintRouter(theEnv,WERROR,".\n");
+  }
+
 /*****************************************************/
 /* CantDeleteItemErrorMessage: Generic error message */
 /*  when an "item" can not be deleted.               */
@@ -397,6 +430,105 @@ globle char *LongIntegerToString(
    return(ValueToString(thePtr));
   }
 
+/*******************************************************************/
+/* DataObjectToString: Converts a DATA_OBJECT to KB string format. */
+/*******************************************************************/
+globle char *DataObjectToString(
+  void *theEnv,
+  DATA_OBJECT *theDO)
+  {
+   void *thePtr;
+   char *theString, *newString;
+   char *prefix, *postfix;
+   unsigned int length;
+   char buffer[30];
+   
+   switch (GetpType(theDO))
+     {
+      case MULTIFIELD:
+         prefix = "(";
+         theString = ValueToString(ImplodeMultifield(theEnv,theDO));
+         postfix = ")";
+         break;
+         
+      case STRING:
+         prefix = "\"";
+         theString = DOPToString(theDO);
+         postfix = "\"";
+         break;
+         
+      case INSTANCE_NAME:
+         prefix = "[";
+         theString = DOPToString(theDO);
+         postfix = "]";
+         break;
+         
+      case SYMBOL:
+         return(DOPToString(theDO));
+         
+      case FLOAT:
+         return(FloatToString(theEnv,DOPToDouble(theDO)));
+         
+      case INTEGER:
+         return(LongIntegerToString(theEnv,DOPToLong(theDO)));
+         
+      case RVOID:
+         return("");
+
+#if OBJECT_SYSTEM
+      case INSTANCE_ADDRESS:
+         thePtr = DOPToPointer(theDO);
+
+         if (thePtr == (void *) &InstanceData(theEnv)->DummyInstance)
+           { return("<Dummy Instance>"); }
+           
+         if (((struct instance *) thePtr)->garbage)
+           {
+            prefix = "<Stale Instance-";
+            theString = ValueToString(((struct instance *) thePtr)->name);
+            postfix = ">";
+           }
+         else
+           {
+            prefix = "<Instance-";
+            theString = ValueToString(GetFullInstanceName(theEnv,(INSTANCE_TYPE *) thePtr));
+            postfix = ">";
+           }
+           
+        break;
+#endif
+      
+      case EXTERNAL_ADDRESS:
+        sprintf(buffer,"<Pointer-%p>",DOPToPointer(theDO));
+        thePtr = EnvAddSymbol(theEnv,buffer);
+        return(ValueToString(thePtr));
+
+#if DEFTEMPLATE_CONSTRUCT      
+      case FACT_ADDRESS:
+         if (DOPToPointer(theDO) == (void *) &FactData(theEnv)->DummyFact)
+           { return("<Dummy Fact>"); }
+         
+         thePtr = DOPToPointer(theDO);
+         sprintf(buffer,"<Fact-%ld>",((struct fact *) thePtr)->factIndex);
+         thePtr = EnvAddSymbol(theEnv,buffer);
+         return(ValueToString(thePtr));
+#endif
+                        
+      default:
+         return("TBD");
+     }
+     
+   length = strlen(prefix) + strlen(theString) + strlen(postfix) + 1;
+   newString = (char *) genalloc(theEnv,length);
+   newString[0] = '\0';
+   strcat(newString,prefix);
+   strcat(newString,theString);
+   strcat(newString,postfix);
+   thePtr = EnvAddSymbol(theEnv,newString);
+   genfree(theEnv,newString,length);
+   return(ValueToString(thePtr));
+  }
+  
 /************************************************************/
 /* SalienceInformationError: Error message for errors which */
 /*   occur during the evaluation of a salience value.       */
@@ -447,3 +579,22 @@ globle void SalienceNonIntegerError(
    EnvPrintRouter(theEnv,WERROR,"Salience value must be an integer value.\n");
   }
 
+/***************************************************/
+/* SlotExistError: Prints out an appropriate error */
+/*   message when a slot cannot be found for a     */
+/*   function. Input to the function is the slot   */
+/*   name and the function name.                   */
+/***************************************************/
+globle void SlotExistError(
+  void *theEnv,
+  char *sname,
+  char *func)
+  {
+   PrintErrorID(theEnv,"INSFUN",3,FALSE);
+   EnvPrintRouter(theEnv,WERROR,"No such slot ");
+   EnvPrintRouter(theEnv,WERROR,sname);
+   EnvPrintRouter(theEnv,WERROR," in function ");
+   EnvPrintRouter(theEnv,WERROR,func);
+   EnvPrintRouter(theEnv,WERROR,".\n");
+   SetEvaluationError(theEnv,TRUE);
+  }
