@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.21  06/15/03            */
+   /*             CLIPS Version 6.24  06/02/06            */
    /*                                                     */
    /*         CONSTRUCT PROFILING FUNCTIONS MODULE        */
    /*******************************************************/
@@ -16,6 +16,18 @@
 /* Contributing Programmer(s):                               */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Modified OutputProfileInfo to allow a before   */
+/*            and after prefix so that a string buffer does  */
+/*            not need to be created to contain the entire   */
+/*            prefix. This allows a buffer overflow problem  */
+/*            to be corrected. DR0857.                       */
+/*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Added pragmas to remove compilation warnings.  */
+/*                                                           */
+/*            Corrected code to remove run-time program      */
+/*            compiler warnings.                             */
 /*                                                           */
 /*************************************************************/
 
@@ -51,10 +63,13 @@
 /* LOCAL INTERNAL FUNCTION DEFINITIONS */
 /***************************************/
 
-   static BOOLEAN                     OutputProfileInfo(void *,char *,struct constructProfileInfo *,char *,char **);
+   static intBool                     OutputProfileInfo(void *,char *,struct constructProfileInfo *,
+                                                        char *,char *,char *,char **);
    static void                        OutputUserFunctionsInfo(void *);
    static void                        OutputConstructsCodeInfo(void *);
+#if (! RUN_TIME)
    static void                        ProfileClearFunction(void *);
+#endif
 
 /******************************************************/
 /* ConstructProfilingFunctionDefinitions: Initializes */
@@ -150,7 +165,7 @@ globle void ProfileCommand(
 /* Profile: C access routine  */
 /*   for the profile command. */
 /******************************/
-globle BOOLEAN Profile(
+globle intBool Profile(
   void *theEnv,
   char *argument)
   {
@@ -278,7 +293,7 @@ globle void StartProfile(
   void *theEnv,
   struct profileFrameInfo *theFrame,
   struct userData **theList,
-  BOOLEAN checkFlag)
+  intBool checkFlag)
   {
    double startTime, addTime;
    struct constructProfileInfo *profileInfo;
@@ -349,11 +364,13 @@ globle void EndProfile(
 /* OutputProfileInfo: Prints out a single */
 /*   line of profile information.         */
 /******************************************/
-static BOOLEAN OutputProfileInfo(
+static intBool OutputProfileInfo(
   void *theEnv,
   char *itemName,
   struct constructProfileInfo *profileInfo,
+  char *printPrefixBefore,
   char *printPrefix,
+  char *printPrefixAfter,
   char **banner)
   {
    double percent = 0.0, percentWithKids = 0.0;
@@ -378,10 +395,16 @@ static BOOLEAN OutputProfileInfo(
       EnvPrintRouter(theEnv,WDISPLAY,*banner);
       *banner = NULL;
      }
+
+   if (printPrefixBefore != NULL)
+     { EnvPrintRouter(theEnv,WDISPLAY,printPrefixBefore); }
    
    if (printPrefix != NULL)
      { EnvPrintRouter(theEnv,WDISPLAY,printPrefix); }
 
+   if (printPrefixAfter != NULL)
+     { EnvPrintRouter(theEnv,WDISPLAY,printPrefixAfter); }
+
    if (strlen(itemName) >= 40)
      {
       EnvPrintRouter(theEnv,WDISPLAY,itemName);
@@ -541,8 +564,9 @@ static void OutputUserFunctionsInfo(
      {
       OutputProfileInfo(theEnv,ValueToString(theFunction->callFunctionName),
                         (struct constructProfileInfo *) 
-                           TestUserData(ProfileFunctionData(theEnv)->ProfileDataID,theFunction->usrData),
-                        NULL,NULL);
+                           TestUserData(ProfileFunctionData(theEnv)->ProfileDataID,
+                        theFunction->usrData),
+                        NULL,NULL,NULL,NULL);
      }
 
    for (i = 0; i < MAXIMUM_PRIMITIVES; i++)
@@ -551,8 +575,9 @@ static void OutputUserFunctionsInfo(
         {
          OutputProfileInfo(theEnv,EvaluationData(theEnv)->PrimitivesArray[i]->name,
                            (struct constructProfileInfo *)
-                              TestUserData(ProfileFunctionData(theEnv)->ProfileDataID,EvaluationData(theEnv)->PrimitivesArray[i]->usrData),
-                           NULL,NULL);
+                              TestUserData(ProfileFunctionData(theEnv)->ProfileDataID,
+                           EvaluationData(theEnv)->PrimitivesArray[i]->usrData),
+                           NULL,NULL,NULL,NULL);
         }
      }
   }
@@ -560,9 +585,15 @@ static void OutputUserFunctionsInfo(
 /*************************************************/
 /* OutputConstructsCodeInfo:       */
 /*************************************************/
+#if IBM_TBC && (! DEFFUNCTION_CONSTRUCT) && (! DEFGENERIC_CONSTRUCT) && (! OBJECT_SYSTEM) && (! DEFRULE_CONSTRUCT)
+#pragma argsused
+#endif
 static void OutputConstructsCodeInfo(
   void *theEnv)
   {
+#if (! DEFFUNCTION_CONSTRUCT) && (! DEFGENERIC_CONSTRUCT) && (! OBJECT_SYSTEM) && (! DEFRULE_CONSTRUCT)
+#pragma unused(theEnv)
+#endif
 #if DEFFUNCTION_CONSTRUCT
    DEFFUNCTION *theDeffunction;
 #endif
@@ -580,8 +611,9 @@ static void OutputConstructsCodeInfo(
    HANDLER *theHandler;
    unsigned handlerIndex;
 #endif
-   char buffer[512];
-   char *prefix;
+#if DEFGENERIC_CONSTRUCT || OBJECT_SYSTEM
+   char *prefix, *prefixBefore, *prefixAfter;
+#endif
    char *banner;
 
    banner = "\n*** Deffunctions ***\n\n";
@@ -594,7 +626,7 @@ static void OutputConstructsCodeInfo(
       OutputProfileInfo(theEnv,EnvGetDeffunctionName(theEnv,theDeffunction),
                         (struct constructProfileInfo *) 
                           TestUserData(ProfileFunctionData(theEnv)->ProfileDataID,theDeffunction->header.usrData),
-                        NULL,&banner);
+                        NULL,NULL,NULL,&banner);
      }
 #endif
 
@@ -604,8 +636,9 @@ static void OutputConstructsCodeInfo(
         theDefgeneric != NULL;
         theDefgeneric = (DEFGENERIC *) EnvGetNextDefgeneric(theEnv,theDefgeneric))
      {
-      sprintf(buffer,"\n%s\n",EnvGetDefgenericName(theEnv,theDefgeneric));
-      prefix = buffer;
+      prefixBefore = "\n";
+      prefix = EnvGetDefgenericName(theEnv,theDefgeneric);
+      prefixAfter = "\n";
 
       for (methodIndex = EnvGetNextDefmethod(theEnv,theDefgeneric,0);
            methodIndex != 0;
@@ -617,8 +650,12 @@ static void OutputConstructsCodeInfo(
          if (OutputProfileInfo(theEnv,methodBuffer,
                                (struct constructProfileInfo *) 
                                   TestUserData(ProfileFunctionData(theEnv)->ProfileDataID,theMethod->usrData),
-                               prefix,&banner))
-           { prefix = NULL; }
+                               prefixBefore,prefix,prefixAfter,&banner))
+           {
+            prefixBefore = NULL; 
+            prefix = NULL; 
+            prefixAfter = NULL;
+           }
         }
      }
 #endif
@@ -629,8 +666,10 @@ static void OutputConstructsCodeInfo(
         theDefclass != NULL;
         theDefclass = (DEFCLASS *) EnvGetNextDefclass(theEnv,theDefclass))
      {
-      sprintf(buffer,"\n%s\n",EnvGetDefclassName(theEnv,theDefclass));
-      prefix = buffer;
+      prefixAfter = "\n";
+      prefix = EnvGetDefclassName(theEnv,theDefclass);
+      prefixBefore = "\n";
+      
       for (handlerIndex = EnvGetNextDefmessageHandler(theEnv,theDefclass,0);
            handlerIndex != 0;
            handlerIndex = EnvGetNextDefmessageHandler(theEnv,theDefclass,handlerIndex))
@@ -638,15 +677,19 @@ static void OutputConstructsCodeInfo(
          theHandler = GetDefmessageHandlerPointer(theDefclass,handlerIndex);
          if (OutputProfileInfo(theEnv,EnvGetDefmessageHandlerName(theEnv,theDefclass,handlerIndex),
                                (struct constructProfileInfo *) 
-                                  TestUserData(ProfileFunctionData(theEnv)->ProfileDataID,theHandler->usrData),
-                           prefix,&banner))
-           { prefix = NULL; }
+                                  TestUserData(ProfileFunctionData(theEnv)->ProfileDataID,
+                               theHandler->usrData),
+                               prefixBefore,prefix,prefixAfter,&banner))
+           {
+            prefixBefore = NULL; 
+            prefix = NULL; 
+            prefixAfter = NULL;
+           }
         }
 
      }
 #endif
 
-
    banner = "\n*** Defrules ***\n\n";
 
 #if DEFRULE_CONSTRUCT
@@ -657,7 +700,7 @@ static void OutputConstructsCodeInfo(
       OutputProfileInfo(theEnv,EnvGetDefruleName(theEnv,theDefrule),
                         (struct constructProfileInfo *) 
                           TestUserData(ProfileFunctionData(theEnv)->ProfileDataID,theDefrule->header.usrData),
-                        NULL,&banner);
+                        NULL,NULL,NULL,&banner);
      }
 #endif
 
@@ -754,7 +797,8 @@ globle char *SetProfileOutputString(
 
    return(oldOutputString);
   }
-  
+
+#if (! RUN_TIME)  
 /******************************************************************/
 /* ProfileClearFunction: Profiling clear routine for use with the */
 /*   clear command. Removes user data attached to user functions. */
@@ -782,6 +826,7 @@ static void ProfileClearFunction(
         }
      }
   }
-  
+#endif
+
 #endif /* PROFILING_FUNCTIONS */
 
