@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  05/17/06            */
    /*                                                     */
    /*                 RETE UTILITY MODULE                 */
    /*******************************************************/
@@ -17,6 +17,11 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Removed INCREMENTAL_RESET compilation flag.    */
+/*                                                           */
+/*            Rule with exists CE has incorrect activation.  */
+/*            DR0867                                         */
+/*                                                           */
 /*************************************************************/
 
 #define _RETEUTIL_SOURCE_
@@ -150,7 +155,7 @@ globle void InitializePatternHeader(
   void *theEnv,
   struct patternNodeHeader *theHeader)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
    theHeader->entryJoin = NULL;
@@ -159,7 +164,7 @@ globle void InitializePatternHeader(
    theHeader->singlefieldNode = FALSE;
    theHeader->multifieldNode = FALSE;
    theHeader->stopNode = FALSE;
-#if INCREMENTAL_RESET && (! RUN_TIME)
+#if (! RUN_TIME)
    theHeader->initialize = EnvGetIncrementalReset(theEnv);
 #else
    theHeader->initialize = FALSE;
@@ -387,6 +392,25 @@ globle void DestroyAlphaBetaMemory(
      }
   }
 
+/******************************************************/
+/* FindEntityInPartialMatch: Searches for a specified */
+/*   data entity in a partial match.                  */
+/******************************************************/
+globle int FindEntityInPartialMatch(
+  struct patternEntity *theEntity,
+  struct partialMatch *thePartialMatch)
+  {
+   short int i;
+
+   for (i = 0 ; i < (int) thePartialMatch->bcount; i++)
+     {
+      if (thePartialMatch->binds[i].gm.theMatch->matchingItem == theEntity)
+        { return(TRUE); }
+     }
+
+   return(FALSE);
+  }
+
 /***********************************************************************/
 /* GetPatternNumberFromJoin: Given a pointer to a join associated with */
 /*   a pattern CE, returns an integer representing the position of the */
