@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.21  06/15/03            */
+   /*             CLIPS Version 6.24  05/17/06            */
    /*                                                     */
    /*                   RETRACT MODULE                    */
    /*******************************************************/
@@ -18,6 +18,13 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Removed LOGICAL_DEPENDENCIES compilation flag. */
+/*                                                           */
+/*            Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Rule with exists CE has incorrect activation.  */
+/*            DR0867                                         */
+/*                                                           */
 /*************************************************************/
 
 #define _RETRACT_SOURCE_
@@ -36,16 +43,14 @@
 #include "drive.h"
 #include "engine.h"
 #include "envrnmnt.h"
+#include "lgcldpnd.h"
 #include "match.h"
 #include "memalloc.h"
 #include "network.h"
+#include "reteutil.h"
 #include "router.h"
 #include "symbol.h"
 
-#if LOGICAL_DEPENDENCIES
-#include "lgcldpnd.h"
-#endif
-
 #include "retract.h"
 
 /***************************************/
@@ -59,10 +64,10 @@
    static void                    DeletePartialMatches(void *,struct partialMatch *,int);
    static void                    ReturnMarkers(void *,struct multifieldMarker *);
    static void                    DriveRetractions(void *);
-   static BOOLEAN                 FindNextConflictingAlphaMatch(void *,struct partialMatch *,
+   static intBool                 FindNextConflictingAlphaMatch(void *,struct partialMatch *,
                                                                 struct partialMatch *,
                                                                 struct joinNode *);
-   static BOOLEAN                 PartialMatchDefunct(void *,struct partialMatch *);
+   static intBool                 PartialMatchDefunct(void *,struct partialMatch *);
 
 /************************************************************/
 /* NetworkRetract:  Retracts a data entity (such as a fact  */
@@ -114,7 +119,7 @@ globle void NetworkRetract(
            { PosEntryRetract(theEnv,joinPtr,
                              listOfMatchedPatterns->theMatch->binds[0].gm.theMatch,
                              listOfMatchedPatterns->theMatch,
-                             (int) joinPtr->depth - 1,TRUE); }
+                             (int) joinPtr->depth - 1,listOfMatchedPatterns->theMatch->binds[0].gm.theMatch->matchingItem); }
         }
      }
 
@@ -143,7 +148,9 @@ globle void NetworkRetract(
                EnvExitRouter(theEnv,EXIT_FAILURE);
               }
             else
-              { NegEntryRetract(theEnv,joinPtr,listOfMatchedPatterns->theMatch,TRUE); }
+              { 
+               NegEntryRetract(theEnv,joinPtr,listOfMatchedPatterns->theMatch,listOfMatchedPatterns->theMatch->binds[0].gm.theMatch->matchingItem); 
+              }
            }
         }
 
@@ -186,7 +193,7 @@ globle void PosEntryRetract(
   struct alphaMatch *theAlphaNode,
   struct partialMatch *theMatch,
   int position,
-  int duringRetract)
+  void *duringRetract)
   {
    struct partialMatch *deletedMatches;
    struct joinNode *joinPtr;
@@ -258,7 +265,7 @@ void NegEntryRetract(
   void *theEnv,
   struct joinNode *theJoin,
   struct partialMatch *theMatch,
-  int duringRetract)
+  void *duringRetract)
   {
    struct partialMatch *theLHS;
    int result;
@@ -341,13 +348,16 @@ void NegEntryRetract(
               { NetworkAssert(theEnv,theLHS,listOfJoins,RHS); }
             else
               {
-               if (duringRetract)
+               if (duringRetract != NULL)
                  {
-                  tempDR = get_struct(theEnv,rdriveinfo);
-                  tempDR->link = theLHS;
-                  tempDR->jlist = theJoin->nextLevel;
-                  tempDR->next = EngineData(theEnv)->DriveRetractionList;
-                  EngineData(theEnv)->DriveRetractionList = tempDR;
+                  if (FindEntityInPartialMatch((struct patternEntity *) duringRetract,theLHS) == FALSE)
+                    {
+                     tempDR = get_struct(theEnv,rdriveinfo);
+                     tempDR->link = theLHS;
+                     tempDR->jlist = theJoin->nextLevel;
+                     tempDR->next = EngineData(theEnv)->DriveRetractionList;
+                     EngineData(theEnv)->DriveRetractionList = tempDR;
+                    }
                  }
                else while (listOfJoins != NULL)
                  {
@@ -367,7 +377,7 @@ void NegEntryRetract(
 /*   match in the beta memory of the join from being          */
 /*   satisfied.                                               */
 /**************************************************************/
-static BOOLEAN FindNextConflictingAlphaMatch(
+static intBool FindNextConflictingAlphaMatch(
   void *theEnv,
   struct partialMatch *theBind,
   struct partialMatch *possibleConflicts,
@@ -498,7 +508,7 @@ static BOOLEAN FindNextConflictingAlphaMatch(
 /*   this partial match was generated. Assumes counterf is */
 /*   FALSE.                                                */
 /***********************************************************/
-static BOOLEAN PartialMatchDefunct(
+static intBool PartialMatchDefunct(
   void *theEnv,
   struct partialMatch *thePM)
   {
@@ -697,9 +707,7 @@ static void DeletePartialMatches(
       /* result of a logical CE.                        */
       /*================================================*/
 
-#if LOGICAL_DEPENDENCIES
       if (listOfPMs->dependentsf) RemoveLogicalSupport(theEnv,listOfPMs);
-#endif
 
       /*==========================================================*/
       /* If the partial match is being deleted from a beta memory */
@@ -772,9 +780,7 @@ globle void ReturnPartialMatch(
    /* the logical CE.                                 */
    /*=================================================*/
 
-#if LOGICAL_DEPENDENCIES
    if (waste->dependentsf) RemovePMDependencies(theEnv,waste);
-#endif
 
    /*======================================================*/
    /* Return the partial match to the pool of free memory. */
@@ -827,9 +833,7 @@ globle void DestroyPartialMatch(
    /* the logical CE.                                 */
    /*=================================================*/
 
-#if LOGICAL_DEPENDENCIES
    if (waste->dependentsf) DestroyPMDependencies(theEnv,waste);
-#endif
 
    /*======================================================*/
    /* Return the partial match to the pool of free memory. */
