@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  07/01/05            */
    /*                                                     */
    /*                  I/O ROUTER MODULE                  */
    /*******************************************************/
@@ -17,6 +17,13 @@
 /*      Brian L. Donnell                                     */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.24: Removed conversion of '\r' to '\n' from the    */
+/*            EnvGetcRouter function.                        */
+/*                                                           */
+/*            Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Added support for passing context information  */ 
+/*            to the router functions.                       */
 /*                                                           */
 /*************************************************************/
 
@@ -113,6 +120,7 @@ globle int EnvPrintRouter(
    currentPtr = RouterData(theEnv)->ListOfRouters;
    while (currentPtr != NULL)
      {
+      SetEnvironmentRouterContext(theEnv,currentPtr->context);
       if ((currentPtr->printer != NULL) ? QueryRouter(theEnv,logicalName,currentPtr) : FALSE)
         {
          if (currentPtr->environmentAware)
@@ -160,7 +168,7 @@ globle int EnvGetcRouter(
            { IncrementLineCount(theEnv); }
         }
 
-      if (inchar == '\r') return('\n');
+      /* if (inchar == '\r') return('\n'); */
 
       return(inchar);
      }
@@ -186,7 +194,7 @@ globle int EnvGetcRouter(
            { IncrementLineCount(theEnv); }
         }
 
-      if (inchar == '\r') return('\n');
+      /* if (inchar == '\r') return('\n'); */
 
       return(inchar);
      }
@@ -213,7 +221,7 @@ globle int EnvGetcRouter(
               { IncrementLineCount(theEnv); }
            }
 
-         if (inchar == '\r') return('\n');
+         /* if (inchar == '\r') return('\n'); */
          /*
          if (inchar != '\b')
            { return(inchar); }
@@ -380,7 +388,7 @@ globle void AbortExit(
 /*********************************************************/
 /* AddRouter: Adds an I/O router to the list of routers. */
 /*********************************************************/
-globle BOOLEAN AddRouter(
+globle intBool AddRouter(
   char *routerName,
   int priority,
   int (*queryFunction)(char *),
@@ -400,6 +408,7 @@ globle BOOLEAN AddRouter(
    newPtr->active = TRUE;
    newPtr->environmentAware = FALSE;
    newPtr->priority = priority;
+   newPtr->context = NULL;
    newPtr->query = (int (*)(void *,char *)) queryFunction;
    newPtr->printer = (int (*)(void *,char *,char *)) printFunction;
    newPtr->exiter = (int (*)(void *,int)) exitFunction;
@@ -439,7 +448,7 @@ globle BOOLEAN AddRouter(
 /************************************************************/
 /* EnvAddRouter: Adds an I/O router to the list of routers. */
 /************************************************************/
-globle BOOLEAN EnvAddRouter(
+globle intBool EnvAddRouter(
   void *theEnv,
   char *routerName,
   int priority,
@@ -448,6 +457,25 @@ globle BOOLEAN EnvAddRouter(
   int (*getcFunction)(void *,char *),
   int (*ungetcFunction)(void *,int,char *),
   int (*exitFunction)(void *,int))
+  {
+   return EnvAddRouterWithContext(theEnv,routerName,priority,
+                                  queryFunction,printFunction,getcFunction,
+                                  ungetcFunction,exitFunction,NULL);
+  }
+
+/***********************************************************************/
+/* EnvAddRouterWithContext: Adds an I/O router to the list of routers. */
+/***********************************************************************/
+globle intBool EnvAddRouterWithContext(
+  void *theEnv,
+  char *routerName,
+  int priority,
+  int (*queryFunction)(void *,char *),
+  int (*printFunction)(void *,char *,char *),
+  int (*getcFunction)(void *,char *),
+  int (*ungetcFunction)(void *,int,char *),
+  int (*exitFunction)(void *,int),
+  void *context)
   {
    struct router *newPtr, *lastPtr, *currentPtr;
 
@@ -456,6 +484,7 @@ globle BOOLEAN EnvAddRouter(
    newPtr->name = routerName;
    newPtr->active = TRUE;
    newPtr->environmentAware = TRUE;
+   newPtr->context = context;
    newPtr->priority = priority;
    newPtr->query = queryFunction;
    newPtr->printer = printFunction;
