@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  05/17/06            */
    /*                                                     */
    /*                  RULE BUILD MODULE                  */
    /*******************************************************/
@@ -22,6 +22,10 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Removed INCREMENTAL_RESET compilation flag.    */
+/*                                                           */
+/*            Corrected code to remove compiler warnings.    */
+/*                                                           */
 /*************************************************************/
 
 #define _RULEBLD_SOURCE_
@@ -224,7 +228,7 @@ static void AttachTestCEsToPatternCEs(
   void *theEnv,
   struct lhsParseNode *theLHS)
   {
-   struct lhsParseNode *lastNode, *trackNode, *tempNode;
+   struct lhsParseNode *lastNode = NULL, *trackNode, *tempNode;
 
    /*===============================================*/
    /* Look at each pattern on the rule's LHS to see */
@@ -524,11 +528,7 @@ static struct joinNode *CreateNewJoin(
    newJoin->nextLevel = NULL;
    newJoin->joinFromTheRight = joinFromTheRight;
    newJoin->patternIsNegated = negatedRHSPattern;
-#if INCREMENTAL_RESET
    newJoin->initialize = EnvGetIncrementalReset(theEnv);
-#else
-   newJoin->initialize = FALSE;
-#endif
    newJoin->logicalJoin = FALSE;
    newJoin->ruleToActivate = NULL;
 
