@@ -2,7 +2,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  05/17/06            */
    /*                                                     */
    /*            DEFRULE CONSTRUCTS-TO-C MODULE           */
    /*******************************************************/
@@ -19,6 +19,9 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Removed DYNAMIC_SALIENCE and                   */
+/*            LOGICAL_DEPENDENCIES compilation flags.        */
+/*                                                           */
 /*************************************************************/
 
 #define _RULECMP_SOURCE_
@@ -255,7 +258,7 @@ static void DefruleModuleToCode(
   int maxIndices,
   int moduleCount)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(moduleCount)
 #endif
 
@@ -303,10 +306,8 @@ static void DefruleToCode(
    /* Dynamic Salience */
    /*==================*/
 
-#if DYNAMIC_SALIENCE
       ExpressionToCode(theEnv,theFile,theDefrule->dynamicSalience);
       fprintf(theFile,",");
-#endif
 
    /*=============*/
    /* RHS Actions */
@@ -319,7 +320,6 @@ static void DefruleToCode(
    /* Logical Dependency Join */
    /*=========================*/
 
-#if LOGICAL_DEPENDENCIES
    if (theDefrule->logicalJoin != NULL)
      {
       fprintf(theFile,"&%s%d_%ld[%ld],",JoinPrefix(),
@@ -328,7 +328,6 @@ static void DefruleToCode(
      }
    else
      { fprintf(theFile,"NULL,"); }
-#endif
 
    /*===========*/
    /* Last Join */
