@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.21  06/15/03            */
+   /*             CLIPS Version 6.23  01/31/05            */
    /*                                                     */
    /*               STRING FUNCTIONS MODULE               */
    /*******************************************************/
@@ -19,6 +19,7 @@
 /*      Barry Cameron                                        */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Correction for FalseSymbol/TrueSymbol. DR0859  */
 /*                                                           */
 /*************************************************************/
 
@@ -78,7 +79,7 @@ globle void StringFunctionDefinitions(
    EnvDefineFunction2(theEnv,"build", 'b', PTIEF BuildFunction, "BuildFunction", "11k");
    EnvDefineFunction2(theEnv,"string-to-field", 'u', PTIEF StringToFieldFunction, "StringToFieldFunction", "11j");
 #else
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 #endif
@@ -535,7 +536,7 @@ globle void StrIndexFunction(
    int i, j;
 
    result->type = SYMBOL;
-   result->value = SymbolData(theEnv)->FalseSymbol;
+   result->value = EnvFalseSymbol(theEnv);
 
    /*===================================*/
    /* Check and retrieve the arguments. */
@@ -683,7 +684,7 @@ globle void EvalFunction(
    if (EnvArgCountCheck(theEnv,"eval",EXACTLY,1) == -1)
      {
       SetpType(returnValue,SYMBOL);
-      SetpValue(returnValue,SymbolData(theEnv)->FalseSymbol);
+      SetpValue(returnValue,EnvFalseSymbol(theEnv));
       return;
      }
 
@@ -694,7 +695,7 @@ globle void EvalFunction(
    if (EnvArgTypeCheck(theEnv,"eval",1,SYMBOL_OR_STRING,&theArg) == FALSE)
      {
       SetpType(returnValue,SYMBOL);
-      SetpValue(returnValue,SymbolData(theEnv)->FalseSymbol);
+      SetpValue(returnValue,EnvFalseSymbol(theEnv));
       return;
      }
 
@@ -730,7 +731,7 @@ globle int EnvEval(
    if (OpenStringSource(theEnv,logicalNameBuffer,theString,0) == 0)
      {
       SetpType(returnValue,SYMBOL);
-      SetpValue(returnValue,SymbolData(theEnv)->FalseSymbol);
+      SetpValue(returnValue,EnvFalseSymbol(theEnv));
       depth--;
       return(FALSE);
      }
@@ -768,7 +769,7 @@ globle int EnvEval(
       SetEvaluationError(theEnv,TRUE);
       CloseStringSource(theEnv,logicalNameBuffer);
       SetpType(returnValue,SYMBOL);
-      SetpValue(returnValue,SymbolData(theEnv)->FalseSymbol);
+      SetpValue(returnValue,EnvFalseSymbol(theEnv));
       depth--;
       return(FALSE);
      }
@@ -785,7 +786,7 @@ globle int EnvEval(
       SetEvaluationError(theEnv,TRUE);
       CloseStringSource(theEnv,logicalNameBuffer);
       SetpType(returnValue,SYMBOL);
-      SetpValue(returnValue,SymbolData(theEnv)->FalseSymbol);
+      SetpValue(returnValue,EnvFalseSymbol(theEnv));
       ReturnExpression(theEnv,top);
       depth--;
       return(FALSE);
@@ -803,7 +804,7 @@ globle int EnvEval(
       SetEvaluationError(theEnv,TRUE);
       CloseStringSource(theEnv,logicalNameBuffer);
       SetpType(returnValue,SYMBOL);
-      SetpValue(returnValue,SymbolData(theEnv)->FalseSymbol);
+      SetpValue(returnValue,EnvFalseSymbol(theEnv));
       ReturnExpression(theEnv,top);
       depth--;
       return(FALSE);
@@ -839,7 +840,7 @@ globle void EvalFunction(
    PrintErrorID(theEnv,"STRNGFUN",1,FALSE);
    EnvPrintRouter(theEnv,WERROR,"Function eval does not work in run time modules.\n");
    SetpType(returnValue,SYMBOL);
-   SetpValue(returnValue,SymbolData(theEnv)->FalseSymbol);
+   SetpValue(returnValue,EnvFalseSymbol(theEnv));
   }
 
 /*****************************************************/
@@ -851,14 +852,14 @@ globle int EnvEval(
   char *theString,
   DATA_OBJECT_PTR returnValue)
   {
-#if (MAC_MPW || MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY)
+#if (MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY)
 #pragma unused(theString)
 #endif
 
    PrintErrorID(theEnv,"STRNGFUN",1,FALSE);
    EnvPrintRouter(theEnv,WERROR,"Function eval does not work in run time modules.\n");
    SetpType(returnValue,SYMBOL);
-   SetpValue(returnValue,SymbolData(theEnv)->FalseSymbol);
+   SetpValue(returnValue,EnvFalseSymbol(theEnv));
    return(FALSE);
   }
 
@@ -996,15 +997,15 @@ globle int BuildFunction(
    return(FALSE);
   }
 
-/***************************************************/
-/* Build: This is the non-functional stub provided */
-/*   for use with a run-time version.              */
-/***************************************************/
-globle int Build(
+/******************************************************/
+/* EnvBuild: This is the non-functional stub provided */
+/*   for use with a run-time version.                 */
+/******************************************************/
+globle int EnvBuild(
   void *theEnv,
   char *theString)
-  {
-#if (MAC_MPW || MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY)
+  { 
+#if (MAC_MCW || IBM_MCW) && (RUN_TIME || BLOAD_ONLY)
 #pragma unused(theString)
 #endif
 
