@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*          DEFTEMPLATE RHS PARSING HEADER FILE        */
    /*******************************************************/
@@ -17,6 +17,12 @@
 /*                                                           */
 /* Revision History:                                         */
 /*                                                           */
+/*      6.24: Added additional argument required for         */
+/*            DeriveDefaultFromConstraints.                  */
+/*                                                           */
+/*            Added additional argument required for         */
+/*            InvalidDeftemplateSlotMessage.                 */
+/*                                                           */
 /*************************************************************/
 
 #define _TMPLTRHS_SOURCE_
@@ -226,7 +232,7 @@ static struct templateSlot *ParseSlotLabel(
    if ((slotPtr = FindSlot(theDeftemplate,(SYMBOL_HN *) tempToken->value,&position)) == NULL)
      {
       InvalidDeftemplateSlotMessage(theEnv,ValueToString(tempToken->value),
-                                    ValueToString(theDeftemplate->header.name));
+                                    ValueToString(theDeftemplate->header.name),TRUE);
       *error = TRUE;
       return(NULL);
      }
@@ -508,7 +514,7 @@ static struct expr *GetSlotAssertValues(
                (slotPtr->defaultDynamic == FALSE))
         {
          DeriveDefaultFromConstraints(theEnv,slotPtr->constraints,&theDefault,
-                                      (int) slotPtr->multislot);
+                                      (int) slotPtr->multislot,TRUE);
          newArg = ConvertValueToExpression(theEnv,&theDefault);
         }
 
