@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*            DEFTEMPLATE UTILITIES MODULE             */
    /*******************************************************/
@@ -16,6 +16,16 @@
 /*      Brian L. Donnell                                     */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Added support for templates maintaining their  */
+/*            own list of facts.                             */
+/*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Added additional arguments to                  */
+/*            InvalidDeftemplateSlotMessage function.        */
+/*                                                           */
+/*            Added additional arguments to                  */
+/*            PrintTemplateFact function.                    */
 /*                                                           */
 /*************************************************************/
 
@@ -55,9 +65,10 @@
 globle void InvalidDeftemplateSlotMessage(
   void *theEnv,
   char *slotName,
-  char *deftemplateName)
+  char *deftemplateName,
+  int printCR)
   {
-   PrintErrorID(theEnv,"TMPLTDEF",1,TRUE);
+   PrintErrorID(theEnv,"TMPLTDEF",1,printCR);
    EnvPrintRouter(theEnv,WERROR,"Invalid slot ");
    EnvPrintRouter(theEnv,WERROR,slotName);
    EnvPrintRouter(theEnv,WERROR," not defined in corresponding deftemplate ");
@@ -190,7 +201,7 @@ globle void CheckTemplateFact(
 /*   result of an assert, modify, or duplicate command. This checking  */
 /*   is performed statically (i.e. when the command is being parsed).  */
 /***********************************************************************/
-globle BOOLEAN CheckRHSSlotTypes(
+globle intBool CheckRHSSlotTypes(
   void *theEnv,
   struct expr *rhsSlots,
   struct templateSlot *slotPtr,
@@ -265,13 +276,17 @@ globle int FindSlotPosition(
 globle void PrintTemplateFact(
   void *theEnv,
   char *logicalName,
-  struct fact *theFact)
+  struct fact *theFact,
+  int seperateLines,
+  int ignoreDefaults)
   {
    struct field *sublist;
    int i;
    struct deftemplate *theDeftemplate;
    struct templateSlot *slotPtr;
-
+   DATA_OBJECT tempDO;
+   int slotPrinted = FALSE;
+   
    /*==============================*/
    /* Initialize some information. */
    /*==============================*/
@@ -285,7 +300,6 @@ globle void PrintTemplateFact(
 
    EnvPrintRouter(theEnv,logicalName,"(");
    EnvPrintRouter(theEnv,logicalName,theDeftemplate->header.name->contents);
-   if (theDeftemplate->slotList != NULL) EnvPrintRouter(theEnv,logicalName," ");
 
    /*===================================================*/
    /* Print each of the field slots of the deftemplate. */
@@ -295,11 +309,49 @@ globle void PrintTemplateFact(
 
    i = 0;
    while (slotPtr != NULL)
-     {
+     {         
+      /*=================================================*/
+      /* If we're ignoring slots with their original     */
+      /* default value, check to see if the fact's slot  */
+      /* value differs from the deftemplate default.     */
+      /*=================================================*/
+      
+      if (ignoreDefaults && (slotPtr->defaultDynamic == FALSE))
+        {
+         DeftemplateSlotDefault(theEnv,theDeftemplate,slotPtr,&tempDO,TRUE);
+         
+         if (slotPtr->multislot == FALSE)
+           {
+            if ((GetType(tempDO) == sublist[i].type) &&
+                (GetValue(tempDO) == sublist[i].value))
+              {     
+               i++;
+               slotPtr = slotPtr->next;
+               continue;
+              }
+           }
+         else if (MultifieldsEqual((struct multifield*) GetValue(tempDO),
+                                   (struct multifield *) sublist[i].value))
+           {
+            i++;
+            slotPtr = slotPtr->next;
+            continue;
+           }
+        }
+        
       /*===========================================*/
-      /* Print the closing parenthesis of the slot */
+      /* Print the opening parenthesis of the slot */
       /* and the slot name.                        */
       /*===========================================*/
+     
+      if (! slotPrinted) 
+        { 
+         slotPrinted = TRUE;
+         EnvPrintRouter(theEnv,logicalName," "); 
+        }
+
+      if (seperateLines)
+        { EnvPrintRouter(theEnv,logicalName,"\n   "); }
 
       EnvPrintRouter(theEnv,logicalName,"(");
       EnvPrintRouter(theEnv,logicalName,slotPtr->slotName->contents);
@@ -435,6 +487,8 @@ globle struct deftemplate *CreateImpliedDeftemplate(
    newDeftemplate->numberOfSlots = 0;
    newDeftemplate->inScope = 1;
    newDeftemplate->patternNetwork = NULL;
+   newDeftemplate->factList = NULL;
+   newDeftemplate->lastFact = NULL;
    newDeftemplate->busyCount = 0;
    newDeftemplate->watch = FALSE;
    newDeftemplate->header.next = NULL;
