@@ -1,7 +1,7 @@
    /*******************************************************/
    /*      "C" Language Integrated Production System      */
    /*                                                     */
-   /*             CLIPS Version 6.20  01/31/02            */
+   /*             CLIPS Version 6.24  06/05/06            */
    /*                                                     */
    /*                    WATCH MODULE                     */
    /*******************************************************/
@@ -18,6 +18,13 @@
 /*      Brian Donnell                                        */
 /*                                                           */
 /* Revision History:                                         */
+/*      6.23: Changed name of variable log to logName        */
+/*            because of Unix compiler warnings of shadowed  */
+/*            definitions.                                   */
+/*                                                           */
+/*      6.24: Renamed BOOLEAN macro type to intBool.         */
+/*                                                           */
+/*            Added EnvSetWatchItem function.                */
 /*                                                           */
 /*************************************************************/
 
@@ -44,7 +51,7 @@
 /***************************************/
 
    static struct watchItem       *ValidWatchItem(void *,char *,int *);
-   static BOOLEAN                 RecognizeWatchRouters(void *,char *);
+   static intBool                 RecognizeWatchRouters(void *,char *);
    static int                     CaptureWatchPrints(void *,char *,char *);
    static void                    DeallocateWatchData(void *);
 
@@ -82,7 +89,7 @@ static void DeallocateWatchData(
 /*   Returns FALSE if the item is already in the list,       */
 /*   otherwise returns TRUE.                                 */
 /*************************************************************/
-globle BOOLEAN AddWatchItem(
+globle intBool AddWatchItem(
   void *theEnv,
   char *name,
   int code,
@@ -143,28 +150,28 @@ globle BOOLEAN AddWatchItem(
 /*****************************************************/
 /* EnvWatch: C access routine for the watch command. */
 /*****************************************************/
-globle BOOLEAN EnvWatch(
+globle intBool EnvWatch(
   void *theEnv,
   char *itemName)
   {
-   return(SetWatchItem(theEnv,itemName,ON,NULL));
+   return(EnvSetWatchItem(theEnv,itemName,ON,NULL));
   }
 
 /*********************************************************/
 /* EnvUnwatch: C access routine for the unwatch command. */
 /*********************************************************/
-globle BOOLEAN EnvUnwatch(
+globle intBool EnvUnwatch(
   void *theEnv,
   char *itemName)
   {
-   return(SetWatchItem(theEnv,itemName,OFF,NULL));
+   return(EnvSetWatchItem(theEnv,itemName,OFF,NULL));
   }
 
-/********************************************************************/
-/* SetWatchItem: Sets the state of a specified watch item to either */
-/*   on or off. Returns TRUE if the item was set, otherwise FALSE.  */
-/********************************************************************/
-globle int SetWatchItem(
+/***********************************************************************/
+/* EnvSetWatchItem: Sets the state of a specified watch item to either */
+/*   on or off. Returns TRUE if the item was set, otherwise FALSE.     */
+/***********************************************************************/
+globle int EnvSetWatchItem(
   void *theEnv,
   char *itemName,
   unsigned newState,
@@ -376,7 +383,7 @@ globle void WatchCommand(
    /* Set the watch item. */
    /*=====================*/
 
-   SetWatchItem(theEnv,argument,ON,GetNextArgument(GetFirstArgument()));
+   EnvSetWatchItem(theEnv,argument,ON,GetNextArgument(GetFirstArgument()));
   }
 
 /****************************************/
@@ -423,7 +430,7 @@ globle void UnwatchCommand(
    /* Set the watch item. */
    /*=====================*/
 
-   SetWatchItem(theEnv,argument,OFF,GetNextArgument(GetFirstArgument()));
+   EnvSetWatchItem(theEnv,argument,OFF,GetNextArgument(GetFirstArgument()));
   }
 
 /************************************************/
@@ -565,15 +572,15 @@ globle void WatchFunctionDefinitions(
 #if IBM_TBC
 #pragma argsused
 #endif
-static BOOLEAN RecognizeWatchRouters(
+static intBool RecognizeWatchRouters(
   void *theEnv,
-  char *log)
+  char *logName)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
+#if MAC_MCW || IBM_MCW || MAC_XCD
 #pragma unused(theEnv)
 #endif
 
-   if (strcmp(log,WTRACE) == 0) return(TRUE);
+   if (strcmp(logName,WTRACE) == 0) return(TRUE);
 
    return(FALSE);
   }
@@ -586,11 +593,11 @@ static BOOLEAN RecognizeWatchRouters(
 #endif
 static int CaptureWatchPrints(
   void *theEnv,
-  char *log,
+  char *logName,
   char *str)
   {
-#if MAC_MPW || MAC_MCW || IBM_MCW
-#pragma unused(log)
+#if MAC_MCW || IBM_MCW || MAC_XCD
+#pragma unused(logName)
 #pragma unused(str)
 #pragma unused(theEnv)
 #endif
