@@ -58,7 +58,7 @@
 
 /********* Local functions visible outside this file **********/
 
-static void PeriodicUpdate(void);
+static void PeriodicUpdate(void *);
 static void UpdateWindowsMenu(void);
 static int GetEvent(void *);
 static int InitalizeLogTable(void);
@@ -88,11 +88,13 @@ LogNamePtr stdin_log, xclips_log,
 *******************************************************************************/
 void InitializeInterface()
   {
+   void *theEnv = GetCurrentEnvironment();
+
    if (! InitalizeLogTable())
      {
-      PrintRouter("werror", "Could not initialize logical name hash table\n");
-      XclipsExit(0);
-      ExitRouter(0);
+      EnvPrintRouter(theEnv,"werror", "Could not initialize logical name hash table\n");
+      XclipsExit(theEnv,0);
+      EnvExitRouter(theEnv,0);
      }
      
    //SetDribbleStatusFunction(GetCurrentEnvironment(),NULL);
@@ -101,7 +103,7 @@ void InitializeInterface()
    /* Tell CLIPS which GetEvent function to call when an event needed. */
    /*==================================================================*/
 
-   SetEventFunction(GetCurrentEnvironment(),GetEvent);
+   SetEventFunction(theEnv,GetEvent);
 
    /*  SetMemoryStatusFunction((int(*)())ActivateTheMenus());*/
 
@@ -109,21 +111,21 @@ void InitializeInterface()
    /* Tell CLIPS which function to call periodically. */
    /*=================================================*/
   
-   AddPeriodicFunction("PeriodicUpdate",PeriodicUpdate,90);
+   EnvAddPeriodicFunction(theEnv,"PeriodicUpdate",PeriodicUpdate,90);
    
    /*========================*/
    /* Add a main I/O router. */
    /*========================*/
    
-   if (! AddRouter("wclips", 10, XclipsQuery, XclipsPrint, XclipsGetc, XclipsUngetc,
+   if (! EnvAddRouter(theEnv,"wclips", 10, XclipsQuery, XclipsPrint, XclipsGetc, XclipsUngetc,
                 XclipsExit))
      {
       printf("Could not allocate xclips router!\n");
-      XclipsExit(0);
-      ExitRouter(0);
+      XclipsExit(theEnv,0);
+      EnvExitRouter(theEnv,0);
      }
      
-   PrintRouter("wclips", "                  XCLIPS for:");
+   EnvPrintRouter(theEnv,"wclips", "                  XCLIPS for:");
   }
 
 /*******************************************************************************
@@ -133,6 +135,7 @@ void InitializeInterface()
           Returns:      
 *******************************************************************************/
 int XclipsQuery(
+  void *theEnv,
   char *log_name)
   {
    return((LogLookup(log_name) != NULL) ? TRUE : FALSE);
@@ -147,6 +150,7 @@ int XclipsQuery(
           Returns:     unused
 *******************************************************************************/
 int XclipsPrint(
+  void *theEnv,
   char *log_name, 
   char *str)
   {
@@ -235,6 +239,7 @@ int XclipsPrint(
           Returns:       
 *******************************************************************************/
 int XclipsGetc(
+  void *theEnv,
   char *log_name)
   {
    int quit = False;
@@ -278,7 +283,7 @@ int XclipsGetc(
            }
          else if ((TheKeysym != XK_Delete) ? (TheKeysym == XK_BackSpace) :TRUE)
            {
-            if (RouterData(GetCurrentEnvironment())->CommandBufferInputCount != 0)
+            if (RouterData(theEnv)->CommandBufferInputCount != 0)
               {
                ch[0] = BACKSPACE;
                quit = True;
@@ -301,6 +306,7 @@ int XclipsGetc(
           Returns:       
 *******************************************************************************/
 int XclipsUngetc(
+  void *theEnv,
   int ch,
   char *log_name)
   {
@@ -317,10 +323,11 @@ int XclipsUngetc(
           Returns:       
 *******************************************************************************/
 int XclipsExit(
+  void *theEnv,
   int num)
   {
-   DribbleOff();
-   DeleteRouter("wclips");
+   EnvDribbleOff(theEnv);
+   EnvDeleteRouter(theEnv,"wclips");
    XtDestroyApplicationContext(app_con);
    ReleaseLogTable();
    exit(0);
@@ -334,12 +341,13 @@ int XclipsExit(
 *******************************************************************************/
 int PrintChangedAgenda()
   {
+   void *theEnv = GetCurrentEnvironment();
    VOID *rule_ptr;
    char buffer[MAX_CHAR_IN_BUF];
    char *name, labelBuffer[MAX_CHAR_IN_BUF];
    Window AgendaWin;
    Display *theDisplay;
-   struct defmodule* theModule = (struct defmodule *)GetCurrentModule();
+   struct defmodule* theModule = (struct defmodule *) EnvGetCurrentModule(theEnv);
 
    /*======================================================*/
    /* Change the name of the window to the current module. */
@@ -349,7 +357,7 @@ int PrintChangedAgenda()
    theDisplay = XtDisplay(agenda);
    if (theModule  != NULL)
      {
-      name = GetDefmoduleName(theModule);
+      name = EnvGetDefmoduleName(theEnv,theModule);
       strcpy(labelBuffer,"Agenda Window(");
       strcat(labelBuffer,name);
       strcat(labelBuffer,")");
@@ -373,13 +381,13 @@ int PrintChangedAgenda()
    /* Print the new agenda list. */
    /*============================*/
 
-   rule_ptr = GetNextActivation(NULL);
+   rule_ptr = EnvGetNextActivation(theEnv,NULL);
    while (rule_ptr != NULL)
      {
-      GetActivationPPForm(buffer,MAX_CHAR_IN_BUF - 1,rule_ptr);
-      PrintRouter("xagenda",buffer);
-      PrintRouter("xagenda", "\n");
-      rule_ptr = GetNextActivation(rule_ptr);
+      EnvGetActivationPPForm(theEnv,buffer,MAX_CHAR_IN_BUF - 1,rule_ptr);
+      EnvPrintRouter(theEnv,"xagenda",buffer);
+      EnvPrintRouter(theEnv,"xagenda", "\n");
+      rule_ptr = EnvGetNextActivation(theEnv,rule_ptr);
      }
     
    return 0;
@@ -393,12 +401,13 @@ int PrintChangedAgenda()
 *******************************************************************************/
 int PrintChangedFacts()
   {
+   void *theEnv = GetCurrentEnvironment();
   VOID *fact_ptr;
   char buffer[MAX_CHAR_IN_BUF];
   char *name,labelBuffer[MAX_CHAR_IN_BUF];
   Window FactWin;
   Display *theDisplay;
-  struct defmodule* theModule = (struct defmodule *)GetCurrentModule();
+  struct defmodule* theModule = (struct defmodule *) EnvGetCurrentModule(theEnv);
 
 
  /* Change the name of the window to the current module */
@@ -407,7 +416,7 @@ int PrintChangedFacts()
   theDisplay = XtDisplay(facts);
   if(theModule  != NULL)
      {
-       name = GetDefmoduleName(theModule);
+       name = EnvGetDefmoduleName(theEnv,theModule);
        strcpy(labelBuffer,"Fact Window(");
        strcat(labelBuffer,name);
        strcat(labelBuffer,")");
@@ -427,13 +436,13 @@ int PrintChangedFacts()
 
   /* Print the new fact list */
 
-  fact_ptr = GetNextFact(NULL);
+  fact_ptr = EnvGetNextFact(theEnv,NULL);
   while (fact_ptr != NULL)
     {
-    GetFactPPForm(buffer,MAX_CHAR_IN_BUF - 1,fact_ptr);
-    PrintRouter("xfacts",buffer);
-    PrintRouter("xfacts", "\n");
-    fact_ptr = GetNextFact(fact_ptr);
+    EnvGetFactPPForm(theEnv,buffer,MAX_CHAR_IN_BUF - 1,fact_ptr);
+    EnvPrintRouter(theEnv,"xfacts",buffer);
+    EnvPrintRouter(theEnv,"xfacts", "\n");
+    fact_ptr = EnvGetNextFact(theEnv,fact_ptr);
     }
   return 0;
   }
@@ -445,32 +454,32 @@ int PrintChangedFacts()
           Returns:
 *******************************************************************************/
 int PrintChangedInstances()
-{
-   int   n = 0;
+  {
+   void *theEnv = GetCurrentEnvironment();
+   int n = 0;
    VOID *instancePtr;
    char buffer[MAX_CHAR_IN_BUF];
-   char *name,labelBuffer[MAX_CHAR_IN_BUF];
+   char *name, labelBuffer[MAX_CHAR_IN_BUF];
    Window InstanceWin;
    Display *theDisplay;
-   struct defmodule* theModule = (struct defmodule *)GetCurrentModule();
+   struct defmodule* theModule = (struct defmodule *) EnvGetCurrentModule(theEnv);
 
+   /* Change the name of the window to the current module */
 
- /* Change the name of the window to the current module */
-
-    InstanceWin = XtWindow(instances);
-    theDisplay = XtDisplay(instances);
-    if(theModule  != NULL)
+   InstanceWin = XtWindow(instances);
+   theDisplay = XtDisplay(instances);
+   if (theModule != NULL)
      {
-       name = GetDefmoduleName(theModule);
-       strcpy(labelBuffer,"Instances Window(");
-       strcat(labelBuffer,name);
-       strcat(labelBuffer,")");
+      name = EnvGetDefmoduleName(theEnv,theModule);
+      strcpy(labelBuffer,"Instances Window(");
+      strcat(labelBuffer,name);
+      strcat(labelBuffer,")");
      }
-     else
+   else
      {
-       strcpy(labelBuffer,"Instances Window");
+      strcpy(labelBuffer,"Instances Window");
      }
-    XStoreName(theDisplay,InstanceWin,labelBuffer);
+   XStoreName(theDisplay,InstanceWin,labelBuffer);
 
 
    /* Clear the old contents */
@@ -479,16 +488,17 @@ int PrintChangedInstances()
    XtSetValues(instances_text,TheArgs,n);
    XawAsciiSourceFreeString(XawTextGetSource(instances_text));
    /* Print the new instance list */
-   instancePtr = (VOID*)GetNextInstance(NULL);
-   while(instancePtr != NULL)
-    {
-       GetInstancePPForm(buffer,MAX_CHAR_IN_BUF - 1,instancePtr);
-       PrintRouter("xinstances",buffer);
-       PrintRouter("xinstances","\n");
-       instancePtr = (VOID*)GetNextInstance(instancePtr);
-    }
+   instancePtr = (VOID *) EnvGetNextInstance(theEnv,NULL);
+   while (instancePtr != NULL)
+     {
+      EnvGetInstancePPForm(theEnv,buffer,MAX_CHAR_IN_BUF - 1,instancePtr);
+      EnvPrintRouter(theEnv,"xinstances",buffer);
+      EnvPrintRouter(theEnv,"xinstances","\n");
+      instancePtr = (VOID *) EnvGetNextInstance(theEnv,instancePtr);
+     }
+  
    return 0;
-}
+  }
 
 /*******************************************************************************
           Name:        PrintChangedGlobals
@@ -497,30 +507,31 @@ int PrintChangedInstances()
           Returns:
 *******************************************************************************/
 int PrintChangedGlobals()
-{
+  {
+   void *theEnv = GetCurrentEnvironment();
    VOID *dgPtr;
    int n;
    char *buffer;
    char *name,labelBuffer[MAX_CHAR_IN_BUF];
    Window GlobalWin;
    Display *theDisplay;
-   struct defmodule* theModule = (struct defmodule *)GetCurrentModule();
+   struct defmodule* theModule = (struct defmodule *) EnvGetCurrentModule(theEnv);
 
 
- /* Change the name of the window to the current module */
+   /* Change the name of the window to the current module */
 
-    GlobalWin = XtWindow(globals);
-    theDisplay = XtDisplay(globals);
-    if(theModule  != NULL)
+   GlobalWin = XtWindow(globals);
+   theDisplay = XtDisplay(globals);
+   if (theModule  != NULL)
      {
-       name = GetDefmoduleName(theModule);
-       strcpy(labelBuffer,"Globals Window(");
-       strcat(labelBuffer,name);
-       strcat(labelBuffer,")");
+      name = EnvGetDefmoduleName(theEnv,theModule);
+      strcpy(labelBuffer,"Globals Window(");
+      strcat(labelBuffer,name);
+      strcat(labelBuffer,")");
      }
-     else
+    else
      {
-       strcpy(labelBuffer,"Globals Window");
+      strcpy(labelBuffer,"Globals Window");
      }
     XStoreName(theDisplay,GlobalWin,labelBuffer);
 
@@ -533,16 +544,17 @@ int PrintChangedGlobals()
 
    /* Print the new defglobal list */
 
-   dgPtr = GetNextDefglobal(NULL);
-   while(dgPtr != NULL)
-    {
-      buffer = (char *) GetDefglobalPPForm((struct constructHeader *) dgPtr);
-      PrintRouter("xglobals",buffer);
-      PrintRouter("xglobals","\n");
-      dgPtr = GetNextDefglobal(dgPtr);
-    }
+   dgPtr = EnvGetNextDefglobal(theEnv,NULL);
+   while (dgPtr != NULL)
+     {
+      buffer = (char *) EnvGetDefglobalPPForm(theEnv,(struct constructHeader *) dgPtr);
+      EnvPrintRouter(theEnv,"xglobals",buffer);
+      EnvPrintRouter(theEnv,"xglobals","\n");
+      dgPtr = EnvGetNextDefglobal(theEnv,dgPtr);
+     }
+   
    return 0;
-}
+  }
 
 /*******************************************************************************
           Name:        PrintChangedFocus
@@ -551,7 +563,8 @@ int PrintChangedGlobals()
           Returns:
 *******************************************************************************/
 int PrintChangedFocus()
-{
+  {
+   void *theEnv = GetCurrentEnvironment();
    VOID *FocusPtr;
    int n;
    char *buffer;
@@ -564,13 +577,13 @@ int PrintChangedFocus()
 
    /* Print the new focus list */
 
-   FocusPtr = GetNextFocus(GetCurrentEnvironment(),NULL);
+   FocusPtr = EnvGetNextFocus(theEnv,NULL);
    while(FocusPtr != NULL)
     {
-      buffer = GetDefmoduleName(((struct focus*)FocusPtr)->theModule);
-      PrintRouter("xfocus",buffer);
-      PrintRouter("xfocus","\n");
-      FocusPtr = GetNextFocus(GetCurrentEnvironment(),FocusPtr);
+      buffer = EnvGetDefmoduleName(theEnv,((struct focus*)FocusPtr)->theModule);
+      EnvPrintRouter(theEnv,"xfocus",buffer);
+      EnvPrintRouter(theEnv,"xfocus","\n");
+      FocusPtr = EnvGetNextFocus(theEnv,FocusPtr);
     }
    return 0;
 }
@@ -584,50 +597,51 @@ int PrintChangedFocus()
 *******************************************************************************/
 void UpdateMenus()
   {
+   void *theEnv = GetCurrentEnvironment();
   static long LastModuleIndex = -1; 
   Boolean UpdateAll = False;
 
   UpdateWindowsMenu();
-  if(LastModuleIndex != DefmoduleData(GetCurrentEnvironment())->ModuleChangeIndex)
+  if(LastModuleIndex != DefmoduleData(theEnv)->ModuleChangeIndex)
    {
      UpdateAll = True;
-     LastModuleIndex = DefmoduleData(GetCurrentEnvironment())->ModuleChangeIndex;
+     LastModuleIndex = DefmoduleData(theEnv)->ModuleChangeIndex;
    }
 #if DEFRULE_CONSTRUCT
-  if((Browse_status[AGENDA_WIN] == True ) ? (UpdateAll || (GetAgendaChanged() == CLIPS_TRUE)) : FALSE)
+  if((Browse_status[AGENDA_WIN] == True ) ? (UpdateAll || (EnvGetAgendaChanged(theEnv) == CLIPS_TRUE)) : FALSE)
       {
-      SetAgendaChanged(CLIPS_FALSE);
+      EnvSetAgendaChanged(theEnv,CLIPS_FALSE);
       PrintChangedAgenda();
       }
 
- if((Browse_status[FOCUS_WIN] == True) ? ( UpdateAll || (GetFocusChanged(GetCurrentEnvironment()) == CLIPS_TRUE)) : FALSE)
+ if((Browse_status[FOCUS_WIN] == True) ? ( UpdateAll || (EnvGetFocusChanged(theEnv) == CLIPS_TRUE)) : FALSE)
      {
-     SetFocusChanged(GetCurrentEnvironment(),CLIPS_FALSE);
+     EnvSetFocusChanged(theEnv,CLIPS_FALSE);
      PrintChangedFocus();
      }
 
 #endif
 
 #if DEFTEMPLATE_CONSTRUCT
-  if((Browse_status[FACT_WIN] == True) ? ( UpdateAll || (GetFactListChanged() == CLIPS_TRUE)) : FALSE)
+  if((Browse_status[FACT_WIN] == True) ? ( UpdateAll || (EnvGetFactListChanged(theEnv) == CLIPS_TRUE)) : FALSE)
       {
-      SetFactListChanged(CLIPS_FALSE);
+      EnvSetFactListChanged(theEnv,CLIPS_FALSE);
       PrintChangedFacts();
       }
 #endif
 
 #if OBJECT_SYSTEM
- if((Browse_status[INSTANCE_WIN]) ? (UpdateAll || (GetInstancesChanged() == CLIPS_TRUE)) : FALSE)
+ if((Browse_status[INSTANCE_WIN]) ? (UpdateAll || (EnvGetInstancesChanged(theEnv) == CLIPS_TRUE)) : FALSE)
       {
-      SetInstancesChanged(CLIPS_FALSE);
+      EnvSetInstancesChanged(theEnv,CLIPS_FALSE);
       PrintChangedInstances();
       }
 #endif
 
 #ifdef DEFGLOBAL_CONSTRUCT
- if((Browse_status[GLOBAL_WIN] == True) ? (UpdateAll || (GetGlobalsChanged() == CLIPS_TRUE)) : FALSE)
+ if((Browse_status[GLOBAL_WIN] == True) ? (UpdateAll || (EnvGetGlobalsChanged(theEnv) == CLIPS_TRUE)) : FALSE)
       {
-      SetGlobalsChanged(CLIPS_FALSE);
+      EnvSetGlobalsChanged(theEnv,CLIPS_FALSE);
       PrintChangedGlobals();
       }
 
@@ -642,8 +656,9 @@ void UpdateMenus()
 *******************************************************************************/
 void UpdateOptionsMenu()
   {
-  int i;
-  unsigned n =  0;
+   int i;
+   unsigned n =  0;
+   void *theEnv = GetCurrentEnvironment();
 
   XtSetArg(TheArgs[n], XtNleftBitmap, None);n++;
   for(i = 0; i <= RANDOM_STRATEGY;i++) 
@@ -652,10 +667,10 @@ void UpdateOptionsMenu()
     XtSetValues(sal_opt_widgets[i],TheArgs,n);
   n = 0;
   XtSetArg(TheArgs[n], XtNleftBitmap, checker);n++;
-  XtSetValues(strategy_widgets[GetStrategy()],TheArgs,n);
-  XtSetValues(sal_opt_widgets[GetSalienceEvaluation()],TheArgs,n);
+  XtSetValues(strategy_widgets[EnvGetStrategy(theEnv)],TheArgs,n);
+  XtSetValues(sal_opt_widgets[EnvGetSalienceEvaluation(theEnv)],TheArgs,n);
   n = 0;
-  if (GetFactDuplication())
+  if (EnvGetFactDuplication(theEnv))
     {
     XtSetArg(TheArgs[n], XtNstate,True);n++;
     XtSetValues(option_widgets[INT_FACT_DUPLICATION], TheArgs, n);
@@ -666,7 +681,7 @@ void UpdateOptionsMenu()
     XtSetValues(option_widgets[INT_FACT_DUPLICATION], TheArgs, n);
     }
   n = 0;
-  if (GetDynamicConstraintChecking())
+  if (EnvGetDynamicConstraintChecking(theEnv))
     {
     XtSetArg(TheArgs[n], XtNstate,True);n++;
     XtSetValues(option_widgets[INT_DYN_CONSTRAINT_CHK], TheArgs, n);
@@ -677,7 +692,7 @@ void UpdateOptionsMenu()
     XtSetValues(option_widgets[INT_DYN_CONSTRAINT_CHK], TheArgs, n);
     }
   n = 0;
-  if (GetStaticConstraintChecking())
+  if (EnvGetStaticConstraintChecking(theEnv))
     {
     XtSetArg(TheArgs[n], XtNstate,True);n++;
     XtSetValues(option_widgets[INT_STA_CONSTRAINT_CHK], TheArgs, n);
@@ -688,7 +703,7 @@ void UpdateOptionsMenu()
     XtSetValues(option_widgets[INT_STA_CONSTRAINT_CHK], TheArgs, n);
     }
   n = 0;
-  if (GetSequenceOperatorRecognition())
+  if (EnvGetSequenceOperatorRecognition(theEnv))
     {
     XtSetArg(TheArgs[n], XtNstate,True);n++;
     XtSetValues(option_widgets[INT_SEQUENCE_OPT_REG], TheArgs, n);
@@ -700,7 +715,7 @@ void UpdateOptionsMenu()
     }
 
   n = 0;
-  if (GetAutoFloatDividend())
+  if (EnvGetAutoFloatDividend(theEnv))
     {
     XtSetArg(TheArgs[n], XtNstate,True);n++;
     XtSetValues(option_widgets[INT_AUTO_FLOAT_DIV], TheArgs, n);
@@ -711,7 +726,7 @@ void UpdateOptionsMenu()
     XtSetValues(option_widgets[INT_AUTO_FLOAT_DIV], TheArgs, n);
     }
   n =  0;
-  if (GetIncrementalReset())
+  if (EnvGetIncrementalReset(theEnv))
     {
     XtSetArg(TheArgs[n], XtNstate,True);n++;
     XtSetValues(option_widgets[INT_INCREMENTAL_RESET], TheArgs, n);
@@ -722,7 +737,7 @@ void UpdateOptionsMenu()
     XtSetValues(option_widgets[INT_INCREMENTAL_RESET], TheArgs, n);
     }
   n =  0;
-  if (GetResetGlobals())
+  if (EnvGetResetGlobals(theEnv))
     {
     XtSetArg(TheArgs[n], XtNstate,True);n++;
     XtSetValues(option_widgets[INT_RESET_GLOBALS], TheArgs, n);
@@ -742,6 +757,8 @@ void UpdateOptionsMenu()
 *******************************************************************************/
 static void UpdateWindowsMenu()
   {
+   void *theEnv = GetCurrentEnvironment();
+
   /* ==================================================== */
   /*   Refresh the manager window if nessessary           */
   /* ==================================================== */
@@ -751,7 +768,7 @@ static void UpdateWindowsMenu()
   /* =================================================================== */
   /*  Set the sensitive state to defrule manager item in the browse menu */
   /* =================================================================== */
-  if(GetNextDefrule(NULL))
+  if(EnvGetNextDefrule(theEnv,NULL))
     {
     XtSetArg(TheArgs[0], XtNsensitive, True);
     XtSetValues(defrule_manager, TheArgs, 1);
@@ -765,7 +782,7 @@ static void UpdateWindowsMenu()
   /* ===================================-================================ */
   /*  Set the sensitive state to deffacts manager item in the browse menu */
   /* ==================================================================== */
-  if(GetNextDeffacts(NULL))
+  if(EnvGetNextDeffacts(theEnv,NULL))
     {
     XtSetArg(TheArgs[0], XtNsensitive, True);
     XtSetValues(deffact_manager, TheArgs, 1);
@@ -779,7 +796,7 @@ static void UpdateWindowsMenu()
   /* ======================================================================= */
   /*  Set the sensitive state to deftemplate manager item in the browse menu */
   /* ======================================================================= */
-  if(GetNextDeftemplate(NULL))
+  if(EnvGetNextDeftemplate(theEnv,NULL))
     {
     XtSetArg(TheArgs[0], XtNsensitive, True);
     XtSetValues(deftemplate_manager, TheArgs, 1);
@@ -793,7 +810,7 @@ static void UpdateWindowsMenu()
   /* ======================================================================= */
   /*  Set the sensitive state to deffunction manager item in the browse menu */
   /* ======================================================================= */
-  if(GetNextDeffunction(NULL))
+  if(EnvGetNextDeffunction(theEnv,NULL))
     {
     XtSetArg(TheArgs[0], XtNsensitive, True);
     XtSetValues(deffunction_manager, TheArgs, 1);
@@ -808,7 +825,7 @@ static void UpdateWindowsMenu()
   /*  Set the sensitive state to defglobal manager item in the browse menu */
   /* ===================================================================== */
 
-  if(GetNextDefglobal(NULL))
+  if(EnvGetNextDefglobal(theEnv,NULL))
    {
     XtSetArg(TheArgs[0], XtNsensitive, True);
     XtSetValues(defglobal_manager,TheArgs,1);
@@ -823,7 +840,7 @@ static void UpdateWindowsMenu()
   /*  Set the sensitive state to defgeneric manager item in the browse menu */
   /* ====================================================================== */
 
-  if(GetNextDefgeneric(NULL))
+  if(EnvGetNextDefgeneric(theEnv,NULL))
     {
     XtSetArg(TheArgs[0], XtNsensitive, True);
     XtSetValues(defgeneric_manager, TheArgs, 1);
@@ -838,7 +855,7 @@ static void UpdateWindowsMenu()
   /*  Set the sensitive state to definstances manager item in the browse menu */
   /* ======================================================================== */
 
-  if(GetNextDefinstances(NULL))
+  if(EnvGetNextDefinstances(theEnv,NULL))
     {
     XtSetArg(TheArgs[0], XtNsensitive, True);
     XtSetValues(definstances_manager, TheArgs, 1);
@@ -853,7 +870,7 @@ static void UpdateWindowsMenu()
   /*  Set the sensitive state to defclass manager item in the browse menu */
   /* ==================================================================== */
 
-  if(GetNextDefclass(NULL))
+  if(EnvGetNextDefclass(theEnv,NULL))
     {
     XtSetArg(TheArgs[0], XtNsensitive, True);
     XtSetValues(defclass_manager, TheArgs, 1);
@@ -868,7 +885,7 @@ static void UpdateWindowsMenu()
   /*  Set the sensitive state to agenda manager item in the browse menu */
   /* =================================================================== */
 
-  if(GetNextActivation(NULL))
+  if(EnvGetNextActivation(theEnv,NULL))
     {
     XtSetArg(TheArgs[0], XtNsensitive, True);
     XtSetValues(agenda_manager, TheArgs, 1);
@@ -1170,41 +1187,43 @@ int get_clips_command()
  *               update the the windows during CLIPS process
  ******************************************************************************
  */
-static void PeriodicUpdate()
-{
-  periodicChecking = True;
-  while(XtAppPending(app_con) != 0)
-   {
-     XtAppNextEvent(app_con, &TheEvent);
-     XtDispatchEvent(&TheEvent);
-   }
+static void PeriodicUpdate(
+  void *theEnv)
+  {
+   periodicChecking = True;
+   
+   while(XtAppPending(app_con) != 0)
+     {
+      XtAppNextEvent(app_con, &TheEvent);
+      XtDispatchEvent(&TheEvent);
+     }
 
-  periodicChecking = False;
+   periodicChecking = False;
 
-  if((Browse_status[AGENDA_WIN] == True) ? (GetAgendaChanged() == CLIPS_TRUE) : FALSE)
+   if((Browse_status[AGENDA_WIN] == True) ? (EnvGetAgendaChanged(theEnv) == CLIPS_TRUE) : FALSE)
       {
       PrintChangedAgenda();
-      SetAgendaChanged(CLIPS_FALSE);
+      EnvSetAgendaChanged(theEnv,CLIPS_FALSE);
       }
-  if((Browse_status[FACT_WIN] == True) ? (GetFactListChanged() == CLIPS_TRUE) : FALSE)
+  if((Browse_status[FACT_WIN] == True) ? (EnvGetFactListChanged(theEnv) == CLIPS_TRUE) : FALSE)
       {
       PrintChangedFacts();
-      SetFactListChanged(CLIPS_FALSE);
+      EnvSetFactListChanged(theEnv,CLIPS_FALSE);
       }
- if((Browse_status[INSTANCE_WIN] == True) ? (GetInstancesChanged() == CLIPS_TRUE) : FALSE)
+ if((Browse_status[INSTANCE_WIN] == True) ? (EnvGetInstancesChanged(theEnv) == CLIPS_TRUE) : FALSE)
       {
       PrintChangedInstances();
-      SetInstancesChanged(CLIPS_FALSE);
+      EnvSetInstancesChanged(theEnv,CLIPS_FALSE);
       }
- if((Browse_status[GLOBAL_WIN] == True) ? (GetGlobalsChanged() == CLIPS_TRUE) : FALSE)
+ if((Browse_status[GLOBAL_WIN] == True) ? (EnvGetGlobalsChanged(theEnv) == CLIPS_TRUE) : FALSE)
       {
       PrintChangedGlobals();
-      SetGlobalsChanged(CLIPS_FALSE);
+      EnvSetGlobalsChanged(theEnv,CLIPS_FALSE);
       }
- if((Browse_status[FOCUS_WIN] == True) ? (GetFocusChanged(GetCurrentEnvironment()) == CLIPS_TRUE) :FALSE)
+ if((Browse_status[FOCUS_WIN] == True) ? (EnvGetFocusChanged(theEnv) == CLIPS_TRUE) :FALSE)
      {
       PrintChangedFocus();
-      SetFocusChanged(GetCurrentEnvironment(),CLIPS_FALSE);
+      EnvSetFocusChanged(theEnv,CLIPS_FALSE);
      }
 
 }
