@@ -580,7 +580,7 @@ static void InsertClipsNewLine(
  *
  ************************************************************/
 
-static XComposeStatus compose_status = {NULL, 0};
+XComposeStatus compose_status = {NULL, 0};
 
 /*	Function Name: AutoFill
  *	Description: Breaks the line at the previous word boundry when
