@@ -25,6 +25,7 @@
 
 #include <stdio.h>
 #include <errno.h>
+#include <unistd.h>
 
 #include "setup.h"
 
@@ -70,7 +71,7 @@ Widget ExecItemWidgets[5];
 
 String about_info[] =
   {
-  "XCLIPS for CLIPS version 6.21",
+  "XCLIPS for CLIPS version 6.24",
   "",
   "Developers:",
   "",
@@ -587,6 +588,7 @@ void MenuFunc(
   XtPointer client_data,
   XtPointer call_data)
   {
+   void *theEnv = GetCurrentEnvironment();
    String filename = XawDialogGetValueString(XtParent(w));
    char fullpath[255];
    Widget popup = XtParent(XtParent(XtParent(w)));
@@ -628,7 +630,7 @@ void MenuFunc(
 
       case DRIBBLEON:
         XtDestroyWidget(popup);
-        DribbleOn(fullpath);
+        EnvDribbleOn(theEnv,fullpath);
         break;
 
       case SAVERULES:
