@@ -104,7 +104,9 @@ void CompletionDialogCallback(
   XtPointer client_data, 
   XtPointer call_data)
 {
-  int NumberOfMatches,length;
+  void *theEnv = GetCurrentEnvironment();
+  unsigned int NumberOfMatches;
+  int length;
   struct symbolMatch *matches;
   char *commandString;
 
@@ -162,7 +164,7 @@ void CompletionDialogCallback(
    {
       length = strlen(completionString);
       AppendCommandString(GetCurrentEnvironment(),&(matches->match->contents[length]));
-      PrintRouter("stdin",&(matches->match->contents[length]));
+      EnvPrintRouter(theEnv,"stdin",&(matches->match->contents[length]));
    }
   else
    {
@@ -184,7 +186,8 @@ void CompletionEditCallback(
   XtPointer client_data, 
   XtPointer call_data)
 {
-  int NumberOfMatches,length;
+  unsigned int NumberOfMatches;
+  int length;
   struct symbolMatch *matches;
   XawTextBlock text;
   char *matchString = NULL;
@@ -427,11 +430,12 @@ static void printMatch(
   XtPointer client_data, 
   XtPointer call_data)
 {
+  void *theEnv = GetCurrentEnvironment();
   String aString = XawDialogGetValueString(XtParent(w));
   int length = strlen((char*)client_data);
 
-  AppendCommandString(GetCurrentEnvironment(),&(aString[length]));
-  PrintRouter("stdin",&(aString[length]));
+  AppendCommandString(theEnv,&(aString[length]));
+  EnvPrintRouter(theEnv,"stdin",&(aString[length]));
   XtDestroyWidget(XtParent(XtParent(XtParent(w))));
 }
 
@@ -615,15 +619,16 @@ void DribbleCallback(
   XtPointer client_data, 
   XtPointer call_data)
   {
+  void *theEnv = GetCurrentEnvironment();
   MoveEndOfFile(dialog_text, &TheEvent);
   file_item = DRIBBLEON;
   if (Dribble_status)
     {
     XtSetArg(TheArgs[0], XtNleftBitmap, None);
     XtSetValues(file_dribble, TheArgs, 1);
-    SetCommandString(GetCurrentEnvironment(),"(dribble-off)\n");
-    if(!CommandLineData(GetCurrentEnvironment())->EvaluatingTopLevelCommand)
-      PrintRouter("wclips","(dribble-off)\n");
+    SetCommandString(theEnv,"(dribble-off)\n");
+    if(!CommandLineData(theEnv)->EvaluatingTopLevelCommand)
+      EnvPrintRouter(theEnv,"wclips","(dribble-off)\n");
     quit_get_event = True;
     Dribble_status = !Dribble_status;
     }
@@ -761,49 +766,50 @@ void IntSave(
   XtPointer client_data, 
   XtPointer call_data)
   {
+  void *theEnv = GetCurrentEnvironment();
   char *filename = XawDialogGetValueString(XtParent(w));
 
   switch(file_item)
     {
     case SAVEBINARY:
-      PrintRouter("wclips", "(bsave ");
-      SetCommandString(GetCurrentEnvironment(),"(bsave");
-      AppendCommandString(GetCurrentEnvironment(),"\"");
-      PrintRouter("wclips", "\"");
-      AppendCommandString(GetCurrentEnvironment(),filename);
-      PrintRouter("wclips", filename);
-      AppendCommandString(GetCurrentEnvironment(),"\"");
-      PrintRouter("wclips", "\"");
-      AppendCommandString(GetCurrentEnvironment(),")\n");
-      PrintRouter("wclips", ")\n");
+      EnvPrintRouter(theEnv,"wclips", "(bsave ");
+      SetCommandString(theEnv,"(bsave");
+      AppendCommandString(theEnv,"\"");
+      EnvPrintRouter(theEnv,"wclips", "\"");
+      AppendCommandString(theEnv,filename);
+      EnvPrintRouter(theEnv,"wclips", filename);
+      AppendCommandString(theEnv,"\"");
+      EnvPrintRouter(theEnv,"wclips", "\"");
+      AppendCommandString(theEnv,")\n");
+      EnvPrintRouter(theEnv,"wclips", ")\n");
       quit_get_event = True;
     break;
 
     case SAVEFACTS:
-      PrintRouter("wclips", "(save-facts ");
-      SetCommandString(GetCurrentEnvironment(),"(save-facts");
-      AppendCommandString(GetCurrentEnvironment(),"\"");
-      PrintRouter("wclips", "\"");
-      AppendCommandString(GetCurrentEnvironment(),filename);
-      PrintRouter("wclips", filename);
-      AppendCommandString(GetCurrentEnvironment(),"\"");
-      PrintRouter("wclips", "\"");
-      AppendCommandString(GetCurrentEnvironment(),")\n");
-      PrintRouter("wclips", ")\n");
+      EnvPrintRouter(theEnv,"wclips", "(save-facts ");
+      SetCommandString(theEnv,"(save-facts");
+      AppendCommandString(theEnv,"\"");
+      EnvPrintRouter(theEnv,"wclips", "\"");
+      AppendCommandString(theEnv,filename);
+      EnvPrintRouter(theEnv,"wclips", filename);
+      AppendCommandString(theEnv,"\"");
+      EnvPrintRouter(theEnv,"wclips", "\"");
+      AppendCommandString(theEnv,")\n");
+      EnvPrintRouter(theEnv,"wclips", ")\n");
       quit_get_event = True;
     break;
 
     case SAVERULES:
-      PrintRouter("wclips", "(save ");
-      SetCommandString(GetCurrentEnvironment(),"(save");
-      AppendCommandString(GetCurrentEnvironment(),"\"");
-      PrintCLIPS("wclips", "\"");
-      AppendCommandString(GetCurrentEnvironment(),filename);
-      PrintCLIPS("wclips", filename);
-      AppendCommandString(GetCurrentEnvironment(),"\"");
-      PrintCLIPS("wclips", "\"");
-      AppendCommandString(GetCurrentEnvironment(),")\n");
-      PrintCLIPS("wclips", ")\n");
+      EnvPrintRouter(theEnv,"wclips", "(save ");
+      SetCommandString(theEnv,"(save");
+      AppendCommandString(theEnv,"\"");
+      EnvPrintRouter(theEnv,"wclips", "\"");
+      AppendCommandString(theEnv,filename);
+      EnvPrintRouter(theEnv,"wclips", filename);
+      AppendCommandString(theEnv,"\"");
+      EnvPrintRouter(theEnv,"wclips", "\"");
+      AppendCommandString(theEnv,")\n");
+      EnvPrintRouter(theEnv,"wclips", ")\n");
       quit_get_event = True;
     break;
     }
@@ -1068,11 +1074,12 @@ static void FileToDialog(
 void LoadBatch(
   char *str)
   {
-  PrintCLIPS("wclips", "(batch ");
-  SetCommandString(GetCurrentEnvironment(),"(batch");
+  void *theEnv = GetCurrentEnvironment();
+  EnvPrintRouter(theEnv,"wclips", "(batch ");
+  SetCommandString(theEnv,"(batch");
   GetFileForCLIPS(str);
-  PrintCLIPS("wclips", ")\n");
-  AppendCommandString(GetCurrentEnvironment(),")\n");
+  EnvPrintRouter(theEnv,"wclips", ")\n");
+  AppendCommandString(theEnv,")\n");
   quit_get_event = True;
   }
 
@@ -1085,11 +1092,12 @@ void LoadBatch(
 void LoadBinary(
   char *str)
   {
-  PrintCLIPS("wclips", "(bload ");
-  SetCommandString(GetCurrentEnvironment(),"(bload");
+  void *theEnv = GetCurrentEnvironment();
+  EnvPrintRouter(theEnv,"wclips", "(bload ");
+  SetCommandString(theEnv,"(bload");
   GetFileForCLIPS(str);
-  PrintCLIPS("wclips", ")\n");
-  AppendCommandString(GetCurrentEnvironment(),")\n");
+  EnvPrintRouter(theEnv,"wclips", ")\n");
+  AppendCommandString(theEnv,")\n");
   quit_get_event = True;
   }
 
@@ -1102,11 +1110,12 @@ void LoadBinary(
 void LoadTheFacts(
   char *str)
   {
-  PrintCLIPS("wclips", "(load-facts ");
-  SetCommandString(GetCurrentEnvironment(),"(load-facts");
+  void *theEnv = GetCurrentEnvironment();
+  EnvPrintRouter(theEnv,"wclips", "(load-facts ");
+  SetCommandString(theEnv,"(load-facts");
   GetFileForCLIPS(str);
-  PrintCLIPS("wclips", ")\n");
-  AppendCommandString(GetCurrentEnvironment(),")\n");
+  EnvPrintRouter(theEnv,"wclips", ")\n");
+  AppendCommandString(theEnv,")\n");
   quit_get_event = True;
   }
 
@@ -1119,11 +1128,12 @@ void LoadTheFacts(
 void LoadRules(
   char *str)
   {
-  PrintCLIPS("wclips", "(load ");
-  SetCommandString(GetCurrentEnvironment(),"(load");
+  void *theEnv = GetCurrentEnvironment();
+  EnvPrintRouter(theEnv,"wclips", "(load ");
+  SetCommandString(theEnv,"(load");
   GetFileForCLIPS(str);
-  PrintCLIPS("wclips", ")\n");
-  AppendCommandString(GetCurrentEnvironment(),")\n");
+  EnvPrintRouter(theEnv,"wclips", ")\n");
+  AppendCommandString(theEnv,")\n");
   quit_get_event = True;
   }
 
@@ -1136,13 +1146,14 @@ void LoadRules(
 void IntDribbleOn(
   String str)
   {
-  if(!CommandLineData(GetCurrentEnvironment())->EvaluatingTopLevelCommand)
-    PrintCLIPS("wclips", "(dribble-on ");
-  SetCommandString(GetCurrentEnvironment(),"(dribble-on");
+  void *theEnv = GetCurrentEnvironment();
+  if(!CommandLineData(theEnv)->EvaluatingTopLevelCommand)
+    EnvPrintRouter(theEnv,"wclips", "(dribble-on ");
+  SetCommandString(theEnv,"(dribble-on");
   GetFileForCLIPS(str);
-  if(!CommandLineData(GetCurrentEnvironment())->EvaluatingTopLevelCommand)
-    PrintCLIPS("wclips", ")\n");
-  AppendCommandString(GetCurrentEnvironment(),")\n");
+  if(!CommandLineData(theEnv)->EvaluatingTopLevelCommand)
+    EnvPrintRouter(theEnv,"wclips", ")\n");
+  AppendCommandString(theEnv,")\n");
   quit_get_event = True;
   if (((access(str, 02) == 0) || (access(str, 00))) && (strcmp(str, "\0") != 0))
     {
@@ -1161,14 +1172,15 @@ void IntDribbleOn(
 static void GetFileForCLIPS(
   char *file)
   {
-  AppendCommandString(GetCurrentEnvironment(),"\"");
-  AppendCommandString(GetCurrentEnvironment(),file);
-  AppendCommandString(GetCurrentEnvironment(),"\"");
-  if(!CommandLineData(GetCurrentEnvironment())->EvaluatingTopLevelCommand)
+  void *theEnv = GetCurrentEnvironment();
+  AppendCommandString(theEnv,"\"");
+  AppendCommandString(theEnv,file);
+  AppendCommandString(theEnv,"\"");
+  if(!CommandLineData(theEnv)->EvaluatingTopLevelCommand)
    {
-    PrintCLIPS("wclips", "\"");
-    PrintCLIPS("wclips", file);
-    PrintCLIPS("wclips", "\"");
+    EnvPrintRouter(theEnv,"wclips", "\"");
+    EnvPrintRouter(theEnv,"wclips", file);
+    EnvPrintRouter(theEnv,"wclips", "\"");
    }
   }
 
@@ -1184,9 +1196,10 @@ void Restart(
   Widget w,
   XtPointer client_data, 
   XtPointer call_data)
-  {
-  system("xclips&");
-  XclipsExit(0);
+  {  
+   void *theEnv = GetCurrentEnvironment();
+   system("xclips&");
+   XclipsExit(theEnv,0);
   }
 
 /******************************************************************************
@@ -1200,6 +1213,7 @@ void Quit(
   XtPointer client_data,
   XtPointer call_data)  
   {
-  XclipsExit(0);
+   void *theEnv = GetCurrentEnvironment();
+   XclipsExit(theEnv,0);
   }
 
