@@ -389,95 +389,96 @@ void OkayOptionsCallback(
   Widget w,
   XtPointer client,
   XtPointer call)
-{
+  {
+   void *theEnv = GetCurrentEnvironment();
   Boolean OnOff;
   int n;
  
-   if((GetStrategy()) != optionFlags[STRATEGY_FLAG])
-     SetStrategy(optionFlags[STRATEGY_FLAG]);
-   if((optionFlags[SALIENCE_FLAG]) != GetSalienceEvaluation())
-     SetSalienceEvaluation(optionFlags[SALIENCE_FLAG]);
+   if((EnvGetStrategy(theEnv)) != optionFlags[STRATEGY_FLAG])
+     EnvSetStrategy(theEnv,optionFlags[STRATEGY_FLAG]);
+   if((optionFlags[SALIENCE_FLAG]) != EnvGetSalienceEvaluation(theEnv))
+     EnvSetSalienceEvaluation(theEnv,optionFlags[SALIENCE_FLAG]);
    n = 0;
 
 /* ========================================================= */
 
    XtSetArg(TheArgs[n],XtNstate,&OnOff);n++;
    XtGetValues(option_widgets[INT_FACT_DUPLICATION],TheArgs,n);
-   if((OnOff)&&(!GetFactDuplication()))
+   if((OnOff)&&(! EnvGetFactDuplication(theEnv)))
     {
-      SetFactDuplication(CLIPS_TRUE);
+      EnvSetFactDuplication(theEnv,CLIPS_TRUE);
     }
-   else if ((!OnOff)&&(GetFactDuplication()))
+   else if ((!OnOff)&&(EnvGetFactDuplication(theEnv)))
     {
-      SetFactDuplication(CLIPS_FALSE);
+      EnvSetFactDuplication(theEnv,CLIPS_FALSE);
     }
 /* ========================================================= */
 
    XtGetValues(option_widgets[INT_DYN_CONSTRAINT_CHK],TheArgs,n);
-   if((OnOff)&&(!GetDynamicConstraintChecking()))
+   if((OnOff)&&(! EnvGetDynamicConstraintChecking(theEnv)))
     {
-      SetDynamicConstraintChecking(CLIPS_TRUE);
+      EnvSetDynamicConstraintChecking(theEnv,CLIPS_TRUE);
     }
-   else if((!OnOff) &&(GetDynamicConstraintChecking()))
+   else if((!OnOff) &&(EnvGetDynamicConstraintChecking(theEnv)))
     {
-      SetDynamicConstraintChecking(CLIPS_FALSE);
+      EnvSetDynamicConstraintChecking(theEnv,CLIPS_FALSE);
     }
 
 /* ========================================================= */
 
    XtGetValues(option_widgets[INT_STA_CONSTRAINT_CHK],TheArgs,n);
-   if((OnOff)&&(!GetStaticConstraintChecking()))
+   if((OnOff)&&(! EnvGetStaticConstraintChecking(theEnv)))
     {
-      SetStaticConstraintChecking(CLIPS_TRUE);
+      EnvSetStaticConstraintChecking(theEnv,CLIPS_TRUE);
     }
-   else if((!OnOff) &&(GetStaticConstraintChecking()))  
+   else if((!OnOff) &&(EnvGetStaticConstraintChecking(theEnv)))  
     { 
-      SetStaticConstraintChecking(CLIPS_FALSE);
+      EnvSetStaticConstraintChecking(theEnv,CLIPS_FALSE);
     }
 /* ========================================================= */
 
    XtGetValues(option_widgets[INT_SEQUENCE_OPT_REG],TheArgs,n);
-   if((OnOff)&&(!GetSequenceOperatorRecognition()))
+   if((OnOff)&&(!EnvGetSequenceOperatorRecognition(theEnv)))
     {
-      SetSequenceOperatorRecognition(CLIPS_TRUE);
+      EnvSetSequenceOperatorRecognition(theEnv,CLIPS_TRUE);
     }
-   else if((!OnOff) &&(GetSequenceOperatorRecognition()))
+   else if((!OnOff) &&(EnvGetSequenceOperatorRecognition(theEnv)))
     {
-      SetSequenceOperatorRecognition(CLIPS_FALSE);
+      EnvSetSequenceOperatorRecognition(theEnv,CLIPS_FALSE);
     }
 
 /* ========================================================= */
 
    XtGetValues(option_widgets[INT_AUTO_FLOAT_DIV],TheArgs,n);
-   if((OnOff)&&(!GetAutoFloatDividend()))
+   if((OnOff)&&(!EnvGetAutoFloatDividend(theEnv)))
     {
-      SetAutoFloatDividend(CLIPS_TRUE);
+      EnvSetAutoFloatDividend(theEnv,CLIPS_TRUE);
     }
-   else if((!OnOff) &&(GetAutoFloatDividend()))
+   else if((!OnOff) &&(EnvGetAutoFloatDividend(theEnv)))
     {
-      SetAutoFloatDividend(CLIPS_FALSE);
+      EnvSetAutoFloatDividend(theEnv,CLIPS_FALSE);
     }
 /* ========================================================= */
 
    XtGetValues(option_widgets[INT_INCREMENTAL_RESET],TheArgs,n);
-   if((OnOff)&&(!GetIncrementalReset()))
+   if((OnOff)&&(!EnvGetIncrementalReset(theEnv)))
     {
-      SetIncrementalReset(CLIPS_TRUE);
+      EnvSetIncrementalReset(theEnv,CLIPS_TRUE);
     }
-   else if((!OnOff) &&(GetIncrementalReset()))
+   else if((!OnOff) &&(EnvGetIncrementalReset(theEnv)))
     {
-      SetIncrementalReset(CLIPS_FALSE);
+      EnvSetIncrementalReset(theEnv,CLIPS_FALSE);
     }
 /* ========================================================= */
 
    XtGetValues(option_widgets[INT_RESET_GLOBALS],TheArgs,n);
-   if((OnOff)&&(!GetResetGlobals()))
+   if((OnOff)&&(!EnvGetResetGlobals(theEnv)))
     {
-      SetResetGlobals(CLIPS_TRUE);
+      EnvSetResetGlobals(theEnv,CLIPS_TRUE);
     }
-   else if((!OnOff) &&(GetResetGlobals()))
+   else if((!OnOff) &&(EnvGetResetGlobals(theEnv)))
     {
-      SetResetGlobals(CLIPS_FALSE);
+      EnvSetResetGlobals(theEnv,CLIPS_FALSE);
     }
    XtPopdown(XtParent(XtParent(w)));
   quit_get_event = True;
